@@ -27,11 +27,15 @@
 #include <gtkhtml/gtkhtml.h>
 #include <gtkhtml/htmlengine.h>
 
+#ifdef USE_GTKMOZEMBED
+#include <gtkmozembed.h>
+#endif
 
 
 #include "gui/gnomesword.h"
 #include "gui/bibletext.h"
 #include "gui/bibletext_dialog.h"
+#include "gui/bookmarks_treeview.h"
 #include "gui/shortcutbar_main.h"
 #include "gui/sidebar.h"
 #include "gui/cipher_key_dialog.h"
@@ -45,40 +49,19 @@
 #include "gui/tabbed_browser.h"
 #include "gui/widgets.h"
 
-#include "main/bibletext.h"
 #include "main/settings.h"
 #include "main/lists.h"
 #include "main/sword.h"
 #include "main/xml.h"
 #include "main/global_ops.hh"
+#include "main/embed.h"
 
-static void create_menu(GdkEventButton * event);
+gboolean shift_key_presed = FALSE;
+
+static void create_menu(void); //GdkEventButton * event);
 
 static GtkTextBuffer *text_buffer;
 
-/******************************************************************************
- * Name
- *  update_text_global_ops
- *
- * Synopsis
- *   #include "gui/bibletext.h"
- *
- *   void update_text_global_ops(gchar * option, gboolean choice)
- *
- * Description
- *
- *
- * Return value
- *   void
- */
-
-void gui_update_text_global_ops(gchar * option, gboolean choice)
-{
-	/*g_warning("gui_update_text_global_ops");
-	save_module_options(settings.MainWindowModule, option, choice);
-	gui_display_text(settings.currentverse);*/
-}
-
 /******************************************************************************
  * Name
  *  global_option_red_words
@@ -101,7 +84,7 @@ static void on_global_option(GtkMenuItem * menuitem, gpointer data)
 	gchar *url = g_strdup_printf(	"sword://%s/%s",
 					settings.MainWindowModule,
 					settings.currentverse);
-	save_module_options(settings.MainWindowModule, (gchar *) data,
+	main_save_module_options(settings.MainWindowModule, (gchar *) data,
 			    GTK_CHECK_MENU_ITEM(menuitem)->active);
 	/* show the change */
 	main_url_handler(url, TRUE);		
@@ -119,17 +102,15 @@ static void on_global_option(GtkMenuItem * menuitem, gpointer data)
  *
  *
  * Description
- *   add global module options to popup menus
+ *   
  *
  * Return value
  *   void
  */
 
-void gui_popup_pm_text(gchar * mod_name, GdkEventButton * event)
+void gui_popup_pm_text(void)
 {
-	GLOBAL_OPS *ops = main_new_globals(settings.MainWindowModule);
-	create_menu(event);	
-	g_free(ops);
+	create_menu();	
 }
 
 
@@ -157,9 +138,10 @@ static gboolean on_text_button_press_event(GtkWidget * widget,
 	case 1:
 		break;
 	case 2:
+		shift_key_presed = TRUE;
 		break;
 	case 3:
-		gui_popup_pm_text(settings.MainWindowModule, event);
+		gui_popup_pm_text();
 		break;
 	}
 	return FALSE;
@@ -210,14 +192,8 @@ static gboolean on_text_button_release_event(GtkWidget * widget,
 						     DefaultDict);
 				else
 					dict =
-					    g_strdup(settings.
-						     DictWindowModule);
-				if (settings.inViewer)
-					main_sidebar_display_dictlex
-					    (dict, key);
-				if (settings.inDictpane)
-					main_display_dictionary(dict,
-								  key);
+					    g_strdup(settings.DictWindowModule);
+				main_display_dictionary(dict, key);
 				g_free(key);
 				if (dict)
 					g_free(dict);
@@ -225,6 +201,10 @@ static gboolean on_text_button_release_event(GtkWidget * widget,
 		}
 		break;
 	case 2:
+		if(shift_key_presed) {
+			shift_key_presed = FALSE;
+			break;
+		}
 		if (!in_url)
 			break;
 		url = html_engine_get_link_at (GTK_HTML(widgets.html_text)->engine,
@@ -277,27 +257,54 @@ static gboolean textview_button_press_event(GtkWidget * widget,
 	case 2:
 		break;
 	case 3:
-		gui_popup_pm_text(settings.MainWindowModule, event);
+		gui_popup_pm_text();
 		return TRUE;
 		break;
 	}
 	return FALSE;
 }
 
-gboolean on_motion_notify_event
-                                        (GtkWidget       *widget,
-                                        GdkEventMotion  *event,
+
+
+static gboolean
+on_enter_notify_event        (GtkWidget       *widget,
+                                        GdkEventCrossing *event,
                                         gpointer         user_data)
 {
-	static gulong delay = 5000000;	
-			
-	while(delay != 0) {
-			--delay;
-	} 
-	delay = 5000000; //g_warning("on_motion_notify_event");
-	return FALSE;
+	shift_key_presed = FALSE;
+	//gtk_widget_grab_focus (widgets.html_text);
+	settings.whichwindow = MAIN_TEXT_WINDOW;
+	gui_change_window_title(settings.MainWindowModule);
+  	return FALSE;
 }
 
+static gboolean on_key_press_event           (GtkWidget       *widget,
+                                        GdkEventKey     *event,
+                                        gpointer         user_data)
+{
+	switch(event->hardware_keycode) {
+		case 50:
+		case 62:
+			shift_key_presed = TRUE;
+		break;
+	}
+	g_message("on_key_press_event");
+  	return FALSE;
+}
+
+
+static gboolean on_key_release_event         (GtkWidget       *widget,
+                                        GdkEventKey     *event,
+                                        gpointer         user_data)
+{
+	switch(event->hardware_keycode) {
+		case 50:
+		case 62:
+			shift_key_presed = FALSE;
+		break;
+	}
+  	return FALSE;
+}
 
 
 static gint tag_event_handler (GtkTextTag *tag, GtkWidget *widget,
@@ -480,11 +487,33 @@ GtkWidget *gui_create_bible_pane(void)
 {
 	GtkWidget *notebook_text;
 	GtkWidget *scrolledwindow;
-	
+	GtkWidget *eventbox1;
+	GtkWidget *frame;
 	
 	notebook_text = gtk_notebook_new();
 	gtk_widget_show(notebook_text);
+	/*gtk_notebook_set_show_border((GtkNotebook *)notebook_text,
+                                             TRUE);*/
+
+#ifdef USE_GTKMOZEMBED	
 	
+/*	frame = gtk_frame_new(NULL);
+	gtk_widget_show(frame);
+	gtk_container_add(GTK_CONTAINER(notebook_text), frame);
+	gtk_frame_set_shadow_type(GTK_FRAME(frame), settings.shadow_type);*/
+	
+	eventbox1 = gtk_event_box_new ();
+	gtk_widget_show (eventbox1);
+	gtk_container_add(GTK_CONTAINER(notebook_text), eventbox1);
+	widgets.html_text = embed_new(TEXT_TYPE);
+	gtk_widget_show(widgets.html_text);
+	gtk_container_add(GTK_CONTAINER(eventbox1),
+			 widgets.html_text);
+	
+	g_signal_connect ((gpointer) eventbox1, "enter_notify_event",
+		    G_CALLBACK (on_enter_notify_event),
+		    NULL);
+#else		
 	scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow);
 	gtk_container_add(GTK_CONTAINER(notebook_text),
@@ -493,14 +522,36 @@ GtkWidget *gui_create_bible_pane(void)
 				       (scrolledwindow),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
-
+	/*gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow,
+                                             settings.shadow_type);*/
+	
 	widgets.html_text = gtk_html_new();
 	gtk_widget_show(widgets.html_text);
 	gtk_container_add(GTK_CONTAINER(scrolledwindow),
 			  widgets.html_text);
-
-
-
+			  
+	g_signal_connect(GTK_OBJECT(widgets.html_text), "link_clicked",
+				G_CALLBACK(gui_link_clicked),
+				NULL);
+	g_signal_connect(GTK_OBJECT(widgets.html_text), "on_url",
+				G_CALLBACK(gui_url),
+				GINT_TO_POINTER(TEXT_TYPE));		    
+	g_signal_connect(GTK_OBJECT(widgets.html_text),"button_release_event",
+				G_CALLBACK(on_text_button_release_event),
+				NULL);
+	g_signal_connect(GTK_OBJECT(widgets.html_text), "button_press_event",
+				G_CALLBACK(on_text_button_press_event),
+				NULL);
+	g_signal_connect(GTK_OBJECT(widgets.html_text), "enter_notify_event",
+		    		G_CALLBACK (on_enter_notify_event),
+		       		NULL);
+	g_signal_connect(GTK_OBJECT(widgets.html_text), "key_press_event",
+		    		G_CALLBACK (on_key_press_event),
+		    		NULL);
+	g_signal_connect(GTK_OBJECT(widgets.html_text), "key_release_event",
+		    		G_CALLBACK (on_key_release_event),
+		    		NULL);				   
+#endif
 	scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow);
 	gtk_container_add(GTK_CONTAINER(notebook_text),
@@ -509,6 +560,9 @@ GtkWidget *gui_create_bible_pane(void)
 				       (scrolledwindow),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow,
+                                             settings.shadow_type);
+					     
 	widgets.textview = gtk_text_view_new ();
 	gtk_widget_show(widgets.textview);
 	gtk_container_add(GTK_CONTAINER(scrolledwindow),
@@ -520,6 +574,7 @@ GtkWidget *gui_create_bible_pane(void)
 	gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW (widgets.textview),
 						GTK_WRAP_WORD);
 
+		    
 	g_signal_connect(GTK_OBJECT(widgets.textview),
 				   "button_release_event",
 				   G_CALLBACK
@@ -530,32 +585,12 @@ GtkWidget *gui_create_bible_pane(void)
 				   G_CALLBACK
 				   (textview_button_press_event),
 				  NULL);
-	g_signal_connect(GTK_OBJECT(widgets.html_text), "link_clicked",
-				   G_CALLBACK(gui_link_clicked),
-				   NULL);
-	g_signal_connect ((gpointer)widgets.html_text , 
-			"motion_notify_event",
-                    G_CALLBACK (on_motion_notify_event),
-                    NULL);
-	g_signal_connect(GTK_OBJECT(widgets.html_text), "on_url",
-				   G_CALLBACK(gui_url),
-				   GINT_TO_POINTER(TEXT_TYPE));
-	g_signal_connect(GTK_OBJECT(widgets.html_text),
-				   "button_press_event",
-				   G_CALLBACK
-				   (on_text_button_press_event),
-				   NULL);
-	g_signal_connect(GTK_OBJECT(widgets.html_text),
-				   "button_release_event",
-				   G_CALLBACK
-				   (on_text_button_release_event),
-				   NULL);
 	return 	notebook_text;			   
 	
 }
 
 
-/** BiblicalText menu stuff
+/** menu stuff
  **
  **
  **
@@ -584,7 +619,11 @@ void on_print1_activate(GtkMenuItem * menuitem, gpointer user_data)
 
 void on_copy2_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
+#ifdef USE_GTKMOZEMBED
+	embed_copy_selection(GTK_MOZ_EMBED(widgets.html_text));
+#else
 	gui_copy_html(widgets.html_text);
+#endif
 }
 
 
@@ -617,18 +656,19 @@ on_set_module_font_activate(GtkMenuItem * menuitem, gpointer user_data)
 static void on_use_current_dictionary_activate(GtkMenuItem * menuitem,
 				   		gpointer user_data)
 {
+#ifdef USE_GTKMOZEMBED
+	embed_copy_selection(GTK_MOZ_EMBED(widgets.html_text));
+	gtk_editable_select_region((GtkEditable *)widgets.entry_dict,0,-1);
+	gtk_editable_paste_clipboard((GtkEditable *)widgets.entry_dict);
+	gtk_widget_activate(widgets.entry_dict);
+#else
 	gchar *dict_key = gui_get_word_or_selection(widgets.html_text, FALSE);
 	if (dict_key) {
-		if (settings.inViewer)
-			main_sidebar_display_dictlex(settings.
-						      DictWindowModule,
-						      dict_key);
-		if (settings.inDictpane)
-			main_display_dictionary(settings.
-						  DictWindowModule,
-						  dict_key);
+		gtk_entry_set_text(GTK_ENTRY(widgets.entry_dict), dict_key);
+		gtk_widget_activate(widgets.entry_dict);
 		g_free(dict_key);
 	}
+#endif
 }
 
 
@@ -698,15 +738,20 @@ void gui_lookup_bibletext_selection(GtkMenuItem * menuitem,
 {
 	gchar *dict_key = NULL;
 	gchar *mod_name = NULL;
-
+	
 	mod_name = main_module_name_from_description(dict_mod_description);
+#ifdef USE_GTKMOZEMBED
+	embed_copy_selection(GTK_MOZ_EMBED(widgets.html_text));
+	gtk_editable_select_region((GtkEditable *)widgets.entry_dict,0,-1);
+	gtk_editable_paste_clipboard((GtkEditable *)widgets.entry_dict);
+	dict_key = 
+		g_strdup(gtk_editable_get_chars(
+			(GtkEditable *)widgets.entry_dict,0,-1));
+#else
 	dict_key = gui_get_word_or_selection(widgets.html_text, FALSE);
+#endif
 	if (dict_key && mod_name) {
-		if (settings.inViewer)
-			main_sidebar_display_dictlex(mod_name,
-						      dict_key);
-		if (settings.inDictpane)
-			main_display_dictionary(mod_name, dict_key);
+		main_display_dictionary(mod_name, dict_key);
 		g_free(dict_key);
 		g_free(mod_name);
 	}
@@ -730,7 +775,7 @@ void gui_lookup_bibletext_selection(GtkMenuItem * menuitem,
 
 static void edit_percomm(GtkMenuItem * menuitem, gpointer user_data)
 {
-	main_dialogs_open((gchar *) user_data);
+	main_dialogs_open((gchar *)user_data, (gchar *)settings.currentverse);
 }
 
 /******************************************************************************
@@ -763,6 +808,17 @@ static void on_view_mod_activate(GtkMenuItem * menuitem,
 }
 
 
+static 
+void on_add_bookmark_activate(GtkMenuItem * menuitem, gpointer user_data)
+{	
+	gchar *label = g_strdup_printf("%s, %s",settings.currentverse,
+					settings.MainWindowModule);
+	gtk_dialog_run((GtkDialog *)gui_create_dialog_add_bookmark(label,
+			settings.MainWindowModule, settings.currentverse));
+	g_free(label);	
+}
+
+
 static GnomeUIInfo view_text_menu_uiinfo[] = {
 	{
 	 GNOME_APP_UI_ITEM, N_("item1"),
@@ -956,6 +1012,13 @@ static GnomeUIInfo menu1_uiinfo[] = {
 	 (gpointer) on_about_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, "gnome-stock-about",
 	 0, (GdkModifierType) 0, NULL},
+	//GNOMEUIINFO_SEPARATOR,
+	{
+	 GNOME_APP_UI_ITEM, N_("Bookmark"),
+	 NULL,
+	 (gpointer) on_add_bookmark_activate, NULL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, "gtk-add",
+	 0, (GdkModifierType) 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_SUBTREE, N_("File"),
@@ -997,7 +1060,8 @@ static GnomeUIInfo menu1_uiinfo[] = {
 	GNOMEUIINFO_END
 };
 
-static void create_menu(GdkEventButton * event)
+static 
+void create_menu(void)
 {
 	GtkWidget *menu1;
 	GtkWidget *lookup_selection_menu;
@@ -1027,9 +1091,9 @@ static void create_menu(GdkEventButton * event)
 	gtk_widget_hide(module_options_menu_uiinfo[10].widget);	//"hebrew_cantillation"
 	gtk_widget_hide(module_options_menu_uiinfo[11].widget);	//"headings"
 	gtk_widget_hide(module_options_menu_uiinfo[12].widget);	//"variants"
-	gtk_widget_hide(menu1_uiinfo[6].widget);	//"unlock_module"
-	gtk_widget_hide(menu1_uiinfo[7].widget);
+	gtk_widget_hide(menu1_uiinfo[7].widget);	//"unlock_module"
 	gtk_widget_hide(menu1_uiinfo[8].widget);
+	gtk_widget_hide(menu1_uiinfo[9].widget);
 
 
 
@@ -1050,7 +1114,7 @@ static void create_menu(GdkEventButton * event)
 
 
 	lookup_selection_menu = gtk_menu_new();
-	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu1_uiinfo[5].widget),
+	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu1_uiinfo[6].widget),
 				  lookup_selection_menu);
 
 	usecurrent =
@@ -1151,7 +1215,7 @@ static void create_menu(GdkEventButton * event)
 
 	}
 	if(main_has_cipher_tag(mod_name))
-		gtk_widget_show(menu1_uiinfo[6].widget);
+		gtk_widget_show(menu1_uiinfo[7].widget);
 
 
 	/*
@@ -1176,10 +1240,12 @@ static void create_menu(GdkEventButton * event)
 	 * menu1_uiinfo[7].widget, "separator7");
 	 * menu1_uiinfo[8].widget, "show_tabs");
 	 */
-	gnome_popup_menu_do_popup_modal(menu1, NULL,
+	/*gnome_popup_menu_do_popup_modal(menu1, NULL,
 					NULL, event, NULL,
-					widgets.html_text);
-	gtk_widget_destroy(menu1);
+					widgets.html_text); */
+	gtk_menu_popup((GtkMenu*)menu1, NULL, NULL, NULL, NULL, 2,
+		     			gtk_get_current_event_time());
+	//gtk_widget_destroy(menu1);
 	g_free(ops);
 }
 
