@@ -25,7 +25,7 @@
 
 #include <gnome.h>
 #include <libxml/parser.h>
-#include <gal/shortcut-bar/e-shortcut-bar.h>
+//#include <gal/shortcut-bar/e-shortcut-bar.h>
 #include <math.h>
 #include <ctype.h>
 #include <sys/types.h>
@@ -60,7 +60,6 @@ gboolean bookmarks_changed;
 
 //extern GtkTreeView *bookmark_tree;
 
-static void save_bookmarks(GtkMenuItem * menuitem, gpointer user_data);
 
 /******************************************************************************
  * Name
@@ -144,9 +143,9 @@ static void save_iter_to_xml_removed(GtkTreeIter * iter)
 	xmlNodePtr cur_node = NULL;
 	xmlDocPtr root_doc;
 	xmlAttrPtr root_attr;
-	const xmlChar *xml_filename;
+	//const xmlChar *xml_filename;
 	gchar *caption = NULL;
-	gchar buf[256];
+	gchar filename[256];
 	GtkTreeIter child;
 	
 	if (!bookmarks_changed) 
@@ -154,15 +153,15 @@ static void save_iter_to_xml_removed(GtkTreeIter * iter)
 	
 	gtk_tree_model_get(GTK_TREE_MODEL(model), iter,
 			   2, &caption, -1);
-	sprintf(buf, "%s/bookmarks/removed/%s.xml", settings.gSwordDir,caption);
-	xml_filename = (const xmlChar *) buf;
+	sprintf(filename, "%s/bookmarks/removed/%s.xml", settings.gSwordDir,caption);
+	//xml_filename = (const xmlChar *) buf;
 	root_doc = xmlNewDoc((const xmlChar *) "1.0");
 	
 	if (root_doc != NULL) {
 		root_node = xmlNewNode(NULL, (const xmlChar *)
 				       "SwordBookmarks");
 		root_attr =
-		    xmlNewProp(root_node, "syntaxVersion",
+		    xmlNewProp(root_node, (const xmlChar *)"syntaxVersion",
 			       (const xmlChar *) "1");
 		xmlDocSetRootElement(root_doc, root_node);
 	}
@@ -173,7 +172,7 @@ static void save_iter_to_xml_removed(GtkTreeIter * iter)
 			parse_treeview(cur_node, iter);
 		}
 	g_free(caption);
-	xmlSaveFormatFile(xml_filename, root_doc,1);
+	xmlSaveFormatFile(filename, root_doc,1);
 	xmlFreeDoc(root_doc);
 	
 	bookmarks_changed = FALSE;
@@ -201,7 +200,7 @@ static void save_treeview_to_xml_bookmarks(GtkTreeIter * iter, gchar * filename)
 	xmlNodePtr cur_node = NULL;
 	xmlDocPtr root_doc;
 	xmlAttrPtr root_attr;
-	const xmlChar *xml_filename;
+	//const xmlChar *xml_filename;
 	gchar *caption = NULL;
 	gchar *key = NULL;
 	gchar *module = NULL;
@@ -211,14 +210,14 @@ static void save_treeview_to_xml_bookmarks(GtkTreeIter * iter, gchar * filename)
 	if (!bookmarks_changed) 
 		return;
 	
-	xml_filename = (const xmlChar *) filename;
+	//xml_filename = (const xmlChar *) filename;
 	root_doc = xmlNewDoc((const xmlChar *) "1.0");
 	
 	if (root_doc != NULL) {
 		root_node = xmlNewNode(NULL, (const xmlChar *)
 				       "SwordBookmarks");
 		root_attr =
-		    xmlNewProp(root_node, "syntaxVersion",
+		    xmlNewProp(root_node, (const xmlChar *) "syntaxVersion",
 			       (const xmlChar *) "1");
 		xmlDocSetRootElement(root_doc, root_node);
 	}
@@ -248,7 +247,7 @@ static void save_treeview_to_xml_bookmarks(GtkTreeIter * iter, gchar * filename)
 		g_free(description);	
 	} while(gtk_tree_model_iter_next(GTK_TREE_MODEL(model),iter));
 	
-	xmlSaveFormatFile(xml_filename, root_doc,1);
+	xmlSaveFormatFile(filename, root_doc,1);
 	xmlFreeDoc(root_doc);
 	g_free(filename);	
 	bookmarks_changed = FALSE;
@@ -290,46 +289,6 @@ static void add_item_to_tree(GtkTreeIter *iter,GtkTreeIter *parent,
 }
 
 
-/******************************************************************************
- * Name
- *   goto_bookmark
- *
- * Synopsis
- *   #include "gui/bookmarks_menu.h"
- *
- *   void goto_bookmark(gchar * mod_name, gchar * key)
- *
- * Description
- *   test for module type and call the appropriate function to
- *   display bookmark
- *
- * Return value
- *   void
- */
-
-static void goto_bookmark(gchar * url)
-{
-	gint module_type;
-	
-	if (use_dialog) {
-		module_type = main_main_get_mod_type_from_url(url);
-		switch (module_type) {
-		case TEXT_TYPE:
-		case COMMENTARY_TYPE:
-			main_dialog_goto_bookmark(url);
-			break;
-		case DICTIONARY_TYPE:
-			//gui_dictionary_dialog_goto_bookmark(mod_name, key);
-			break;
-		case BOOK_TYPE:
-			//gui_gbs_dialog_goto_bookmark(mod_name, key);
-			break;
-		}
-	} else
-		main_url_handler(url);
-}
-
-
 /******************************************************************************
  * Name
  *   
@@ -435,7 +394,11 @@ static void on_dialog_activate(GtkMenuItem * menuitem, gpointer user_data)
 					3, &key, 
 					4, &module, 
 					-1);
-		url = g_strdup_printf("bookmark://%s/%s",module,key);
+		url = g_strdup_printf("gnomesword.url?action=showBookmark&"
+					"type=%s&value=%s&module=%s",
+					"newDialog",
+					main_url_encode(key), 
+					main_url_encode(module));
 		main_url_handler(url, TRUE);
 		g_free(url);
 	}
@@ -547,7 +510,7 @@ static void on_edit_item_activate(GtkMenuItem * menuitem, gpointer user_data)
 			   COL_DESCRIPTION, data->description,
 			   -1);	
 		bookmarks_changed = TRUE;
-		save_bookmarks(NULL, NULL);
+		gui_save_bookmarks(NULL, NULL);
 		g_free(data);
 	}
 	g_free(info->text1);	// we used g_strdup() 
@@ -602,7 +565,7 @@ static void on_remove_folder_activate(GtkMenuItem * menuitem,
 	save_iter_to_xml_removed(&selected);
 	gtk_tree_store_remove(GTK_TREE_STORE(model), &selected);
 	bookmarks_changed = TRUE;
-	save_bookmarks(NULL, NULL);
+	gui_save_bookmarks(NULL, NULL);
 	g_free(caption);
 }
 
@@ -634,7 +597,7 @@ static void restore_ok(GtkButton * button, GtkWidget * filesel)
 	gui_load_removed(file);
 	
 	bookmarks_changed = TRUE;
-	save_bookmarks(NULL, NULL);
+	gui_save_bookmarks(NULL, NULL);
 	gtk_widget_destroy(filesel);
 }
 
@@ -780,7 +743,7 @@ static void on_delete_item_activate(GtkMenuItem * menuitem, gpointer user_data)
 	if (test == GS_YES) {
 		gtk_tree_store_remove(GTK_TREE_STORE(model), &selected);
 		bookmarks_changed = TRUE;
-		save_bookmarks(NULL, NULL);
+		gui_save_bookmarks(NULL, NULL);
 	}
 	g_free(yes_no_dialog);
 	g_free(caption);
@@ -792,12 +755,12 @@ static void on_delete_item_activate(GtkMenuItem * menuitem, gpointer user_data)
 
 /******************************************************************************
  * Name
- *   save_bookmarks
+ *   gui_save_bookmarks
  *
  * Synopsis
  *   #include "gui/bookmarks_menu.h"
  *
- *   void save_bookmarks(GtkMenuItem * menuitem, gpointer user_data)
+ *   void gui_save_bookmarks(GtkMenuItem * menuitem, gpointer user_data)
  *
  * Description
  *   save bookmark tree 
@@ -806,7 +769,7 @@ static void on_delete_item_activate(GtkMenuItem * menuitem, gpointer user_data)
  *   void
  */
 
-void save_bookmarks(GtkMenuItem * menuitem, gpointer user_data)
+void gui_save_bookmarks(GtkMenuItem * menuitem, gpointer user_data)
 {
 	
 	GtkTreeIter root;
@@ -819,7 +782,7 @@ void save_bookmarks(GtkMenuItem * menuitem, gpointer user_data)
                                              &root))
 		return;
 
-	sprintf(buf, "%s/bookmarks/%s", settings.gSwordDir,"bookmarks.xml");
+	sprintf(buf, "%s/bookmarks/bookmarks.xml", settings.gSwordDir);
 	save_treeview_to_xml_bookmarks(&first_child, g_strdup(buf));
 }
 
@@ -841,7 +804,7 @@ void save_bookmarks(GtkMenuItem * menuitem, gpointer user_data)
 
 void gui_save_bookmarks_treeview(void)
 {
-	save_bookmarks(NULL, NULL);
+	gui_save_bookmarks(NULL, NULL);
 }
 
 
@@ -960,7 +923,7 @@ static void on_add_bookmark_activate(GtkMenuItem * menuitem,
 		data->closed = NULL;			
 		add_item_to_tree(&iter,&selected, data);			
 		bookmarks_changed = TRUE;
-		save_bookmarks(NULL, NULL);
+		gui_save_bookmarks(NULL, NULL);
 	}
 	g_free(info->text1);	/* we used g_strdup() */
 	g_free(info->text2);
@@ -1054,7 +1017,7 @@ static void on_new_folder_activate(GtkMenuItem * menuitem, gpointer user_data)
 		data->closed = bm_pixbufs->pixbuf_closed;			
 		add_item_to_tree(&iter,&selected, data);
 		bookmarks_changed = TRUE;
-		save_bookmarks(NULL, NULL);
+		gui_save_bookmarks(NULL, NULL);
 		g_free(data->caption);
 	}
 	g_free(data);
@@ -1086,6 +1049,7 @@ void on_open_in_tab_activate(GtkMenuItem * menuitem, gpointer user_data)
 	GtkTreeIter iter;
 	gchar *key = NULL;
 	gchar *module = NULL;
+	gchar *url = NULL;
 	
 	
 	selection = gtk_tree_view_get_selection(bookmark_tree);
@@ -1095,9 +1059,15 @@ void on_open_in_tab_activate(GtkMenuItem * menuitem, gpointer user_data)
 				   3, &key, 
 				   4, &module, 
 			           -1);	
-	main_open_bookmark_in_new_tab(module,key);
+	url = g_strdup_printf("gnomesword.url?action=showBookmark&"
+					"type=%s&value=%s&module=%s",
+					"newTab",
+					main_url_encode(key), 
+					main_url_encode(module));
+	main_url_handler(url,TRUE);
 	g_free(key);
 	g_free(module);
+	g_free(url);
 }
 
 
@@ -1144,7 +1114,7 @@ static GnomeUIInfo pmBookmarkTree_uiinfo[] = {
 	 GNOME_APP_UI_ITEM, N_("Open in a dialog"),
 	 N_("Open this bookmark in a dialog"),
 	 (gpointer) on_dialog_activate, NULL, NULL,
-	 GNOME_APP_PIXMAP_STOCK, GTK_STOCK_OPEN,
+	 GNOME_APP_PIXMAP_FILENAME, PACKAGE_PIXMAPS_DIR "/dlg-un.png",
 	 0, (GdkModifierType) 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("New Folder"),
