@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
-
+ 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -26,12 +26,19 @@
 #include <gnome.h>
 #include <gtkhtml/gtkhtml.h>
 #include <gtkhtml/htmlengine.h>
+/*
+#ifdef USE_GTKHTML30
 #include <gal/widgets/e-unicode.h>
+#endif
+*/
+#ifdef USE_GTKMOZEMBED
+#include <gtkmozembed.h>
+#endif
 
 #include "gui/commentary.h"
+#include "gui/bookmarks_treeview.h"
 #include "gui/gnomesword.h"
 #include "gui/cipher_key_dialog.h"
-//#include "gui/commentary_dialog.h"
 #include "gui/sidebar.h"
 #include "gui/html.h"
 #include "gui/main_window.h"
@@ -39,8 +46,7 @@
 #include "gui/font_dialog.h"
 #include "gui/widgets.h"
 
-#include "main/commentary.h"
-#include "main/percomm.h"
+#include "main/embed.h"
 #include "main/settings.h"
 #include "main/lists.h"
 #include "main/sword.h"
@@ -50,7 +56,7 @@
 
 
 
-static void create_menu(GdkEventButton * event);
+//static void create_menu(GdkEventButton * event);
 
 /******************************************************************************
  * Name
@@ -72,34 +78,12 @@ static void create_menu(GdkEventButton * event);
 static void on_global_option(GtkMenuItem * menuitem, gpointer data)
 {
 	
-	main_save_module_options_comm(settings.MainWindowModule, (gchar *) data,
+	main_save_module_options(settings.MainWindowModule, (gchar *) data,
 			    GTK_CHECK_MENU_ITEM(menuitem)->active);
 	main_display_commentary(settings.CommWindowModule,settings.comm_key);
 }
 
 
-/******************************************************************************
- * Name
- *    
- *
- * Synopsis
- *   #include "gui/.h"
- *
- *   
- *
- * Description
- *   
- *
- * Return value
- *   void
- */
-
-static void popup_pm_comm(GdkEventButton * event)
-{
-	create_menu(event);
-}
-
-
 /******************************************************************************
  * Name
  *  on_comm_button_press_event
@@ -126,10 +110,7 @@ static gboolean on_comm_button_press_event(GtkWidget * widget,
 	case 2:
 		break;
 	case 3:
-		if(settings.comm_showing)
-			create_menu(event); //gui_popup_pm_comm(event);
-		else
-			gui_popup_menu_gbs(event);
+		gui_create_pm_commentary(); //gui_popup_pm_comm(event);
 		break;
 	}
 	return FALSE;
@@ -162,43 +143,38 @@ static gboolean on_comm_button_release_event(GtkWidget * widget,
 	const gchar *url;
 	gchar *buf = NULL;
 	
-	/*
-	 * set program title to current text module name
-	 */
-	if(settings.comm_showing) {
-		settings.whichwindow = COMMENTARY_WINDOW;
-		gui_change_window_title(settings.CommWindowModule);
-	}
-	else {
-		settings.whichwindow = BOOK_WINDOW;
-		gui_change_window_title(settings.book_mod);
-	}
+	settings.whichwindow = COMMENTARY_WINDOW;
 	
 	switch (event->button) {
 	case 1:
-		if (!in_url) {
-			key = gui_button_press_lookup(widgets.html_comm);
-			if (key) {
-				gchar *dict = NULL;
-				if (settings.useDefaultDict)
-					dict =
-					    g_strdup(settings.
-						     DefaultDict);
-				else
-					dict =
-					    g_strdup(settings.
-						     DictWindowModule);
-				if (settings.inViewer)
-					main_sidebar_display_dictlex
-					    (dict, key);
-				if (settings.inDictpane)
-					main_display_dictionary(dict, key);
-					/*gui_change_module_and_key(dict,
-								  key);*/
+		if (in_url) 
+			break;
+		key = gui_button_press_lookup(widgets.html_comm);
+		if (key) {
+			if(g_strstr_len(key,strlen(key),"*")) {
+				key = g_strdelimit(key, "*", ' ');
+				key = g_strstrip(key);
+				url = g_strdup_printf(
+					"gnomesword.url?action=showModInfo&value=1&module=%s",
+					key);
+				main_url_handler(url,TRUE);
+				g_free((gchar*)url);
 				g_free(key);
-				if (dict)
-					g_free(dict);
+				break;
 			}
+			gchar *dict = NULL;
+			if (settings.useDefaultDict)
+				dict =
+				    g_strdup(settings.
+					     DefaultDict);
+			else
+				dict =
+				    g_strdup(settings.
+					     DictWindowModule);
+			main_display_dictionary(dict, key);
+			g_free(key);
+			if (dict)
+				g_free(dict);
 		}
 		break;
 	case 2:
@@ -220,6 +196,17 @@ static gboolean on_comm_button_release_event(GtkWidget * widget,
 }
 
 
+static gboolean on_enter_notify_event(GtkWidget * widget,
+				      GdkEventCrossing * event,
+				      gpointer user_data)
+{
+	//shift_key_presed = FALSE;
+	//gtk_widget_grab_focus (widgets.html_comm);
+	//settings.whichwindow = COMMENTARY_WINDOW;
+	//gui_change_window_title(settings.CommWindowModule);
+  	return FALSE;
+}
+
 /******************************************************************************
  * Name
  *   gui_create_commentary_pane
@@ -239,11 +226,12 @@ static gboolean on_comm_button_release_event(GtkWidget * widget,
 GtkWidget *gui_create_commentary_pane(void)
 {
 	GtkWidget *box_comm;
-	GtkWidget *scrolledwindow;	
+	GtkWidget *scrolledwindow;
+	GtkWidget *eventbox1;	
 	
 	box_comm = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(box_comm);
-
+/*
 	widgets.label_comm = gtk_label_new(settings.CommWindowModule);
 	gtk_widget_show(widgets.label_comm);
 	gtk_box_pack_start(GTK_BOX(box_comm),
@@ -251,8 +239,23 @@ GtkWidget *gui_create_commentary_pane(void)
 			   FALSE, 0);
 	gtk_label_set_justify (GTK_LABEL (widgets.label_comm), GTK_JUSTIFY_LEFT);
 	gtk_misc_set_alignment (GTK_MISC (widgets.label_comm), 0, 0.5);
+*/
+#ifdef USE_GTKMOZEMBED	
+	eventbox1 = gtk_event_box_new ();
+	gtk_widget_show (eventbox1);
+	gtk_box_pack_start(GTK_BOX(box_comm),
+			   eventbox1, TRUE,
+			   TRUE, 0);
+	widgets.html_comm = embed_new(COMMENTARY_TYPE);
+	gtk_widget_show(widgets.html_comm);
+	gtk_container_add(GTK_CONTAINER(eventbox1),
+			 widgets.html_comm);
+	
+	g_signal_connect ((gpointer) eventbox1, "enter_notify_event",
+		    G_CALLBACK (on_enter_notify_event),
+		    NULL);
 
-
+#else
 	scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow);
 	gtk_box_pack_start(GTK_BOX(box_comm),
@@ -262,6 +265,8 @@ GtkWidget *gui_create_commentary_pane(void)
 				       (scrolledwindow),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow,
+                                             settings.shadow_type);
 
 	widgets.html_comm = gtk_html_new();
 	gtk_widget_show(widgets.html_comm);
@@ -287,6 +292,7 @@ GtkWidget *gui_create_commentary_pane(void)
 	g_signal_connect(GTK_OBJECT(widgets.html_comm),
 			   "url_requested",
 			   G_CALLBACK(url_requested), NULL);
+#endif
 	return box_comm;
 }
 
@@ -303,8 +309,7 @@ GtkWidget *gui_create_commentary_pane(void)
 
 static void on_about_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
-	gui_display_about_module_dialog((settings.comm_showing)?
-			settings.CommWindowModule:settings.book_mod, FALSE);
+	gui_display_about_module_dialog(settings.CommWindowModule, FALSE);
 }
 
 
@@ -322,14 +327,18 @@ static void on_print1_activate(GtkMenuItem * menuitem, gpointer user_data)
 
 static void on_copy2_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
+#ifdef USE_GTKMOZEMBED
+	embed_copy_selection(GTK_MOZ_EMBED(widgets.html_comm));
+#else
 	gui_copy_html(widgets.html_comm);
+#endif
 }
 
 
 static void on_find1_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
-	gui_find_dlg(widgets.html_comm, (settings.comm_showing)?
-			settings.CommWindowModule:settings.book_mod, FALSE, NULL);
+	gui_find_dlg(widgets.html_comm, settings.CommWindowModule, 
+				FALSE, NULL);
 }
 
 
@@ -342,9 +351,7 @@ static void on_item2_activate(GtkMenuItem * menuitem, gpointer user_data)
 static void
 on_set_module_font_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
-	gui_set_module_font((settings.comm_showing)?
-			settings.CommWindowModule:settings.book_mod);
-	//gui_display_text(settings.currentverse);
+	gui_set_module_font(settings.CommWindowModule);
 }
 
 
@@ -352,20 +359,18 @@ static void
 on_use_current_dictionary_activate(GtkMenuItem * menuitem,
 				   gpointer user_data)
 {
-	gchar *dict_key = gui_get_word_or_selection(widgets.html_comm, FALSE);
-	if (dict_key) {
-		if (settings.inViewer)
-			main_sidebar_display_dictlex(settings.
-						      DictWindowModule,
-						      dict_key);
-		if (settings.inDictpane)
-			main_display_dictionary(settings.DictWindowModule,
-						  dict_key);
-			/*gui_change_module_and_key(settings.
-						  DictWindowModule,
-						  dict_key);*/
-		g_free(dict_key);
-	}
+	gchar *dict_key =NULL;
+#ifdef USE_GTKMOZEMBED
+	embed_copy_selection(GTK_MOZ_EMBED(widgets.html_comm));
+	gtk_editable_select_region((GtkEditable *)widgets.entry_dict,0,-1);
+	gtk_editable_paste_clipboard((GtkEditable *)widgets.entry_dict);
+	gtk_widget_activate(widgets.entry_dict);	
+#else
+	dict_key = gui_get_word_or_selection(widgets.html_comm, FALSE);
+	gtk_entry_set_text(GTK_ENTRY(widgets.entry_dict), dict_key);
+	gtk_widget_activate(widgets.entry_dict);
+	g_free(dict_key);
+#endif
 }
 
 
@@ -438,18 +443,22 @@ void gui_lookup_comm_selection(GtkMenuItem * menuitem,
 {
 	gchar *dict_key = NULL;
 	gchar *mod_name = NULL;
-	
-	//if(!cur_t->html) return;
-	
+		
 	mod_name = main_module_name_from_description(dict_mod_description);
+#ifdef USE_GTKMOZEMBED
+	embed_copy_selection(GTK_MOZ_EMBED(widgets.html_comm));
+	gtk_editable_select_region((GtkEditable *)widgets.entry_dict,0,-1);
+	gtk_editable_paste_clipboard((GtkEditable *)widgets.entry_dict);
+	dict_key = 
+		g_strdup(gtk_editable_get_chars(
+			(GtkEditable *)widgets.entry_dict,0,-1));
+#else	
 	dict_key = gui_get_word_or_selection(widgets.html_comm, FALSE);
+	gtk_entry_set_text(GTK_ENTRY(widgets.entry_dict), dict_key);
+	g_free(dict_key);
+#endif
 	if (dict_key && mod_name) {
-		if (settings.inViewer)
-			main_sidebar_display_dictlex(mod_name,
-						      dict_key);
-		if (settings.inDictpane)
-			main_display_dictionary(mod_name, dict_key);
-			//gui_change_module_and_key(mod_name, dict_key);
+		main_display_dictionary(mod_name, dict_key);
 		g_free(dict_key);
 		g_free(mod_name);
 	}
@@ -474,6 +483,7 @@ void gui_lookup_comm_selection(GtkMenuItem * menuitem,
 static void edit_percomm(GtkMenuItem * menuitem, gpointer user_data)
 {
 //	gui_open_commentary_editor((gchar *) user_data);
+	main_dialogs_open((gchar *)user_data, (gchar *)settings.currentverse);
 }
 
 /******************************************************************************
@@ -507,6 +517,20 @@ static void on_view_mod_activate(GtkMenuItem * menuitem,
 }
 
 
+
+static void on_add_bookmark_activate(GtkMenuItem * menuitem,
+				 gpointer user_data)
+{
+	
+	gchar *label = g_strdup_printf("%s, %s",settings.currentverse,
+					settings.CommWindowModule);
+
+	gtk_dialog_run((GtkDialog *)gui_create_dialog_add_bookmark(label,
+			settings.CommWindowModule, settings.currentverse));
+	g_free(label);	
+	
+}
+
 static GnomeUIInfo view_text_menu_uiinfo[] = {
 	{
 	 GNOME_APP_UI_ITEM, N_("item1"),
@@ -700,6 +724,13 @@ static GnomeUIInfo menu1_uiinfo[] = {
 	 (gpointer) on_about_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, "gnome-stock-about",
 	 0, (GdkModifierType) 0, NULL},
+	//GNOMEUIINFO_SEPARATOR,
+	{
+	 GNOME_APP_UI_ITEM, N_("Bookmark"),
+	 NULL,
+	 (gpointer) on_add_bookmark_activate, NULL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, "gtk-add",
+	 0, (GdkModifierType) 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_SUBTREE, N_("File"),
@@ -741,7 +772,7 @@ static GnomeUIInfo menu1_uiinfo[] = {
 	GNOMEUIINFO_END
 };
 
-static void create_menu(GdkEventButton * event)
+void gui_create_pm_commentary(void)
 {
 	GtkWidget *menu1;
 	GtkWidget *lookup_selection_menu;
@@ -770,36 +801,31 @@ static void create_menu(GdkEventButton * event)
 	gtk_widget_hide(module_options_menu_uiinfo[10].widget);	//"hebrew_cantillation"        
 	gtk_widget_hide(module_options_menu_uiinfo[11].widget);	//"headings"    
 	gtk_widget_hide(module_options_menu_uiinfo[12].widget);	//"variants"   
-	gtk_widget_hide(menu1_uiinfo[6].widget);	//"unlock_module"
-	gtk_widget_hide(menu1_uiinfo[7].widget);
+	gtk_widget_hide(menu1_uiinfo[7].widget);	//"unlock_module"
 	gtk_widget_hide(menu1_uiinfo[8].widget);
+	gtk_widget_hide(menu1_uiinfo[9].widget);
 
 
-	if(settings.comm_showing) {
-		view_menu = gtk_menu_new();
-		gtk_menu_item_set_submenu(GTK_MENU_ITEM(file3_menu_uiinfo[0].widget),
-					  view_menu);
-		
-		gui_add_mods_2_gtk_menu(COMM_DESC_LIST, view_menu,
-					(GCallback) on_view_mod_activate);
-		
-		edit_per_menu = gtk_menu_new();
-		gtk_menu_item_set_submenu(GTK_MENU_ITEM(edit3_menu_uiinfo[2].widget),
-					  edit_per_menu);
-					  
-		gui_add_mods_2_gtk_menu(PERCOMM_LIST, edit_per_menu,
-					(GCallback) edit_percomm);
-	} else {
-		gtk_widget_hide(file3_menu_uiinfo[0].widget);
-		gtk_widget_hide(file3_menu_uiinfo[1].widget);
-		gtk_widget_hide(edit3_menu_uiinfo[2].widget);
-		//gtk_widget_hide();
-	}
+	
+	view_menu = gtk_menu_new();
+	gtk_menu_item_set_submenu(GTK_MENU_ITEM(file3_menu_uiinfo[0].widget),
+				  view_menu);
+	
+	gui_add_mods_2_gtk_menu(COMM_DESC_LIST, view_menu,
+				(GCallback) on_view_mod_activate);
+	
+	edit_per_menu = gtk_menu_new();
+	gtk_menu_item_set_submenu(GTK_MENU_ITEM(edit3_menu_uiinfo[2].widget),
+				  edit_per_menu);
+				  
+	gui_add_mods_2_gtk_menu(PERCOMM_LIST, edit_per_menu,
+				(GCallback) edit_percomm);
+	
 				
 								
 	
 	lookup_selection_menu = gtk_menu_new();
-	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu1_uiinfo[5].widget),
+	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu1_uiinfo[6].widget),
 				  lookup_selection_menu);
 	
 	usecurrent =
@@ -808,6 +834,11 @@ static void create_menu(GdkEventButton * event)
 	gtk_container_add(GTK_CONTAINER(lookup_selection_menu),
 			  usecurrent);
 
+	g_signal_connect(GTK_OBJECT(usecurrent),
+			   "activate",
+			   G_CALLBACK(on_use_current_dictionary_activate), 
+			   NULL);
+			   
 	separator = gtk_menu_item_new();
 	gtk_widget_show(separator);
 	gtk_container_add(GTK_CONTAINER(lookup_selection_menu),
@@ -895,7 +926,7 @@ static void create_menu(GdkEventButton * event)
 		
 	}
 	if(main_has_cipher_tag(mod_name))
-		gtk_widget_show(menu1_uiinfo[6].widget);
+		gtk_widget_show(menu1_uiinfo[7].widget);
 	
 	
 	/* 
@@ -920,10 +951,12 @@ static void create_menu(GdkEventButton * event)
 	 * menu1_uiinfo[7].widget, "separator7");
 	 * menu1_uiinfo[8].widget, "show_tabs");
 	 */
-	gnome_popup_menu_do_popup_modal(menu1, NULL,
+	gtk_menu_popup((GtkMenu*)menu1, NULL, NULL, NULL, NULL, 2,
+		     			gtk_get_current_event_time());
+	/*gnome_popup_menu_do_popup_modal(menu1, NULL,
 					NULL, event, NULL,
-					widgets.html_text);
-	gtk_widget_destroy(menu1);
+					widgets.html_text);*/
+	//gtk_widget_destroy(menu1);
 	g_free(ops);
 }
 
