@@ -156,7 +156,7 @@ static GtkWidget *create_dialog_alert(GS_DIALOG * info)
 
 	dialog_alert = gtk_dialog_new();
 	gtk_container_set_border_width(GTK_CONTAINER(dialog_alert), 5);
-	gtk_window_set_title(GTK_WINDOW(dialog_alert), _(" "));
+	gtk_window_set_title(GTK_WINDOW(dialog_alert), " ");
 	gtk_window_set_resizable(GTK_WINDOW(dialog_alert), FALSE);
 	gtk_dialog_set_has_separator(GTK_DIALOG(dialog_alert), FALSE);
 
@@ -461,7 +461,7 @@ static GtkWidget *gs_dialog_build(GS_DIALOG * info)
 			    gs_dialog);
 	gtk_window_set_title(GTK_WINDOW(gs_dialog),
 			     info->title ? info->title : " ");
-	gtk_window_set_policy(GTK_WINDOW(gs_dialog), TRUE, TRUE, FALSE);
+	gtk_window_set_resizable(GTK_WINDOW(gs_dialog), TRUE);
 	gtk_container_set_border_width(GTK_CONTAINER(gs_dialog), 12);
 
 	if (info->no)
@@ -771,3 +771,43 @@ gint gui_alert_dialog(GS_DIALOG * info)
 	}
 	return 4;
 }
+
+/******************************************************************************
+ * Name
+ *   gui_alert_dialog
+ *
+ * Synopsis
+ *   #include "gui/dialog.h"
+ *
+ *   gint gui_alert_dialog(GS_DIALOG * info)
+ *
+ * Description
+ *   
+ *
+ * Return value
+ *   gint
+ */
+
+gint gui_close_confirmation_dialog(GS_DIALOG * info)
+{
+	GtkWidget *dialog;
+	static gboolean is_running = FALSE;
+
+	if (!is_running) {
+		dialog = create_dialog_alert(info);	//gs_dialog_build(info);
+		gtk_dialog_add_button (GTK_DIALOG (dialog),
+				       _("Close _without Saving"),
+				       GTK_RESPONSE_NO);
+	
+		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					GTK_STOCK_SAVE, GTK_RESPONSE_YES, NULL);
+		retval = 4;
+		is_running = TRUE;
+		gtk_dialog_run((GtkDialog *) dialog);
+		is_running = FALSE;
+		gtk_widget_destroy(dialog);
+		return retval;
+	}
+	return 4;
+}
