@@ -25,8 +25,12 @@
 
 #include <gnome.h>
 
-//#include "gui/gtkhtml_display.h"
+#ifdef USE_GTKMOZEMBED
+#include <gtkmozembed.h>
+#endif
+
 #include "gui/dictlex.h"
+#include "gui/bookmarks_treeview.h"
 #include "gui/gnomesword.h"
 #include "gui/cipher_key_dialog.h"
 #include "gui/shortcutbar_main.h"
@@ -39,10 +43,10 @@
 #include "gui/font_dialog.h"
 #include "gui/widgets.h"
 
+#include "main/embed.h"
 #include "main/sword.h"
 #include "main/settings.h"
 #include "main/lists.h"
-#include "main/dictlex.h"
 #include "main/xml.h"
 
 /******************************************************************************
@@ -57,7 +61,6 @@ extern gboolean isrunningSD;	/* is the view dictionary dialog runing */
 /******************************************************************************
  * static
  */
-static void create_menu(GdkEventButton * event);
 
 
 
@@ -87,29 +90,9 @@ static void set_label(gchar * mod_name)
 
 void on_entryDictLookup_changed(GtkEditable * editable, gpointer data)
 {
-	main_dictionary_entery_changed(settings.DictWindowModule);
+	main_dictionary_entry_changed(settings.DictWindowModule);
 }
 
-/******************************************************************************
- * Name
- *    
- *
- * Synopsis
- *   #include "gui/dictlex.h"
- *
- *   
- *
- * Description
- *   add global module options to popup menus
- *
- * Return value
- *   void
- */
-
-static void popup_pm_dict(gchar * mod_name, GdkEventButton * event)
-{
-	create_menu(event);
-}
 
 
 /******************************************************************************
@@ -191,7 +174,7 @@ static gint html_button_pressed(GtkWidget * html,
 {
 	settings.whichwindow = DICTIONARY_WINDOW;
 
-	gui_change_window_title(settings.DictWindowModule);
+	//gui_change_window_title(settings.DictWindowModule);
 
 	switch (event->button) {
 	case 1:
@@ -203,7 +186,7 @@ static gint html_button_pressed(GtkWidget * html,
 		 */
 		break;
 	case 3:
-		popup_pm_dict(settings.DictWindowModule, event);
+		gui_create_pm_dictionary();
 		break;
 		/*gtk_signal_emit_stop_by_name(GTK_OBJECT(html),
 		   "button_press_event"); */
@@ -216,6 +199,60 @@ static gint html_button_pressed(GtkWidget * html,
 }
 
 
+
+/******************************************************************************
+ * Name
+ *  html_button_released
+ *
+ * Synopsis
+ *   #include "gui/dictlex.h"
+ *
+ *   gint html_button_released(GtkWidget * html, GdkEventButton * event,
+ *					GSHTMLEditorControlData * d)	
+ *
+ * Description
+ *    mouse button released in dictionary / lexicon 
+ *
+ * Return value
+ *   gint
+ */
+
+static gint html_button_released(GtkWidget * html,
+				GdkEventButton * event, gpointer data)
+{
+	extern gboolean in_url;
+	gchar *key;
+	const gchar *url;
+	//gchar *buf = NULL;
+	
+	settings.whichwindow = DICTIONARY_WINDOW;
+
+	//gui_change_window_title(settings.DictWindowModule);
+
+	switch (event->button) {
+	case 1:
+		if (in_url) 
+			break;
+		key = gui_button_press_lookup(widgets.html_dict);
+		if (key) {
+			if(g_strstr_len(key,strlen(key),"*")) {
+				key = g_strdelimit(key, "*", ' ');
+				key = g_strstrip(key);
+				url = g_strdup_printf(
+					"gnomesword.url?action=showModInfo&value=1&module=%s",
+					key);
+				main_url_handler(url,TRUE);
+				g_free((gchar*)url);
+				g_free(key);
+				break;
+			}
+		}
+		break;
+	}
+
+	return FALSE;
+}
+
 /******************************************************************************
  * Name
  *  list_button_released
@@ -292,71 +329,249 @@ static void add_columns(GtkTreeView * treeview)
 				   NULL, NULL, &settings.cell_height);
 }
 
+
+static gboolean on_enter_notify_event(GtkWidget * widget,
+				      GdkEventCrossing * event,
+				      gpointer user_data)
+{
+	//gtk_widget_grab_focus (widgets.html_dict);
+	//settings.whichwindow = DICTIONARY_WINDOW;
+	//gui_change_window_title(settings.DictWindowModule);
+  	return FALSE;
+}
+
+void dict_key_entry_changed(GtkEntry * entry, gpointer data)
+{
+	gchar *buf = NULL;
+	
+	buf = (gchar*)gtk_entry_get_text(entry);
+	
+	if(strlen(buf) < 2 )
+		return;
+	
+	main_display_dictionary(settings.DictWindowModule, buf);
+	//gtk_widget_grab_focus(widgets.entry_dict);
+}
+
+void button_back_clicked(GtkButton * button, gpointer user_data)
+{
+	if(settings.havedict) main_dictionary_button_clicked(0);
+}
+
+void button_forward_clicked(GtkButton * button, gpointer user_data)
+{
+	if(settings.havedict) main_dictionary_button_clicked(1);
+}
+
+static void on_entry_activate(GtkEntry * entry,
+				   gpointer user_data)
+{
+	g_message("on_entry_activate");
+}
+
+
+/******************************************************************************
+ * Name
+ *   menu_deactivate_callback
+ *
+ * Synopsis
+ *   #include "gui/.h"
+ *
+ *   void menu_deactivate_callback (GtkWidget *widget, gpointer user_data)
+ *
+ * Description
+ *
+ *
+ * Return value
+ *   void
+ */
+
+static void menu_deactivate_callback (GtkWidget *widget, gpointer user_data)
+{
+	GtkWidget *menu_button;
+	
+	menu_button = GTK_WIDGET (user_data);
+		
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (menu_button), FALSE);
+}
+
+
+/******************************************************************************
+ * Name
+ *   
+ *
+ * Synopsis
+ *   #include "gui/.h"
+ *
+ *   
+ *
+ * Description
+ *
+ *
+ * Return value
+ *   
+ */
+
+static void menu_position_under (GtkMenu *menu, 
+		     int *x, 
+		     int *y,
+		     gboolean *push_in,
+		     gpointer user_data)
+{
+	GtkWidget *widget;
+	
+	g_return_if_fail (GTK_IS_BUTTON (user_data));
+	g_return_if_fail (GTK_WIDGET_NO_WINDOW (user_data));
+
+	widget = GTK_WIDGET (user_data);
+	
+	gdk_window_get_origin (widget->window, x, y);
+	
+	*x += widget->allocation.x;
+	*y += widget->allocation.y + widget->allocation.height;
+
+	*push_in = FALSE;
+}
+
+
+/******************************************************************************
+ * Name
+ *   select_button_press_callback
+ *
+ * Synopsis
+ *   #include "gui/.h"
+ *
+ *   gboolean select_button_press_callback (GtkWidget *widget,
+ *			      GdkEventButton *event,
+ *			      gpointer user_data)
+ *
+ * Description
+ *    make the tooglebutton act like a gtk optionmenu by dropping a popup
+ *    under the button
+ *
+ * Return value
+ *   gboolean
+ */
+
+static gboolean select_button_press_callback (GtkWidget *widget,
+			      GdkEventButton *event,
+			      gpointer user_data)
+{
+	GtkWidget *menu = main_dictionary_drop_down_new(settings.DictWindowModule,
+						settings.dictkey);
+	
+	g_signal_connect (menu, "deactivate",
+			  G_CALLBACK (menu_deactivate_callback),
+			  widget);
+	if ((event->type == GDK_BUTTON_PRESS) && event->button == 1) {
+		gtk_widget_grab_focus (widget);
+		
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
+		gtk_menu_popup (GTK_MENU (menu),
+				NULL, NULL, menu_position_under, widget, 
+				event->button, event->time);
+
+		return TRUE;
+	}
+	return FALSE;
+}
+
+
 GtkWidget *gui_create_dictionary_pane(void)
 {
 	GtkWidget *box_dict;
 	GtkWidget *hpaned;
 	GtkWidget *vbox;
+	GtkWidget *hbox2;
+	GtkWidget *button10;
+	GtkWidget *image1;
+	GtkWidget *comboboxentry1;
+	GtkWidget *button11;
+	GtkWidget *image2;
+	GtkWidget *arrow1;
 	GtkWidget *frame_entry;
 	GtkWidget *toolbarDLKey;
+	GtkWidget *dict_drop_down;
 	GtkWidget *tmp_toolbar_icon;
 	GtkWidget *label205;
 	GtkWidget *scrolledwindow;
+	GtkWidget *frame;
 	GtkListStore *model;
+	GtkWidget *eventbox;
+	GtkListStore *store;
 
 	box_dict = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(box_dict);
+	
+	gtk_container_set_border_width (GTK_CONTAINER (box_dict), 1);
 
-	widgets.label_dict = gtk_label_new(settings.DictWindowModule);
-	gtk_widget_show(widgets.label_dict);
-	gtk_box_pack_start(GTK_BOX(box_dict),
-			   widgets.label_dict, FALSE, FALSE, 0);
-	gtk_label_set_justify(GTK_LABEL(widgets.label_dict),
-			      GTK_JUSTIFY_LEFT);
-	gtk_misc_set_alignment(GTK_MISC(widgets.label_dict), 0, 0.5);
+	hbox2 = gtk_hbox_new(FALSE, 0);
+	gtk_widget_show(hbox2);
+	gtk_box_pack_start(GTK_BOX(box_dict), hbox2, FALSE, FALSE, 0);
 
-	hpaned = gtk_hpaned_new();
-	gtk_widget_show(hpaned);
-	gtk_box_pack_start(GTK_BOX(box_dict), hpaned, TRUE, TRUE, 0);
-	gtk_paned_set_position(GTK_PANED(hpaned), 195);
+	button10 = gtk_button_new();
+	gtk_widget_show(button10);
+	gtk_box_pack_start(GTK_BOX(hbox2), button10, FALSE, FALSE, 0);
+	gtk_button_set_relief(GTK_BUTTON(button10), GTK_RELIEF_NONE);
 
-	vbox = gtk_vbox_new(FALSE, 0);
-	gtk_widget_show(vbox);
-	gtk_paned_pack1(GTK_PANED(hpaned), vbox, TRUE, TRUE);
+	image1 =
+	    gtk_image_new_from_stock("gtk-go-back",
+				     GTK_ICON_SIZE_BUTTON);
+	gtk_widget_show(image1);
+	gtk_container_add(GTK_CONTAINER(button10), image1);
+	
+  	widgets.entry_dict = gtk_entry_new ();
+  	gtk_widget_show (widgets.entry_dict);
+	gtk_box_pack_start(GTK_BOX(hbox2), widgets.entry_dict, TRUE, TRUE, 0);
+	
+		   
+  	dict_drop_down = gtk_toggle_button_new ();
+ 	 gtk_widget_show (dict_drop_down);
+	gtk_box_pack_start(GTK_BOX(hbox2), dict_drop_down, FALSE, TRUE, 0);
 
-	frame_entry = gtk_frame_new(NULL);
-	gtk_widget_show(frame_entry);
-	gtk_box_pack_start(GTK_BOX(vbox), frame_entry, FALSE, TRUE, 0);
+  	arrow1 = gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_OUT);
+  	gtk_widget_show (arrow1);
+  	gtk_container_add (GTK_CONTAINER (dict_drop_down), arrow1);
+	
+	button11 = gtk_button_new();
+	gtk_widget_show(button11);
+	gtk_box_pack_start(GTK_BOX(hbox2), button11, FALSE, FALSE, 0);
+	gtk_button_set_relief(GTK_BUTTON(button11), GTK_RELIEF_NONE);
 
-	widgets.entry_dict = gtk_entry_new();
-	gtk_widget_show(widgets.entry_dict);
-	gtk_container_add(GTK_CONTAINER(frame_entry),
-			  widgets.entry_dict);
-
-	/* create tree model */
-	model = gtk_list_store_new(1, G_TYPE_STRING);
-
-	/* create tree view */
-	widgets.listview_dict =
-	    gtk_tree_view_new_with_model(GTK_TREE_MODEL(model));
-	gtk_widget_show(widgets.listview_dict);
-	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW
-				     (widgets.listview_dict), TRUE);
-	gtk_box_pack_start(GTK_BOX(vbox), widgets.listview_dict, TRUE,
-			   TRUE, 0);
-	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW
-					  (widgets.listview_dict),
-					  FALSE);
-	add_columns(GTK_TREE_VIEW(widgets.listview_dict));
+	image2 =
+	    gtk_image_new_from_stock("gtk-go-forward",
+				     GTK_ICON_SIZE_BUTTON);
+	gtk_widget_show(image2);
+	gtk_container_add(GTK_CONTAINER(button11), image2);
 
+#ifdef USE_GTKMOZEMBED
+	frame = gtk_frame_new(NULL);
+	gtk_frame_set_shadow_type(GTK_FRAME(frame), settings.shadow_type);
+	gtk_box_pack_start(GTK_BOX(box_dict), frame, TRUE, TRUE, 0);
+	gtk_widget_show(frame);
+	
+	eventbox = gtk_event_box_new ();
+	gtk_container_add(GTK_CONTAINER(frame), eventbox);
+	gtk_widget_show (eventbox);
+	
+	widgets.html_dict = embed_new(DICTIONARY_TYPE);
+	gtk_widget_show(widgets.html_dict);
+	gtk_container_add(GTK_CONTAINER(eventbox),
+			 widgets.html_dict);
+	g_signal_connect ((gpointer) eventbox, "enter_notify_event",
+		    G_CALLBACK (on_enter_notify_event),
+		    NULL);
+#else
 	scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow);
-	gtk_paned_pack2(GTK_PANED(hpaned), scrolledwindow, TRUE, TRUE);
+	gtk_box_pack_start(GTK_BOX(box_dict), scrolledwindow, TRUE, TRUE, 0);
 
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW
 				       (scrolledwindow),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow,
+                                             settings.shadow_type);
 
 	widgets.html_dict = gtk_html_new();
 	gtk_widget_show(widgets.html_dict);
@@ -366,6 +581,9 @@ GtkWidget *gui_create_dictionary_pane(void)
 	g_signal_connect(GTK_OBJECT(widgets.html_dict),
 			 "button_press_event",
 			 G_CALLBACK(html_button_pressed), NULL);
+	g_signal_connect(GTK_OBJECT(widgets.html_dict),
+			 "button_release_event",
+			 G_CALLBACK(html_button_released), NULL);
 	g_signal_connect(GTK_OBJECT(widgets.html_dict),
 			 "url_requested",
 			 G_CALLBACK(url_requested), NULL);
@@ -374,11 +592,21 @@ GtkWidget *gui_create_dictionary_pane(void)
 			 GINT_TO_POINTER(DICTIONARY_TYPE));
 	g_signal_connect(GTK_OBJECT(widgets.html_dict), "link_clicked",
 			 G_CALLBACK(gui_link_clicked), NULL);
-	g_signal_connect(GTK_OBJECT(widgets.entry_dict), "changed",
-			 G_CALLBACK(on_entryDictLookup_changed), NULL);
-	g_signal_connect(G_OBJECT(widgets.listview_dict),
-			 "button_release_event",
-			 G_CALLBACK(list_button_released), NULL);
+#endif
+ 
+	g_signal_connect (dict_drop_down, 
+			  "button_press_event",
+			  G_CALLBACK (select_button_press_callback),
+			  NULL);
+	g_signal_connect(G_OBJECT(widgets.entry_dict), "activate",
+			 G_CALLBACK(dict_key_entry_changed), NULL);
+			 
+	g_signal_connect ((gpointer) button10, "clicked",
+		    G_CALLBACK (button_back_clicked),
+		    NULL);
+	g_signal_connect ((gpointer) button11, "clicked",
+		    G_CALLBACK (button_forward_clicked),
+		    NULL);
 	return box_dict;
 }
 
@@ -392,29 +620,6 @@ GtkWidget *gui_create_dictionary_pane(void)
  **/
 
 
-/******************************************************************************
- * Name
- *  update_text_global_ops
- *
- * Synopsis
- *   #include "gui/bibletext.h"
- *
- *   void update_text_global_ops(gchar * option, gboolean choice)	
- *
- * Description
- *   
- *
- * Return value
- *   void
- */
-
-static void update_comm_global_ops(gchar * option, gboolean choice)
-{
-	/*g_warning("gui_update_text_global_ops");
-	   save_module_options(settings.MainWindowModule, option, choice);
-	   gui_display_text(settings.currentverse); */
-}
-
 /******************************************************************************
  * Name
  *  global_option_red_words
@@ -483,7 +688,11 @@ static void on_print1_activate(GtkMenuItem * menuitem,
 static void on_copy2_activate(GtkMenuItem * menuitem,
 			      gpointer user_data)
 {
+#ifdef USE_GTKMOZEMBED
+	embed_copy_selection(GTK_MOZ_EMBED(widgets.html_dict));
+#else
 	gui_copy_html(widgets.html_dict);
+#endif
 }
 
 
@@ -514,19 +723,22 @@ static void
 on_use_current_dictionary_activate(GtkMenuItem * menuitem,
 				   gpointer user_data)
 {
-	gchar *dict_key =
-	    gui_get_word_or_selection(widgets.html_comm, FALSE);
+	gchar *dict_key = NULL;
+#ifdef USE_GTKMOZEMBED
+	embed_copy_selection(GTK_MOZ_EMBED(widgets.html_dict));
+	gtk_editable_select_region((GtkEditable *)widgets.entry_dict,0,-1);
+	gtk_editable_paste_clipboard((GtkEditable *)widgets.entry_dict);
+	gtk_widget_activate(widgets.entry_dict);		
+#else
+	dict_key =
+	    gui_get_word_or_selection(widgets.html_dict, FALSE);
 	if (dict_key) {
-		if (settings.inViewer)
-			main_sidebar_display_dictlex(settings.
-						     DictWindowModule,
-						     dict_key);
-		if (settings.inDictpane)
-			main_display_dictionary(settings.
+		main_display_dictionary(settings.
 						DictWindowModule,
 						dict_key);
 		g_free(dict_key);
 	}
+#endif
 }
 
 
@@ -592,6 +804,20 @@ static void on_view_mod_activate(GtkMenuItem * menuitem,
 }
 
 
+
+static void on_add_bookmark_activate(GtkMenuItem * menuitem,
+				 gpointer user_data)
+{
+	
+	gchar *label = g_strdup_printf("%s, %s",settings.dictkey,
+					settings.DictWindowModule);
+
+	gtk_dialog_run((GtkDialog *)gui_create_dialog_add_bookmark(label,
+			settings.DictWindowModule, settings.dictkey));
+	g_free(label);	
+	
+}
+
 static GnomeUIInfo view_text_menu_uiinfo[] = {
 	{
 	 GNOME_APP_UI_ITEM, N_("item1"),
@@ -770,6 +996,13 @@ static GnomeUIInfo menu1_uiinfo[] = {
 	 (gpointer) on_about_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, "gnome-stock-about",
 	 0, (GdkModifierType) 0, NULL},
+	//GNOMEUIINFO_SEPARATOR,
+	{
+	 GNOME_APP_UI_ITEM, N_("Bookmark"),
+	 NULL,
+	 (gpointer) on_add_bookmark_activate, NULL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, "gtk-add",
+	 0, (GdkModifierType) 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_SUBTREE, N_("File"),
@@ -811,7 +1044,7 @@ static GnomeUIInfo menu1_uiinfo[] = {
 	GNOMEUIINFO_END
 };
 
-static void create_menu(GdkEventButton * event)
+void gui_create_pm_dictionary(void)
 {
 	GtkWidget *menu1;
 	GtkWidget *lookup_selection_menu;
@@ -838,9 +1071,9 @@ static void create_menu(GdkEventButton * event)
 	gtk_widget_hide(module_options_menu_uiinfo[10].widget);	//"hebrew_cantillation"        
 	gtk_widget_hide(module_options_menu_uiinfo[11].widget);	//"headings"    
 	gtk_widget_hide(module_options_menu_uiinfo[12].widget);	//"variants"   
-	gtk_widget_hide(menu1_uiinfo[6].widget);	//"unlock_module" 
-	gtk_widget_hide(menu1_uiinfo[7].widget);
+	gtk_widget_hide(menu1_uiinfo[7].widget);	//"unlock_module" 
 	gtk_widget_hide(menu1_uiinfo[8].widget);
+	gtk_widget_hide(menu1_uiinfo[9].widget);
 
 
 
@@ -854,7 +1087,7 @@ static void create_menu(GdkEventButton * event)
 
 
 	lookup_selection_menu = gtk_menu_new();
-	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu1_uiinfo[5].widget),
+	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu1_uiinfo[6].widget),
 				  lookup_selection_menu);
 
 	usecurrent =
@@ -862,6 +1095,10 @@ static void create_menu(GdkEventButton * event)
 	gtk_widget_show(usecurrent);
 	gtk_container_add(GTK_CONTAINER(lookup_selection_menu),
 			  usecurrent);
+	g_signal_connect(GTK_OBJECT(usecurrent),
+			   "activate",
+			   G_CALLBACK(on_use_current_dictionary_activate), 
+			   NULL);
 
 	separator = gtk_menu_item_new();
 	gtk_widget_show(separator);
@@ -943,15 +1180,13 @@ static void create_menu(GdkEventButton * event)
 		gtk_widget_show(all_readings_uiinfo[1].widget);	//"primary_reading");
 
 		gtk_widget_show(all_readings_uiinfo[2].widget);	//"secondary_reading");
-
 	}
 	if (main_has_cipher_tag(mod_name))
-		gtk_widget_show(menu1_uiinfo[6].widget);
+		gtk_widget_show(menu1_uiinfo[7].widget);
 
-	gnome_popup_menu_do_popup_modal(menu1, NULL,
-					NULL, event, NULL,
-					widgets.html_text);
-	gtk_widget_destroy(menu1);
+	gtk_menu_popup((GtkMenu*)menu1, NULL, NULL, NULL, NULL, 2,
+		     			gtk_get_current_event_time());
+	
 	g_free(ops);
 }
 
