@@ -42,7 +42,7 @@ extern gboolean dialog_freed;
 /******************************************************************************
  * static - global to this file only
  */
-static GList * dialog_list;
+static GList *dialog_list;
 static DIALOG_DATA *cur_dlg;
 static gint cell_height;
 
@@ -64,8 +64,7 @@ static gint cell_height;
  */
 
 void gui_lookup_dictlex_dialog_selection
-    (GtkMenuItem * menuitem, gchar * dict_mod_description) 
-{
+    (GtkMenuItem * menuitem, gchar * dict_mod_description) {
 /*	gchar *dict_key;
 	gchar *mod_name = NULL;
 
@@ -85,6 +84,7 @@ void gui_lookup_dictlex_dialog_selection
 	if(mod_name) g_free(mod_name);
 */
 }
+
 /******************************************************************************
  * Name
  *   list_selection_changed
@@ -107,10 +107,11 @@ static void list_selection_changed(GtkTreeSelection * selection,
 {
 	GtkTreeIter selected;
 	gchar *buf = NULL;
-	GtkTreeModel *model ;
-	
+	GtkTreeModel *model;
 
-	if (!gtk_tree_selection_get_selected(selection, &model, &selected))
+
+	if (!gtk_tree_selection_get_selected
+	    (selection, &model, &selected))
 		return;
 
 	gtk_tree_model_get(model, &selected, 0, &buf, -1);
@@ -140,7 +141,8 @@ static void list_selection_changed(GtkTreeSelection * selection,
  */
 
 static gint button_press_event(GtkWidget * html,
-			       GdkEventButton * event, DIALOG_DATA * dlg)
+			       GdkEventButton * event,
+			       DIALOG_DATA * dlg)
 {
 	//cur_dlg = dlg;
 	return FALSE;
@@ -165,10 +167,10 @@ static gint button_press_event(GtkWidget * html,
  */
 
 static void dialog_set_focus(GtkWindow * window, GtkWidget * widget,
-                                        DIALOG_DATA * dlg)
+			     DIALOG_DATA * dlg)
 {
 	//cur_dlg = dlg;
-//	g_warning("current module = %s",cur_dlg->mod_name);
+//      g_warning("current module = %s",cur_dlg->mod_name);
 }
 
 /******************************************************************************
@@ -187,7 +189,7 @@ static void dialog_set_focus(GtkWindow * window, GtkWidget * widget,
  *   void
  */
 
-static void dialog_destroy(GtkObject *object, DIALOG_DATA * dlg)
+static void dialog_destroy(GtkObject * object, DIALOG_DATA * dlg)
 {
 	if (!dialog_freed)
 		main_free_on_destroy(dlg);
@@ -211,36 +213,37 @@ static void dialog_destroy(GtkObject *object, DIALOG_DATA * dlg)
  *   void
  */
 
-static void dialog_url(GtkHTML * html, const gchar * url, DIALOG_DATA *dlg)
+static void dialog_url(GtkHTML * html, const gchar * url,
+		       DIALOG_DATA * dlg)
 {
 
 	//cur_dlg = dlg;
 	/*
-	
-		if (*url == '@') {
-			++url;
-			sprintf(buf, _("Show %s in main window"), url);
-		}
-		
-		else if (*url == '[') {
-			++url;
-			while (*url != ']') {
-				++url;
-			}
-			++url;
-			sprintf(buf, "%s", url);
-		}
-		
-		else if (*url == '*') {
-			++url;
-			sprintf(buf, "%s", url);
-		}
-		
-		else
-			sprintf(buf, _("Go to %s"), url);
 
-	
-	*/
+	   if (*url == '@') {
+	   ++url;
+	   sprintf(buf, _("Show %s in main window"), url);
+	   }
+
+	   else if (*url == '[') {
+	   ++url;
+	   while (*url != ']') {
+	   ++url;
+	   }
+	   ++url;
+	   sprintf(buf, "%s", url);
+	   }
+
+	   else if (*url == '*') {
+	   ++url;
+	   sprintf(buf, "%s", url);
+	   }
+
+	   else
+	   sprintf(buf, _("Go to %s"), url);
+
+
+	 */
 }
 
 /******************************************************************************
@@ -261,19 +264,21 @@ static void dialog_url(GtkHTML * html, const gchar * url, DIALOG_DATA *dlg)
  */
 
 static gint list_button_released(GtkWidget * html,
-				GdkEventButton * event, DIALOG_DATA * d)
+				 GdkEventButton * event,
+				 DIALOG_DATA * d)
 {
 	switch (event->button) {
 	case 1:
-		list_selection_changed((GtkTreeSelection*)d->mod_selection, d);
-	 	
+		list_selection_changed((GtkTreeSelection *) d->
+				       mod_selection, d);
+
 		break;
 	case 2:
 	case 3:
 	default:
 		break;
 	}
-	
+
 	return FALSE;
 }
 
@@ -296,12 +301,10 @@ static void add_columns(GtkTreeView * treeview)
 	gtk_tree_view_append_column(treeview, column);
 	/* get cell (row) height */
 	gtk_cell_renderer_get_size(renderer,
-                                   GTK_WIDGET(treeview),
-                                    NULL,
-                                    NULL,
-                                    NULL,
-                                    NULL,
-                                    &cell_height);
+				   GTK_WIDGET(treeview),
+				   NULL,
+				   NULL, NULL, NULL, &cell_height);
+	settings.cell_height = cell_height;
 }
 
 
@@ -342,12 +345,13 @@ void on_btnSyncDL_clicked(GtkButton * button, DIALOG_DATA * d)
  *   void
  */
 
-static void entery_changed(GtkEditable *editable, DIALOG_DATA * d)
+static void entery_changed(GtkEditable * editable, DIALOG_DATA * d)
 {
-	if(d->key)
+	if (d->key)
 		g_free(d->key);
-	d->key = g_strdup((gchar*)gtk_entry_get_text(GTK_ENTRY(d->entry)));
-	
+	d->key =
+	    g_strdup((gchar *) gtk_entry_get_text(GTK_ENTRY(d->entry)));
+
 	main_dialogs_dictionary_entery_changed(d);
 }
 
@@ -368,12 +372,12 @@ static void entery_changed(GtkEditable *editable, DIALOG_DATA * d)
  *   GtkWidget *
  */
 
-void gui_create_dictlex_dialog(DIALOG_DATA *dlg)
+void gui_create_dictlex_dialog(DIALOG_DATA * dlg)
 {
 	GtkWidget *hpaned7;
 	GtkWidget *vbox;
 	GtkWidget *vbox56;
-	GtkWidget *toolbarDLKey;
+	GtkWidget *hbox_toolbar;
 	GtkWidget *tmp_toolbar_icon;
 	GtkWidget *btnSyncDL;
 	GtkWidget *label205;
@@ -381,49 +385,52 @@ void gui_create_dictlex_dialog(DIALOG_DATA *dlg)
 	GtkWidget *scrolledwindowDictHTML;
 	GtkWidget *label;
 	GtkListStore *model;
-	
-	dlg->dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	    
+
+	dlg->dialog = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+
 	gtk_object_set_data(GTK_OBJECT(dlg->dialog), "dlg->dialog",
 			    dlg->dialog);
-	gtk_window_set_title (GTK_WINDOW (dlg->dialog), 
-			main_get_module_description(dlg->mod_name));
+	gtk_window_set_title(GTK_WINDOW(dlg->dialog),
+			     main_get_module_description(dlg->
+							 mod_name));
 	gtk_window_set_default_size(GTK_WINDOW(dlg->dialog), 465, 275);
-	gtk_window_set_policy(GTK_WINDOW(dlg->dialog), TRUE, TRUE,
-			      FALSE);
-	
-	vbox = gtk_vbox_new (FALSE, 0);
-	gtk_widget_show (vbox);
-	gtk_container_add (GTK_CONTAINER (dlg->dialog), vbox);
-  
-  
+	gtk_window_set_resizable(GTK_WINDOW(dlg->dialog), TRUE);
+
+	vbox = gtk_vbox_new(FALSE, 0);
+	gtk_widget_show(vbox);
+	gtk_container_add(GTK_CONTAINER(dlg->dialog), vbox);
+
+
 	dlg->frame = gtk_frame_new(NULL);
-	gtk_widget_show(dlg->frame);	
-	gtk_box_pack_start(GTK_BOX(vbox), dlg->frame, TRUE, TRUE,
-			   0);
+	gtk_widget_show(dlg->frame);
+	gtk_box_pack_start(GTK_BOX(vbox), dlg->frame, TRUE, TRUE, 0);
 
 	hpaned7 = gtk_hpaned_new();
 	gtk_widget_show(hpaned7);
 	gtk_container_add(GTK_CONTAINER(dlg->frame), hpaned7);
-	gtk_paned_set_position(GTK_PANED(hpaned7),
-				     220);
+	gtk_paned_set_position(GTK_PANED(hpaned7), 150);
 
 	vbox56 = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(vbox56);
 	gtk_paned_pack1(GTK_PANED(hpaned7), vbox56, FALSE, TRUE);
 
 
-	toolbarDLKey =
-	    gtk_toolbar_new();
-	gtk_toolbar_set_style (GTK_TOOLBAR (toolbarDLKey), GTK_TOOLBAR_ICONS);
-	gtk_widget_show(toolbarDLKey);
-	gtk_box_pack_start(GTK_BOX(vbox56), toolbarDLKey, FALSE, TRUE,
+	hbox_toolbar = gtk_hbox_new(FALSE, 0);
+	gtk_widget_show(hbox_toolbar);
+	gtk_box_pack_start(GTK_BOX(vbox56), hbox_toolbar, FALSE, TRUE,
 			   0);
-	
-	tmp_toolbar_icon = gtk_image_new_from_stock (
-			GTK_STOCK_REFRESH, 
-			gtk_toolbar_get_icon_size (GTK_TOOLBAR (toolbarDLKey)));			      
-	btnSyncDL =
+			   
+	btnSyncDL = gtk_button_new();
+	gtk_widget_show(btnSyncDL);
+	gtk_box_pack_start(GTK_BOX(hbox_toolbar), btnSyncDL, FALSE,
+			   FALSE, 0);
+	gtk_button_set_relief(GTK_BUTTON(btnSyncDL), GTK_RELIEF_NONE);
+
+	tmp_toolbar_icon =
+	    gtk_image_new_from_stock("gtk-refresh", GTK_ICON_SIZE_BUTTON);
+	gtk_widget_show(tmp_toolbar_icon);
+	gtk_container_add(GTK_CONTAINER(btnSyncDL), tmp_toolbar_icon);
+/*
 	    gtk_toolbar_append_element(GTK_TOOLBAR(toolbarDLKey),
 				       GTK_TOOLBAR_CHILD_BUTTON, 
 				       NULL,
@@ -433,12 +440,15 @@ void gui_create_dictlex_dialog(DIALOG_DATA *dlg)
 				       tmp_toolbar_icon, 
 				       NULL,
 				       NULL);
-	gtk_widget_show(btnSyncDL);
-	
+*/
+//	gtk_widget_show(btnSyncDL);
+
 	dlg->entry = gtk_entry_new();
 	gtk_widget_show(dlg->entry);
-	gtk_toolbar_append_widget(GTK_TOOLBAR(toolbarDLKey), dlg->entry,
-				  NULL, NULL);
+	gtk_box_pack_start(GTK_BOX(hbox_toolbar), dlg->entry, TRUE,
+			   TRUE, 0);
+	
+	
 	/* create tree model */
 	model = gtk_list_store_new(1, G_TYPE_STRING);
 
@@ -446,15 +456,16 @@ void gui_create_dictlex_dialog(DIALOG_DATA *dlg)
 	dlg->listview =
 	    gtk_tree_view_new_with_model(GTK_TREE_MODEL(model));
 	gtk_widget_show(dlg->listview);
-	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(dlg->listview), TRUE);
+	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(dlg->listview),
+				     TRUE);
 	gtk_box_pack_start(GTK_BOX(vbox56), dlg->listview, TRUE, TRUE,
 			   0);
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(dlg->listview),
 					  FALSE);
 	add_columns(GTK_TREE_VIEW(dlg->listview));
 	dlg->mod_selection = G_OBJECT(gtk_tree_view_get_selection
-		     (GTK_TREE_VIEW(dlg->listview)));
-		     
+				      (GTK_TREE_VIEW(dlg->listview)));
+
 
 	frameDictHTML = gtk_frame_new(NULL);
 	gtk_widget_show(frameDictHTML);
@@ -468,6 +479,9 @@ void gui_create_dictlex_dialog(DIALOG_DATA *dlg)
 				       (scrolledwindowDictHTML),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
+					    scrolledwindowDictHTML,
+					    settings.shadow_type);
 
 
 	dlg->html = gtk_html_new();
@@ -475,32 +489,27 @@ void gui_create_dictlex_dialog(DIALOG_DATA *dlg)
 	gtk_container_add(GTK_CONTAINER(scrolledwindowDictHTML),
 			  dlg->html);
 	gtk_html_load_empty(GTK_HTML(dlg->html));
-	
-	g_signal_connect (GTK_OBJECT (dlg->dialog), "set_focus",
-                      G_CALLBACK (dialog_set_focus),
-                      dlg);
-	g_signal_connect (GTK_OBJECT (dlg->dialog), "destroy",
-                      G_CALLBACK (dialog_destroy),
-                      dlg);			   
+
+	g_signal_connect(GTK_OBJECT(dlg->dialog), "set_focus",
+			 G_CALLBACK(dialog_set_focus), dlg);
+	g_signal_connect(GTK_OBJECT(dlg->dialog), "destroy",
+			 G_CALLBACK(dialog_destroy), dlg);
 	g_signal_connect(GTK_OBJECT(dlg->html),
-			"url_requested",
-			G_CALLBACK(url_requested), 
-			NULL);
+			 "url_requested",
+			 G_CALLBACK(url_requested), NULL);
 	g_signal_connect(GTK_OBJECT(dlg->html), "on_url",
-			   G_CALLBACK(dialog_url), 
-			   dlg);
+			 G_CALLBACK(dialog_url), dlg);
 	g_signal_connect(GTK_OBJECT(dlg->html),
-			   "button_press_event",
-			   G_CALLBACK(button_press_event),
-			   dlg);
+			 "button_press_event",
+			 G_CALLBACK(button_press_event), dlg);
 	g_signal_connect(GTK_OBJECT(btnSyncDL), "clicked",
-			   G_CALLBACK(on_btnSyncDL_clicked), dlg);
+			 G_CALLBACK(on_btnSyncDL_clicked), dlg);
 	g_signal_connect(GTK_OBJECT(dlg->entry), "changed",
-			   G_CALLBACK(entery_changed),
-			   (DIALOG_DATA *)dlg);
+			 G_CALLBACK(entery_changed),
+			 (DIALOG_DATA *) dlg);
 	g_signal_connect(G_OBJECT(dlg->listview),
-			   "button_release_event",
-			   G_CALLBACK(list_button_released), dlg);
+			 "button_release_event",
+			 G_CALLBACK(list_button_released), dlg);
 }
 
 
