@@ -25,8 +25,16 @@
 
 #include <gnome.h>
 
+#include <gnome.h>
+#include <gtkhtml/gtkhtml.h>
+#include <gtkhtml/htmlengine.h>
+
+#ifdef USE_GTKMOZEMBED
+#include <gtkmozembed.h>
+#endif
 
 //#include "gui/gtkhtml_display.h"
+#include "gui/bookmarks_treeview.h"
 #include "gui/gbs.h"
 #include "gui/gbs_dialog.h"
 #include "gui/gnomesword.h"
@@ -41,6 +49,7 @@
 #include "gui/font_dialog.h"
 #include "gui/widgets.h"
 
+#include "main/embed.h"
 #include "main/settings.h"
 #include "main/lists.h"
 #include "main/global_ops.hh"
@@ -50,6 +59,118 @@
 static void create_menu(GdkEventButton * event);
 
 
+/******************************************************************************
+ * Name
+ *  on_comm_button_press_event
+ *
+ * Synopsis
+ *   #include ".h"
+ *
+ *  gboolean on_comm_button_press_event(GtkWidget * widget,
+			    GdkEventButton * event, DIALOG_DATA * t)
+ *
+ * Description
+ *   called when mouse button is clicked in html widget
+ *
+ * Return value
+ *   gboolean
+ */
+static gboolean on_book_button_press_event(GtkWidget * widget,
+					GdkEventButton * event,
+					gpointer data)
+{
+	switch (event->button) {
+	case 1:
+		break;
+	case 2:
+		break;
+	case 3:
+		gui_popup_menu_gbs();
+		break;
+	}
+	return FALSE;
+}
+
+
+/******************************************************************************
+ * Name
+ *  on_button_release_event
+ *
+ * Synopsis
+ *   #include "_bibletext.h"
+ *
+ *  gboolean on_button_release_event(GtkWidget * widget,
+			    GdkEventButton * event, DIALOG_DATA * t)
+ *
+ * Description
+ *   called when mouse button is clicked in html widget
+ *
+ * Return value
+ *   gboolean
+ */
+
+static gboolean on_book_button_release_event(GtkWidget * widget,
+					GdkEventButton * event,
+					gpointer data)
+{
+	extern gboolean in_url;
+	gchar *key;
+	const gchar *url;
+	gchar *buf = NULL;
+	
+	settings.whichwindow = BOOK_WINDOW;
+	//gui_change_window_title(settings.book_mod);
+	
+	switch (event->button) {
+	case 1:
+		if (in_url) 
+			break;
+		key = gui_button_press_lookup(widgets.html_book);
+		if (key) {
+			if(g_strstr_len(key,strlen(key),"*")) {
+				key = g_strdelimit(key, "*", ' ');
+				key = g_strstrip(key);
+				url = g_strdup_printf(
+					"gnomesword.url?action=showModInfo&value=1&module=%s",
+					key);
+				main_url_handler(url,TRUE);
+				g_free((gchar*)url);
+				g_free(key);
+				break;
+			}
+			gchar *dict = NULL;
+			if (settings.useDefaultDict)
+				dict =
+				    g_strdup(settings.
+					     DefaultDict);
+			else
+				dict = g_strdup(settings.DictWindowModule);
+			
+			main_display_dictionary(dict, key);
+			g_free(key);
+			if (dict)
+				g_free(dict);
+		}
+		break;
+	case 2:
+		if (!in_url)
+			break;
+		url = html_engine_get_link_at (GTK_HTML(widgets.html_book)->engine,
+					 event->x,
+					 event->y);
+		if(strstr(url,"sword://")) {
+			gchar **work_buf = g_strsplit (url,"/",4);
+			gui_open_passage_in_new_tab(work_buf[3]);
+			g_strfreev(work_buf);
+		}
+		break;
+	case 3:
+		break;
+	}
+	return FALSE;
+}
+
+
 
 /******************************************************************************
  * Name
@@ -67,9 +188,9 @@ static void create_menu(GdkEventButton * event);
  *   void
  */
 
-void gui_popup_menu_gbs(GdkEventButton * event)
+void gui_popup_menu_gbs(void)
 {
-	create_menu(event);
+	create_menu(NULL);
 }
 
 /******************************************************************************
@@ -143,8 +264,102 @@ void gui_update_gbs_global_ops(gchar * option, gboolean choice)
 
 
 
+static gboolean on_enter_notify_event(GtkWidget * widget,
+				      GdkEventCrossing * event,
+				      gpointer user_data)
+{
+	//shift_key_presed = FALSE;
+	//gtk_widget_grab_focus (widgets.html_book);
+	//settings.whichwindow = BOOK_WINDOW;
+  	return FALSE;
+}
 
-/**  Main Commentary menu stuff
+
+/******************************************************************************
+ * Name
+ *   gui_create_book_pane
+ *
+ * Synopsis
+ *   #include "gui/.h"
+ *
+ *   GtkWidget *gui_create_book_pane(void)
+ *
+ * Description
+ *   
+ *
+ * Return value
+ *   GtkWidget*
+ */
+
+GtkWidget *gui_create_book_pane(void)
+{
+	GtkWidget *box;
+	GtkWidget *scrolledwindow;
+	GtkWidget *eventbox;	
+	
+	box = gtk_vbox_new(FALSE, 0);
+	gtk_widget_show(box);
+
+
+#ifdef USE_GTKMOZEMBED	
+	eventbox = gtk_event_box_new ();
+	gtk_widget_show (eventbox);
+	gtk_box_pack_start(GTK_BOX(box),
+			   eventbox, TRUE,
+			   TRUE, 0);
+	widgets.html_book = embed_new(BOOK_TYPE);
+	gtk_widget_show(widgets.html_book);
+	gtk_container_add(GTK_CONTAINER(eventbox),
+			 widgets.html_book);
+	
+	g_signal_connect ((gpointer) eventbox, "enter_notify_event",
+		    G_CALLBACK (on_enter_notify_event),
+		    NULL);
+
+#else
+	scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
+	gtk_widget_show(scrolledwindow);
+	gtk_box_pack_start(GTK_BOX(box),
+			   scrolledwindow, TRUE,
+			   TRUE, 0);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW
+				       (scrolledwindow),
+				       GTK_POLICY_AUTOMATIC,
+				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow,
+                                             settings.shadow_type);
+
+	widgets.html_book = gtk_html_new();
+	gtk_widget_show(widgets.html_book);
+	gtk_container_add(GTK_CONTAINER(scrolledwindow),
+			  widgets.html_book);
+
+	g_signal_connect(GTK_OBJECT(widgets.html_book), "link_clicked",
+				   G_CALLBACK(gui_link_clicked),
+				   NULL);
+	g_signal_connect(GTK_OBJECT(widgets.html_book), "on_url",
+				   G_CALLBACK(gui_url),
+				   GINT_TO_POINTER(BOOK_TYPE));
+	g_signal_connect(GTK_OBJECT(widgets.html_book),
+				   "button_press_event",
+				   G_CALLBACK
+				   (on_book_button_press_event),
+				   NULL);
+	g_signal_connect(GTK_OBJECT(widgets.html_book),
+				   "button_release_event",
+				   G_CALLBACK
+				   (on_book_button_release_event),
+				   NULL);
+	g_signal_connect(GTK_OBJECT(widgets.html_book),
+			   "url_requested",
+			   G_CALLBACK(url_requested), NULL);
+#endif
+	return box;
+}
+
+
+
+/**  Main Book menu stuff
  **
  **
  **
@@ -171,7 +386,7 @@ void gui_update_gbs_global_ops(gchar * option, gboolean choice)
 
 static void on_global_option(GtkMenuItem * menuitem, gpointer data)
 {
-	main_save_module_options_comm(settings.book_mod, (gchar *) data,
+	main_save_module_options(settings.book_mod, (gchar *) data,
 			    GTK_CHECK_MENU_ITEM(menuitem)->active);
 	main_display_book(settings.book_mod,settings.book_key);
 	//gui_set_book_mod_and_key(settings.book_mod, settings.book_key);
@@ -193,19 +408,19 @@ static void on_item1_activate(GtkMenuItem * menuitem, gpointer user_data)
 
 static void on_print1_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
-	gui_html_print(widgets.html_comm, FALSE);
+	gui_html_print(widgets.html_book, FALSE);
 }
 
 
 static void on_copy2_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
-	gui_copy_html(widgets.html_comm);
+	gui_copy_html(widgets.html_book);
 }
 
 
 static void on_find1_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
-	gui_find_dlg(widgets.html_comm, settings.book_mod, FALSE, NULL);
+	gui_find_dlg(widgets.html_book, settings.book_mod, FALSE, NULL);
 }
 
 
@@ -227,18 +442,21 @@ static void
 on_use_current_dictionary_activate(GtkMenuItem * menuitem,
 				   gpointer user_data)
 {
-	gchar *dict_key = gui_get_word_or_selection(widgets.html_comm, FALSE);
-	if (dict_key) {
-		if (settings.inViewer)
-			main_sidebar_display_dictlex(settings.
-						      DictWindowModule,
-						      dict_key);
-		if (settings.inDictpane)
-			main_display_dictionary(settings.
-						  DictWindowModule,
-						  dict_key);
-		g_free(dict_key);
-	}
+#ifdef DEBUG
+	g_message("book on_use_current_dictionary_activate");
+#endif
+	gchar *dict_key =NULL;
+#ifdef USE_GTKMOZEMBED
+	embed_copy_selection(GTK_MOZ_EMBED(widgets.html_book));
+	gtk_editable_select_region((GtkEditable *)widgets.entry_dict,0,-1);
+	gtk_editable_paste_clipboard((GtkEditable *)widgets.entry_dict);
+	gtk_widget_activate(widgets.entry_dict);	
+#else
+	dict_key = gui_get_word_or_selection(widgets.html_book, FALSE);
+	gtk_entry_set_text(GTK_ENTRY(widgets.entry_dict), dict_key);
+	gtk_widget_activate(widgets.entry_dict);
+	g_free(dict_key);
+#endif
 }
 
 
@@ -307,22 +525,27 @@ void gui_lookup_gbs_selection(GtkMenuItem * menuitem,
 {
 	gchar *dict_key = NULL;
 	gchar *mod_name = NULL;
-	
-	//if(!cur_t->html) return;
-	
+		
 	mod_name = main_module_name_from_description(dict_mod_description);
-	dict_key = gui_get_word_or_selection(widgets.html_comm, FALSE);
+#ifdef USE_GTKMOZEMBED
+	embed_copy_selection(GTK_MOZ_EMBED(widgets.html_book));
+	gtk_editable_select_region((GtkEditable *)widgets.entry_dict,0,-1);
+	gtk_editable_paste_clipboard((GtkEditable *)widgets.entry_dict);
+	dict_key = 
+		g_strdup(gtk_editable_get_chars(
+			(GtkEditable *)widgets.entry_dict,0,-1));
+#else	
+	dict_key = gui_get_word_or_selection(widgets.html_book, FALSE);
+	gtk_entry_set_text(GTK_ENTRY(widgets.entry_dict), dict_key);
+#endif
 	if (dict_key && mod_name) {
-		if (settings.inViewer)
-			main_sidebar_display_dictlex(mod_name,
-						      dict_key);
-		if (settings.inDictpane)
-			main_display_dictionary(mod_name, dict_key);
+		main_display_dictionary(mod_name, dict_key);
 		g_free(dict_key);
 		g_free(mod_name);
 	}
 }
 
+
 /******************************************************************************
  * Name
  *  
@@ -374,6 +597,22 @@ static void on_view_mod_activate(GtkMenuItem * menuitem,
 }
 
 
+static void on_add_bookmark_activate(GtkMenuItem * menuitem,
+				 gpointer user_data)
+{
+	gchar *key = g_strdup_printf("%d",settings.book_offset);
+	gchar *local_name = main_get_treekey_local_name(settings.book_offset);
+	gchar *label = g_strdup_printf("%s, %s",local_name,settings.book_mod);
+
+	gtk_dialog_run((GtkDialog *)gui_create_dialog_add_bookmark(label,
+			settings.book_mod, key));
+	g_free(label);	
+	g_free(local_name);		
+	g_free(key);	
+	
+}
+
+
 static GnomeUIInfo view_text_menu_uiinfo[] = {
 	{
 	 GNOME_APP_UI_ITEM, N_("item1"),
@@ -567,6 +806,13 @@ static GnomeUIInfo menu1_uiinfo[] = {
 	 (gpointer) on_about_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, "gnome-stock-about",
 	 0, (GdkModifierType) 0, NULL},
+	//GNOMEUIINFO_SEPARATOR,
+	{
+	 GNOME_APP_UI_ITEM, N_("Bookmark"),
+	 NULL,
+	 (gpointer) on_add_bookmark_activate, NULL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, "gtk-add",
+	 0, (GdkModifierType) 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_SUBTREE, N_("File"),
@@ -636,17 +882,25 @@ static void create_menu(GdkEventButton * event)
 	gtk_widget_hide(module_options_menu_uiinfo[10].widget);	//"hebrew_cantillation"        
 	gtk_widget_hide(module_options_menu_uiinfo[11].widget);	//"headings"    
 	gtk_widget_hide(module_options_menu_uiinfo[12].widget);	//"variants"   
-	gtk_widget_hide(menu1_uiinfo[6].widget);	//"unlock_module"
-	gtk_widget_hide(menu1_uiinfo[7].widget);
+	gtk_widget_hide(menu1_uiinfo[7].widget);	//"unlock_module"
 	gtk_widget_hide(menu1_uiinfo[8].widget);
-	gtk_widget_hide(file3_menu_uiinfo[0].widget);
-	gtk_widget_hide(file3_menu_uiinfo[1].widget);
-	gtk_widget_hide(edit3_menu_uiinfo[2].widget);
+	gtk_widget_hide(menu1_uiinfo[9].widget);
+	//gtk_widget_hide(file3_menu_uiinfo[0].widget);
+	//gtk_widget_hide(file3_menu_uiinfo[1].widget);
+	//gtk_widget_hide(edit3_menu_uiinfo[2].widget);
 				
+	
+	
+	view_menu = gtk_menu_new();
+	gtk_menu_item_set_submenu(GTK_MENU_ITEM(file3_menu_uiinfo[0].widget),
+				  view_menu);
+	
+	gui_add_mods_2_gtk_menu(GBS_DESC_LIST, view_menu,
+				(GCallback) on_view_mod_activate);
 								
 	
 	lookup_selection_menu = gtk_menu_new();
-	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu1_uiinfo[5].widget),
+	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu1_uiinfo[6].widget),
 				  lookup_selection_menu);
 	
 	usecurrent =
@@ -655,6 +909,10 @@ static void create_menu(GdkEventButton * event)
 	gtk_container_add(GTK_CONTAINER(lookup_selection_menu),
 			  usecurrent);
 
+	g_signal_connect(GTK_OBJECT(usecurrent),
+			   "activate",
+			   G_CALLBACK(on_use_current_dictionary_activate), NULL);
+
 	separator = gtk_menu_item_new();
 	gtk_widget_show(separator);
 	gtk_container_add(GTK_CONTAINER(lookup_selection_menu),
@@ -742,7 +1000,7 @@ static void create_menu(GdkEventButton * event)
 		
 	}
 	if(main_has_cipher_tag(mod_name))
-		gtk_widget_show(menu1_uiinfo[6].widget);
+		gtk_widget_show(menu1_uiinfo[7].widget);
 	
 	
 	/* 
@@ -763,14 +1021,17 @@ static void create_menu(GdkEventButton * event)
 	 * module_options_menu_uiinfo[1].widget, "separator5");
 	 * menu1_uiinfo[5].widget, "lookup_selection");
 	 * lookup_selection_menu_uiinfo[0].widget, "use_current_dictionary");
-	 * lookup_selection_menu_uiinfo[1].widget, "separator6");
+	 * lookup_selection_menu_
+	mod_type = backend->module_type((gchar*)module);uiinfo[1].widget, "separator6");
 	 * menu1_uiinfo[7].widget, "separator7");
 	 * menu1_uiinfo[8].widget, "show_tabs");
 	 */
-	gnome_popup_menu_do_popup_modal(menu1, NULL,
+	gtk_menu_popup((GtkMenu*)menu1, NULL, NULL, NULL, NULL, 2,
+		     			gtk_get_current_event_time());
+	/*gnome_popup_menu_do_popup_modal(menu1, NULL,
 					NULL, event, NULL,
-					widgets.html_text);
-	gtk_widget_destroy(menu1);
+					widgets.html_text);*/
+	//gtk_widget_destroy(menu1);
 	g_free(ops);
 }
 
