@@ -27,7 +27,6 @@
 #include <gtkhtml/gtkhtml.h>
 #include <gtkhtml/htmlengine-print.h>
 #include <gtkhtml/htmlselection.h>
-#include <gal/widgets/e-unicode.h>
 #include <libgnomeprint/gnome-print.h>
 #include <libgnomeprintui/gnome-print-dialog.h>
 #include <libgnomeprintui/gnome-print-job-preview.h>
@@ -35,7 +34,7 @@
 
 #include "gui/html.h"
 #include "gui/gnomesword.h"
-#include "gui/editor.h"
+#include "editor/editor.h"
 #include "gui/sidebar.h"
 #include "gui/shortcutbar_main.h"
 #include "gui/parallel_view.h"
@@ -52,7 +51,7 @@
 #include "main/parallel_view.h"
 #include "main/sword.h"
 #include "main/settings.h"
-#include "main/url.h"
+#include "main/url.hh"
 #include "main/xml.h"
 
 static GtkHTMLStream *htmlstream;
@@ -106,331 +105,6 @@ void url_requested(GtkHTML * html, const gchar * url,
 	gtk_html_end(html, handle, status);
 }
 
-/******************************************************************************
- * Name
- *   show_in_appbar
- *
- * Synopsis
- *   #include "gui/html.h"
- *
- *   void show_in_appbar(GtkWidget * appbar, gchar * key, 
- *							gchar * mod)
- *
- * Description
- *   display information (morph or strongs) in appbar
- *
- * Return value
- *   void
- */
-
-static void show_in_appbar(GtkWidget * appbar, gchar * key, gchar * mod)
-{
-	gchar *str;
-	gchar *text;
-	text = main_get_striptext(mod, key);
-	str = remove_linefeeds(text);
-	if (str) {
-		gnome_appbar_set_status(GNOME_APPBAR(appbar), str);
-		g_free(str);
-	}
-	g_free(text);
-}
-
-
-/******************************************************************************
- * Name
- *   deal_with_notes
- *
- * Synopsis
- *   #include "gui/html.h"
- *
- *   void deal_with_notes(const gchar *url)
- *
- * Description
- *   
- *
- * Return value
- *   void
- */
-
-static void deal_with_notes(const gchar * url, gboolean clicked)
-{
-	gchar *buf = NULL;
-	gchar *buf1 = NULL;
-	gchar *tmpbuf = NULL;
-	gchar **work_buf;
-	
-	if(!in_url) {
-		return;
-	}
-	if (hint.in_popup) {
-		gtk_widget_destroy(hint.hint_window);
-		hint.in_popup = FALSE;
-	}
-	buf1 = strchr(url, '=');
-	++buf1;
-	
-	work_buf = g_strsplit (buf1,".",3);
-	
-	if(clicked && !strcmp(work_buf[1], "x")) {
-		tmpbuf = main_get_crossref(settings.MainWindowModule,
-					work_buf[0],
-					work_buf[2]);
-		if (tmpbuf)
-			main_display_verse_list_in_sidebar(settings.
-					  currentverse,
-					  xml_get_value("modules", 
-					  "bible"),
-					  tmpbuf);
-	} else if(!clicked){
-		tmpbuf = main_get_footnote_body(settings.MainWindowModule,
-					work_buf[0],
-					work_buf[2]);
-		if (tmpbuf == NULL)
-			return;
-		gui_display_in_hint_window(tmpbuf);
-	}
-	g_free(tmpbuf);	
-	g_strfreev(work_buf);
-}
-
-
-/******************************************************************************
- * Name
- *   deal_with_refs
- *
- * Synopsis
- *   #include "gui/html.h"
- *
- *   void deal_with_refs(const gchar *url)
- *
- * Description
- *   
- *
- * Return value
- *   void
- */
-
-static void deal_with_refs(const gchar * url)
-{
-	gchar *mybuf = NULL;
-	gchar *modbuf = NULL;
-	gchar *mod_name = NULL;
-	gchar *buf = NULL;
-	gchar newmod[80];
-	gchar newref[80];
-	gint i;
-	
-	mybuf = strstr(url, "version=");
-	if (mybuf) {
-		mybuf = strchr(mybuf, '=');
-		++mybuf;
-		i = 0;
-		while (mybuf[i] != ' ') {
-			newmod[i] = mybuf[i];
-			newmod[i + 1] = '\0';
-			++i;
-		}
-	}
-	mybuf = NULL;
-	mybuf = strstr(url, "passage=");
-	i = 0;
-	if (mybuf) {
-		mybuf = strchr(mybuf, '=');
-		++mybuf;
-		while (i < strlen(mybuf)) {
-			newref[i] = mybuf[i];
-			newref[i + 1] = '\0';
-			++i;
-		}
-	}
-	if (main_is_module(newmod)) {
-		modbuf = newmod;
-	} else {
-		modbuf = xml_get_value("modules", "bible");
-	}
-	buf = g_strdup(newref);
-	mod_name = g_strdup(modbuf);
-
-	if (main_get_mod_type(modbuf) == DICTIONARY_TYPE) {
-		/* we have a dict/lex module 
-		   so we don't need to get a verse list */
-		main_sidebar_display_dictlex(mod_name, buf);
-	} else {
-		main_display_verse_list_in_sidebar(settings.currentverse,
-						  mod_name,
-						  buf);
-	}
-	g_free(buf);
-	g_free(mod_name);
-	
-}
-
-
-/******************************************************************************
- * Name
- *   deal_with_strongs
- *
- * Synopsis
- *   #include "gui/html.h"
- *
- *   void deal_with_strongs(const gchar *url)
- *
- * Description
- *   
- *
- * Return value
- *   void
- */
-
-static void deal_with_storngs(const gchar * url, gboolean clicked)
-{
-	gchar *buf = NULL;
-	gchar *tmpbuf = NULL;
-	gchar *modbuf = NULL;
-	gchar *mybuf = NULL;
-	gchar *modbuf_viewer = NULL;
-	gchar newref[80];
-	gint type = 0;
-	
-	mybuf = NULL;
-	mybuf = strstr(url, "value=");
-	if (mybuf) {
-		mybuf = strchr(mybuf, '=');
-		++mybuf;
-		if (mybuf[0] == 'H')
-			type = 0;
-		if (mybuf[0] == 'G')
-			type = 1;
-		++mybuf;
-		sprintf(newref, "%5.5d", atoi(mybuf));
-	}
-	if (type) {
-		if ((atoi(mybuf) > 5624)
-		    && (settings.havethayer)) {
-			modbuf = "Thayer";
-			modbuf_viewer = "Thayer";
-		} else {
-			modbuf_viewer = settings.lex_greek_viewer;
-			modbuf = settings.lex_greek;
-		}
-	} else {
-		modbuf = settings.lex_hebrew;
-		modbuf_viewer = settings.lex_hebrew_viewer;
-	}
-
-	buf = g_strdup(newref);
-	if (clicked) {
-		if (settings.inDictpane)
-			main_display_dictionary(modbuf, buf);
-		if (settings.inViewer)
-			main_sidebar_display_dictlex(modbuf_viewer, buf);		
-	} else {
-		mybuf =
-		    main_get_rendered_text(modbuf, buf);
-		if (mybuf) {
-			//gui_display_hint_in_viewer(mybuf);
-			show_in_appbar(widgets.appbar, buf, modbuf);
-			//gui_display_in_hint_window(mybuf);
-			g_free(mybuf);
-		}
-	}
-	g_free(buf);
-}
-
-
-/******************************************************************************
- * Name
- *   deal_with_morphs
- *
- * Synopsis
- *   #include "gui/html.h"
- *
- *   void deal_with_morphs(const gchar *url)
- *
- * Description
- *   
- *
- * Return value
- *   void
- */
-
-static void deal_with_morphs(const gchar * url, gboolean clicked)
-{
-	gchar *modbuf = NULL;
-	gchar *mybuf = NULL;
-	gchar *buf = NULL;
-	gchar *myurl = NULL;
-	gchar *oldnew = NULL;
-	gboolean is_strongsmorph = FALSE;
-
-	oldnew = g_strdup(url);
-	myurl = g_strdup(url);
-	buf = g_strdup(myurl);
-
-	mybuf = strstr(myurl, "class=");
-	if (mybuf) {
-		modbuf = strchr(mybuf, '=');
-		++modbuf;
-		if (modbuf[0] == 'x' && modbuf[1] == '-')
-			modbuf += 2;
-		if (!strncmp(modbuf, "Robinson", 7)) {
-			if(main_is_module("Robinson"))
-				modbuf = "Robinson";
-			else
-				return;
-		} else if (!strncmp(modbuf, "none", 4)) {
-			if(main_is_module("Packard"))
-				modbuf = "Packard";
-			else			
-				return;
-		} else
-		    if (!strncmp
-			(modbuf, "StrongsMorph", 11)) {
-			is_strongsmorph = TRUE;
-			if (strstr(oldnew, "value=TH"))
-				modbuf =
-				    settings.lex_hebrew;
-			else
-				modbuf =
-				    settings.lex_greek;
-		}
-	} else
-		modbuf = "Robinson";
-
-	mybuf = NULL;
-	mybuf = strstr(buf, "value=");
-	if (mybuf) {
-		mybuf = strchr(mybuf, '=');
-		++mybuf;
-	}
-	if (is_strongsmorph) {
-		++mybuf;
-		++mybuf;
-	}
-	buf = g_strdup(mybuf);
-	mybuf = NULL;
-	if (clicked) {		
-		if (settings.inDictpane)
-			main_display_dictionary(modbuf, buf);
-		if (settings.inViewer)
-			main_sidebar_display_dictlex(modbuf, buf);
-	} else {
-		mybuf =
-		    main_get_rendered_text(modbuf, buf);
-		if (mybuf) {
-			//gui_display_in_hint_window(mybuf);
-			show_in_appbar(widgets.appbar, buf, modbuf);
-			//gui_display_hint_in_viewer(mybuf);
-			g_free(mybuf);
-		}
-	}
-	show_in_appbar(widgets.appbar, buf, modbuf);
-	g_free(buf);
-	g_free(myurl);
-	g_free(oldnew);	
-}
-
 
 /******************************************************************************
  * Name
@@ -441,7 +115,7 @@ static void deal_with_morphs(const gchar * url, gboolean clicked)
  *
  *   void gui_url(GtkHTML * html, const gchar * url, gpointer data)
  *
- * Description
+ * Descrg_warningiption
  *   called when mouse moves over an url (link)
  *
  * Return value
@@ -451,39 +125,29 @@ static void deal_with_morphs(const gchar * url, gboolean clicked)
 void gui_url(GtkHTML * html, const gchar * url, gpointer data)
 {
 	gchar buf[500];
-	/*static guint delay = 500000;	
-			
-	while(delay != 0) {
-			--delay;
-		if (url == NULL)
-			return;
-	} 
-	delay = 500000; 
-*/
-	if (url == NULL) { /* moved out of url - clear appbar */
+	extern gboolean shift_key_presed;
+	
+	if(shift_key_presed)
+		return;
+	
+	if (url == NULL) { /* moved out of url - clear appbar - info viewer*/
 		gnome_appbar_set_status(GNOME_APPBAR(widgets.appbar), "");
 		in_url = FALSE;
+		if(GPOINTER_TO_INT(data) == TEXT_TYPE)
+			main_clear_viewer();
+		/*
 		if (hint.in_popup) {
 			gtk_widget_destroy(hint.hint_window);
 			hint.in_popup = FALSE;
 		}
+		*/
 	} else {
 		in_url = TRUE;	/* we need this for html_button_released */
-		//g_print("url = %s\n",url);
 		if(main_url_handler(url, FALSE))
 			return;
 		
 		if (*url == 'I') {
 			return;
-		} else if (!strncmp(url, "noteID=", 7)) { /* footnote */
-			deal_with_notes(url, FALSE);
-			return;
-		} else if (!strncmp(url, "type=morph", 10)) {/* morph tag */
-			deal_with_morphs(url, FALSE);
-			return;
-		} else if (!strncmp(url, "type=Strongs", 10)) {/* strongs */
-			deal_with_storngs(url, FALSE);			
-			return;
 		} else if (*url == 'U') {
 			++url;
 			sprintf(buf, "%s %s", _("Unlock "), url);
@@ -492,6 +156,10 @@ void gui_url(GtkHTML * html, const gchar * url, gpointer data)
 			
 		gnome_appbar_set_status(GNOME_APPBAR(widgets.appbar),
 					buf);
+
+#ifdef DEBUG	
+	g_warning("link not handled");
+#endif		
 	}
 }
 
@@ -524,19 +192,12 @@ void gui_link_clicked(GtkHTML * html, const gchar * url, gpointer data)
 	if (*url == '@') {
 		++url;
 		main_swap_parallel_with_main((gchar *) url);
-	} else if (!strncmp(url, "noteID=", 7)) {
-		deal_with_notes(url, TRUE);
 		return;
-	} else if (!strncmp(url, "version=", 7)||!strncmp(url, "passage=", 7)) {
-		deal_with_refs(url);/* thml verse reference *//* for old notes */
-		return;
-	} else if (!strncmp(url, "type=morph", 10)) {/* thml and osis morph tag */
-		deal_with_morphs(url, TRUE);
-		return;
-	} else if (!strncmp(url, "type=Strongs", 12)) {/* gbf thml and osis strongs */		
-		deal_with_storngs(url, TRUE);
-		return;
-	} 
+	}
+	
+//#ifdef DEBUG	
+//	g_warning("link not handled");
+//#endif
 }
 
 
@@ -779,6 +440,46 @@ void gui_display_html(GtkWidget * html, const gchar * txt, gint lentxt)
 }
 
 
+
+
+
+struct _info {
+	GnomeFont *local_font;
+	gint page_num, pages;
+	gchar *header_title;
+	gchar *footer_title;
+	gboolean header_date;
+	gboolean header_page_num;
+	gboolean footer_date;
+	gboolean footer_page_num;
+};
+
+static void print_header(GtkHTML * html,
+			 GnomePrintContext * print_context, gdouble x,
+			 gdouble y, gdouble width, gdouble height,
+			 gpointer user_data)
+{
+/*	struct _info *info = (struct  _info*) user_data;
+	
+	if (info->local_font) {
+		gnome_print_line_stroked(print_context, x, y, width, y);
+		
+		gnome_print_gsave(print_context);
+		gnome_print_newpath(print_context);
+		gnome_print_setrgbcolor(print_context, .0, .0, .0);		
+		gnome_print_moveto(print_context, x,
+				   y -
+				   gnome_font_get_ascender(info->local_font));
+		gnome_print_setfont(print_context, info->local_font);
+		gnome_print_show(print_context, info->header_title);
+		gnome_print_grestore(print_context);
+		
+	
+		info->page_num++;
+	}*/
+}
+
+
 /******************************************************************************
  * Name
  *   print_footer
@@ -796,56 +497,79 @@ void gui_display_html(GtkWidget * html, const gchar * txt, gint lentxt)
  * Return value
  *   void
  */
-
-struct footer_info {
-	GnomeFont *local_font;
-	gint page_num, pages;
-};
-
 static void print_footer(GtkHTML * html,
 			 GnomePrintContext * print_context, gdouble x,
 			 gdouble y, gdouble width, gdouble height,
 			 gpointer user_data)
 {
-	struct footer_info *info = (struct footer_info *) user_data;
+	gdouble h = height - 10.0;
+	struct _info *info = (struct _info *) user_data;
 
 	if (info->local_font) {
-		char *text =
-		    g_strdup_printf(_("Page %d of %d"), info->page_num,
-				    info->pages);
-		gdouble tw = strlen(text) * 8;
-
+		//gnome_print_setfont(print_context, info->local_font);
+		//gnome_print_line_stroked(print_context, x, y, width, y);
 		gnome_print_gsave(print_context);
 		gnome_print_newpath(print_context);
-		gnome_print_setrgbcolor(print_context, .0, .0, .0);
-		gnome_print_moveto(print_context, x + width - tw,
+		gnome_print_setrgbcolor(print_context, .0, .0, .0);		
+		/*gnome_print_moveto(print_context, x,
 				   y -
-				   gnome_font_get_ascender(info->
-							   local_font));
+				   gnome_font_get_ascender(info->local_font));
 		gnome_print_setfont(print_context, info->local_font);
-		gnome_print_show(print_context, text);
+		gnome_print_show(print_context, info->footer_title);*/
+		
+		
+		if(info->footer_page_num) {
+			char *text =
+			    g_strdup_printf(_("Page %d of %d"), info->page_num,
+					    info->pages);
+			gdouble tw = strlen(text) * 8;
+			
+			gnome_print_moveto(print_context, x + width - tw,
+					   y -
+					   gnome_font_get_ascender(info->
+								   local_font));
+			gnome_print_setfont(print_context, info->local_font);
+			gnome_print_show(print_context, (const guchar *)text);
+			g_free(text);
+		}
+		if(info->footer_date) {
+			char *text =
+			    g_strdup_printf("%s", "April 08, 2005");
+			gdouble tw = strlen(text) * 6;
+			
+			gnome_print_moveto(print_context, x + width - tw,
+					   y -
+					   gnome_font_get_ascender(info->
+								   local_font));
+			gnome_print_setfont(print_context, info->local_font);
+			gnome_print_show(print_context, (const guchar *)text);	
+			g_free(text);
+		}
 		gnome_print_grestore(print_context);
-
-		g_free(text);
 		info->page_num++;
 	}
+
 }
 
-static void footer_info_free(struct footer_info *info)
+static void info_free(struct _info *info)
 {
 	if (info->local_font)
 		gnome_font_unref(info->local_font);
+	if(info->header_title)
+		g_free(info->header_title);
+	if(info->footer_title)
+		g_free(info->footer_title);
 	g_free(info);
 }
 
-static struct footer_info *footer_info_new(GtkHTML * html,
+static struct _info *info_new(GtkHTML * html,
 					   GnomePrintContext * pc,
 					   gdouble * line)
 {
-	struct footer_info *info;
+	struct _info *info;
 
-	info = g_new(struct footer_info, 1);
-	info->local_font = gnome_font_find_closest("Luxi Sans", 10.0);
+	info = g_new(struct _info, 1);
+	info->local_font = gnome_font_find_closest((const guchar *)"Sans Regular", 10.0);
 
 	if (info->local_font)
 		*line =
@@ -854,8 +578,13 @@ static struct footer_info *footer_info_new(GtkHTML * html,
 
 	info->page_num = 1;
 	info->pages =
-	    gtk_html_print_get_pages_num(html, pc, 0.0, *line);
-
+	    gtk_html_print_get_pages_num(html, pc, *line, *line);
+	info->header_title = g_strdup("");
+	info->footer_title = g_strdup("");
+	info->header_date = FALSE;
+	info->header_page_num = TRUE;
+	info->footer_date = FALSE;
+	info->footer_page_num = TRUE;
 	return info;
 }
 
@@ -885,12 +614,12 @@ void gui_html_print(GtkWidget * htmlwidget, gboolean preview)
 	GnomePrintConfig *config = NULL;
 	GtkDialog *dialog;
 	gdouble line = 0.0;
-	struct footer_info *info;
+	struct _info *info;
 
 	if (!preview) {
 		dialog =
 		    (GtkDialog *) gnome_print_dialog_new(NULL,
-						 _("Print"),
+						(const guchar *) _("Print"),
 						 GNOME_PRINT_DIALOG_COPIES);
 		gtk_dialog_set_default_response(dialog,
 					GNOME_PRINT_DIALOG_RESPONSE_PRINT);
@@ -910,7 +639,7 @@ void gui_html_print(GtkWidget * htmlwidget, gboolean preview)
 			return;
 		}
 
-		config =
+		//config = gnome_print_config_default();
 		    gnome_print_dialog_get_config((GnomePrintDialog *)
 						  dialog);
 		gtk_widget_destroy((GtkWidget *) dialog);
@@ -928,11 +657,11 @@ void gui_html_print(GtkWidget * htmlwidget, gboolean preview)
 
 	gtk_html_print_set_master(html, print_master);
 
-	info = footer_info_new(html, print_context, &line);
-	gtk_html_print_with_header_footer(html, print_context, 0.0,
-					  line, NULL, print_footer,
+	info = info_new(html, print_context, &line);
+	gtk_html_print_with_header_footer(html, print_context, line,
+					  line, print_header, print_footer,
 					  info);
-	footer_info_free(info);
+	info_free(info);
 
 	gnome_print_job_close(print_master);
 
@@ -940,7 +669,7 @@ void gui_html_print(GtkWidget * htmlwidget, gboolean preview)
 		GtkWidget *pw;
 
 		pw = gnome_print_job_preview_new(print_master,
-						 _("Print Preview"));
+						(const guchar *) _("Print Preview"));
 		gtk_widget_show(pw);
 	} else {
 		int result = gnome_print_job_print(print_master);
