@@ -24,13 +24,12 @@
 #endif
 
 #include <gnome.h>
-#include <gal/shortcut-bar/e-shortcut-bar.h>
+//#include <gal/shortcut-bar/e-shortcut-bar.h>
 
 #include "gui/about_gnomesword.h"
 #include "gui/about_sword.h"
 #include "gui/gnomesword.h"
 #include "gui/hints.h"
-#include "gui/history.h"
 #include "gui/html.h"
 #include "gui/main_window.h"
 #include "gui/main_menu.h"
@@ -38,14 +37,14 @@
 #include "gui/sidebar.h"
 #include "gui/sidebar_dialog.h"
 #include "gui/search_dialog.h"
-#include "gui/studypad_dialog.h"
+#include "gui/studypad.h"
 #include "gui/utilities.h"
 #include "gui/widgets.h"
 
-#include "main/bibletext.h"
 #include "main/lists.h"
 #include "main/sword.h"
 #include "main/search_dialog.h"
+#include "main/tab_history.h"
 
 
 
@@ -93,7 +92,7 @@ void on_help_contents_activate(GtkMenuItem * menuitem,
 {	
 	GError *error = NULL;
 	
-	if (gnome_help_display ((const gchar*)"gnomesword.xml", 
+	if (gnome_help_display ((const gchar*)"gnomesword-manual.xml", 
 			NULL, &error) == FALSE) {
 		g_warning(error->message);
 		g_error_free (error);        
@@ -121,7 +120,7 @@ void on_help_contents_activate(GtkMenuItem * menuitem,
 void on_mnuHistoryitem1_activate(GtkMenuItem * menuitem,
 				 gpointer user_data)
 {
-	gui_change_verse_history(GPOINTER_TO_INT(user_data));
+	main_change_verse_tab_history(GPOINTER_TO_INT(user_data));
 }
 
 /******************************************************************************
@@ -170,7 +169,7 @@ void on_about_the_sword_project1_activate(GtkMenuItem * menuitem,
 void on_daily_devotion1_activate(GtkMenuItem * menuitem,
 				 gpointer user_data)
 {
-	gui_display_devotional_in_sidebar();
+	main_display_devotional();
 }
 
 /******************************************************************************
@@ -300,7 +299,7 @@ void on_exit_activate(GtkMenuItem * menuitem, gpointer user_data)
 
 void on_clear1_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
-	gui_clear_history(widgets.app, GTK_WIDGET(widgets.shortcutbar));
+	main_clear_tab_history();//gui_clear_history(widgets.app);
 }
 
 /******************************************************************************
@@ -348,10 +347,10 @@ void on_about_gnomesword1_activate(GtkMenuItem * menuitem,
 
 static void view_hints(GtkMenuItem * menuitem, gpointer user_data)
 {
-	hint.use_hints = GTK_CHECK_MENU_ITEM(menuitem)->active;
+/*	hint.use_hints = GTK_CHECK_MENU_ITEM(menuitem)->active;
 	
 	if(!hint.use_hints)
-		gui_destroy_hint_window();
+		gui_destroy_hint_window();*/
 	/*
 	if(hint.use_hints)
 		gui_open_hint_viewer();*/
@@ -474,7 +473,7 @@ static void open_studypad(GtkMenuItem * menuitem, gpointer user_data)
 				 window);
 	} else {
 		settings.studypad_dialog_exist =
-			  gui_open_studypad_dialog(settings.studypadfilename);
+			  gui_open_studypad(settings.studypadfilename);
 	}
 }
 
@@ -568,9 +567,9 @@ static GnomeUIInfo view1_menu_uiinfo[] = {
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, (GdkModifierType) 0, NULL},
 	{
-	 GNOME_APP_UI_TOGGLEITEM, N_("Lower Workbook"),
+	 GNOME_APP_UI_TOGGLEITEM, N_("Dictionary/Lexicon"),
 	 N_
-	 ("Show or hide lower workbook - dictionaries and other books"),
+	 ("Show or hide - dictionaries and lexicons"),
 	 (gpointer) view_lower_workbook, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, (GdkModifierType) 0, NULL},
