@@ -75,6 +75,8 @@ static GtkWidget *treeview;
 static GtkWidget *treeview1;
 static GtkWidget *treeview2;
 static GtkWidget *notebook1;
+static GtkWidget *button_close;
+static GtkWidget *button_cancel;
 static GtkWidget *button5;
 static GtkWidget *button6;
 static GtkWidget *button7;
@@ -108,6 +110,7 @@ static gint response;
 static GdkPixbuf *INSTALLED;
 static GdkPixbuf *LOCKED;
 static GdkPixbuf *BLANK;
+static gchar *current_mod;
 
 
 
@@ -133,7 +136,7 @@ static void create_pixbufs(void)
 					   GTK_STOCK_APPLY,
 					   GTK_ICON_SIZE_MENU, NULL);
 	LOCKED = gdk_pixbuf_new_from_file(PACKAGE_PIXMAPS_DIR
-					"/epiphany-secure.png",NULL);
+					  "/epiphany-secure.png", NULL);
 	BLANK = gtk_widget_render_icon(widgets.app,
 				       "gnome-stock-blank",
 				       GTK_ICON_SIZE_MENU, NULL);
@@ -189,7 +192,6 @@ static void remove_install_modules(GList * modules, gboolean install)
 	GString *mods = g_string_new(NULL);
 	GString *dialog_text = g_string_new(NULL);
 
-
 	tmp = modules;
 	while (tmp) {
 		buf = (gchar *) tmp->data;
@@ -228,7 +230,8 @@ static void remove_install_modules(GList * modules, gboolean install)
 	g_free(yes_no_dialog);
 	g_string_free(dialog_text, TRUE);
 	gtk_widget_queue_draw(dialog);
-
+	gtk_widget_hide(button_close);
+	gtk_widget_show(button_cancel);
 	while (gtk_events_pending()) {
 		gtk_main_iteration();
 	}
@@ -236,6 +239,7 @@ static void remove_install_modules(GList * modules, gboolean install)
 	tmp = modules;
 	while (tmp) {
 		buf = (gchar *) tmp->data;
+		current_mod = buf;
 		if (install) {
 			g_string_printf(mods, "%s: %s",
 					_("Installing: "), buf);
@@ -250,7 +254,8 @@ static void remove_install_modules(GList * modules, gboolean install)
 						  mods->str);
 			g_print("uninstalling %s from %s\n", buf,
 				destination);
-			if (mod_mgr_uninstall(destination, buf) == -1) {
+			failed = mod_mgr_uninstall(destination, buf);
+			if (failed == -1) {
 				//mod_mgr_shut_down();
 				if (destination) {
 					new_dest = NULL;
@@ -291,7 +296,7 @@ static void remove_install_modules(GList * modules, gboolean install)
 		else
 			g_string_printf(mods, "%s", _("Remove failed"));
 	} else {
-		g_string_printf(mods, "%s", _("Finished"));
+		g_string_printf(mods, "%s", _("Finished"));		
 	}
 	if (install) {
 		gtk_progress_bar_set_text(GTK_PROGRESS_BAR(progressbar),
@@ -305,6 +310,8 @@ static void remove_install_modules(GList * modules, gboolean install)
 					      (progressbar1), 0);
 	}
 	g_string_free(mods, TRUE);
+	gtk_widget_hide(button_cancel);
+	gtk_widget_show(button_close);
 
 }
 
@@ -480,6 +487,7 @@ static void add_module_to_language_folder(GtkTreeModel * model,
 	}
 }
 
+
 /******************************************************************************
  * Name
  *   add_language_folder
@@ -489,7 +497,7 @@ static void add_module_to_language_folder(GtkTreeModel * model,
  *
  *   void add_language_folder(GtkTreeModel * model, GtkTreeIter iter,
  *			 gchar * language)
- *
+ *   
  * Description
  *   
  *
@@ -506,7 +514,7 @@ static void add_language_folder(GtkTreeModel * model, GtkTreeIter iter,
 	gchar *buf;
 	gsize bytes_read;
 	gsize bytes_written;
-	GError **error;
+	GError *error = NULL;
 	gboolean valid;
 
 	if ((!g_ascii_isalnum(language[0])) || (language == NULL))
@@ -516,24 +524,51 @@ static void add_language_folder(GtkTreeModel * model, GtkTreeIter iter,
 	while (valid) {
 		/* Walk through the list, reading each row */
 		gchar *str_data;
-
-		gtk_tree_model_get(model, &iter_iter, COLUMN_NAME,
-				   &str_data, -1);
-		if (!strcmp(language, str_data)) {
+		buf = g_convert(language, 
+				-1, 
+				UTF_8, 
+				OLD_CODESET, 
+				&bytes_read,
+				&bytes_written, 
+				&error);
+		if(buf == NULL) {
+			g_print ("error: %s\n", error->message);
+			g_error_free (error);
+			return;
+		}
+		
+		gtk_tree_model_get(model, 
+				&iter_iter, 
+				COLUMN_NAME, 
+				&str_data, 
+				-1);
+		
+		if(!g_utf8_collate(g_utf8_casefold(buf,-1),
+				      g_utf8_casefold(str_data,-1))) {
+		/*if(!strcmp(buf,str_data)) {*/
 			g_free(str_data);
+			g_free(buf);
 			return;
 		}
 		g_free(str_data);
+		g_free(buf);
 		valid = gtk_tree_model_iter_next(model, &iter_iter);
 	}
-	gtk_tree_store_append(GTK_TREE_STORE(model), &child_iter,
-			      &iter);
-	buf =
-	    g_convert(language, -1, UTF_8, OLD_CODESET, &bytes_read,
-		      &bytes_written, error);
-	gtk_tree_store_set(GTK_TREE_STORE(model), &child_iter,
-			   COLUMN_VISIBLE, FALSE, COLUMN_NAME,
-			   (gchar *) buf, -1);
+	gtk_tree_store_append(GTK_TREE_STORE(model), &child_iter, &iter);
+	buf = g_convert(language, 
+			-1, 
+			UTF_8, 
+			OLD_CODESET, 
+			&bytes_read,
+			&bytes_written, 
+			&error);
+	gtk_tree_store_set(GTK_TREE_STORE(model), 
+			&child_iter,
+			COLUMN_VISIBLE, 
+			FALSE, 
+			COLUMN_NAME,
+			(gchar *) buf, 
+			-1);
 	g_free(buf);
 
 }
@@ -596,7 +631,7 @@ static void load_module_tree(GtkTreeView * treeview, gboolean install)
 			tmp = mod_mgr_remote_list_modules(source);
 	} else {
 
-		tmp = mod_mgr_list_local_modules(get_path_to_mods());
+		tmp = mod_mgr_list_local_modules(main_get_path_to_mods());
 	}
 
 	store = GTK_TREE_STORE(gtk_tree_view_get_model(treeview));
@@ -754,10 +789,10 @@ static void response_refresh(void)
 
 static void response_close(void)
 {
-	gint test;
-	GS_DIALOG *yes_no_dialog;
+	//gint test;
+	//GS_DIALOG *yes_no_dialog;
 	GString *str = g_string_new(NULL);
-	if (have_changes) {
+	/*if (have_changes) {
 		yes_no_dialog = gui_new_dialog();
 		yes_no_dialog->stock_icon = GTK_STOCK_DIALOG_QUESTION;
 		g_string_printf(str,
@@ -777,12 +812,12 @@ static void response_close(void)
 			gnome_execute_shell(NULL, "gnomesword2");
 			gtk_widget_destroy(widgets.app);
 		}
-	}
+	}*/
 	gtk_widget_destroy(GTK_WIDGET(dialog));
-	mod_mgr_shut_down();
 	g_string_printf(str, "%s/dirlist", settings.homedir);
 	if (mod_mgr_check_for_file(str->str))
 		g_warning(str->str);
+	g_string_free(str,TRUE);
 }
 
 /******************************************************************************
@@ -811,6 +846,12 @@ static void on_dialog_response(GtkDialog * dialog, gint response_id,
 	GString *str = g_string_new(NULL);
 
 	switch (response_id) {
+	case GTK_RESPONSE_CANCEL:
+		mod_mgr_terminate();
+		while (gtk_events_pending()) {
+			gtk_main_iteration();
+		}
+		break;
 	case GTK_RESPONSE_REFRESH:
 		response_refresh();
 		break;
@@ -856,8 +897,8 @@ static void on_dialog_response(GtkDialog * dialog, gint response_id,
  *   void
  */
 
-static void fixed_toggled(GtkCellRendererToggle * cell, gchar * path_str,
-	      gpointer data)
+static void fixed_toggled(GtkCellRendererToggle * cell,
+			  gchar * path_str, gpointer data)
 {
 	GtkTreeModel *model = (GtkTreeModel *) data;
 	GtkTreeIter iter;
@@ -915,7 +956,7 @@ static void add_columns(GtkTreeView * treeview, gboolean remove)
 	gtk_tree_view_append_column(treeview, column);
 
 	column = gtk_tree_view_column_new();
-	image = gtk_image_new_from_stock(GTK_STOCK_APPLY,	
+	image = gtk_image_new_from_stock(GTK_STOCK_APPLY,
 					 GTK_ICON_SIZE_MENU);
 	gtk_widget_show(image);
 	renderer = GTK_CELL_RENDERER(gtk_cell_renderer_pixbuf_new());
@@ -1078,7 +1119,8 @@ static void add_columns_to_remote_treeview(GtkTreeView * treeview)
 	column =
 	    gtk_tree_view_column_new_with_attributes(_("Caption"),
 						     renderer, "text",
-						     COLUMN_CAPTION, NULL);
+						     COLUMN_CAPTION,
+						     NULL);
 	gtk_tree_view_column_set_sort_column_id(column, COLUMN_NAME);
 	gtk_tree_view_append_column(treeview, column);
 
@@ -1086,7 +1128,8 @@ static void add_columns_to_remote_treeview(GtkTreeView * treeview)
 	column =
 	    gtk_tree_view_column_new_with_attributes(_("Source"),
 						     renderer, "text",
-						     COLUMN_SOURCE, NULL);
+						     COLUMN_SOURCE,
+						     NULL);
 	gtk_tree_view_column_set_sort_column_id(column, COLUMN_NAME);
 	gtk_tree_view_append_column(treeview, column);
 
@@ -1094,7 +1137,8 @@ static void add_columns_to_remote_treeview(GtkTreeView * treeview)
 	column =
 	    gtk_tree_view_column_new_with_attributes(_("Directory"),
 						     renderer, "text",
-						     COLUMN_DIRECTORY, NULL);
+						     COLUMN_DIRECTORY,
+						     NULL);
 	gtk_tree_view_column_set_sort_column_id(column, COLUMN_NAME);
 	gtk_tree_view_append_column(treeview, column);
 
@@ -1169,15 +1213,15 @@ static GtkTreeModel *create_remote_source_treeview_model(void)
 	GtkTreeIter iter;
 
 	/* create list store */
-	store = gtk_list_store_new(NUM_REMOTE_COLUMNS, 
+	store = gtk_list_store_new(NUM_REMOTE_COLUMNS,
 				   G_TYPE_STRING,
 				   G_TYPE_STRING,
-				   G_TYPE_STRING,
-				   G_TYPE_STRING);
+				   G_TYPE_STRING, G_TYPE_STRING);
 
 	return GTK_TREE_MODEL(store);
-	
+
 }
+
 /******************************************************************************
  * Name
  *   button_press_event
@@ -1253,6 +1297,7 @@ static gboolean button_press_event(GtkWidget * widget,
 static void load_source_treeviews(void)
 {
 	GList *tmp = NULL;
+	GList *tmp2 = NULL;
 	GList *combo1_items = NULL;
 	GtkTreeIter iter;
 	MOD_MGR_SOURCE *mms;
@@ -1260,30 +1305,43 @@ static void load_source_treeviews(void)
 	    gtk_tree_view_get_model(GTK_TREE_VIEW(treeview_remote));
 	GtkTreeModel *local_model =
 	    gtk_tree_view_get_model(GTK_TREE_VIEW(treeview_local));
-	
+
 	/* remote */
-	gtk_list_store_clear (GTK_LIST_STORE(remote_model));
+	gtk_list_store_clear(GTK_LIST_STORE(remote_model));
 	tmp = mod_mgr_list_remote_sources();
-	while(tmp) {		
+	tmp2 = g_list_first(tmp);
+	while (tmp) {
 		mms = (MOD_MGR_SOURCE *) tmp->data;
-		gtk_list_store_append(GTK_LIST_STORE(remote_model), &iter);
-		gtk_list_store_set(GTK_LIST_STORE(remote_model), &iter, 
-					COLUMN_TYPE, mms->type, 
-					COLUMN_CAPTION, mms->caption, 
-					COLUMN_SOURCE, mms->source, 
-					COLUMN_DIRECTORY, mms->directory, 
-					-1);
+		gtk_list_store_append(GTK_LIST_STORE(remote_model),
+				      &iter);
+		gtk_list_store_set(GTK_LIST_STORE(remote_model), &iter,
+				   COLUMN_TYPE, mms->type,
+				   COLUMN_CAPTION, mms->caption,
+				   COLUMN_SOURCE, mms->source,
+				   COLUMN_DIRECTORY, mms->directory,
+				   -1);
 		combo1_items =
 		    g_list_append(combo1_items, (gchar *) mms->caption);
 		tmp = g_list_next(tmp);
 	}
-	gtk_combo_set_popdown_strings(GTK_COMBO(combo1), combo1_items);	
+	gtk_combo_set_popdown_strings(GTK_COMBO(combo1), combo1_items);
 	g_list_free(combo1_items);
+	while (tmp2) {
+		mms = (MOD_MGR_SOURCE *) tmp2->data;
+		g_free((gchar*)mms->type);
+		g_free((gchar*)mms->caption);
+		g_free((gchar*)mms->source);
+		g_free((gchar*)mms->directory);
+		g_free(mms);
+		tmp2 = g_list_next(tmp2); 
+	}
 	g_list_free(tmp);
 	tmp = NULL;
-	
+	g_list_free(tmp2);
+	tmp2 = NULL;
+
 	/* local */
-	gtk_list_store_clear (GTK_LIST_STORE(local_model));
+	gtk_list_store_clear(GTK_LIST_STORE(local_model));
 	tmp = mod_mgr_list_local_sources();
 	if (tmp) {
 		mms = (MOD_MGR_SOURCE *) tmp->data;
@@ -1291,23 +1349,24 @@ static void load_source_treeviews(void)
 					      fileentry1,
 					      mms->directory);
 	}
-	while(tmp) {		
+	while (tmp) {
 		mms = (MOD_MGR_SOURCE *) tmp->data;
-		gtk_list_store_append(GTK_LIST_STORE(local_model), &iter);
-		gtk_list_store_set(GTK_LIST_STORE(local_model), &iter, 
-					COLUMN_TYPE, mms->type, 
-					COLUMN_CAPTION, mms->caption, 
-					COLUMN_SOURCE, mms->source, 
-					COLUMN_DIRECTORY, mms->directory, 
-					-1);
+		gtk_list_store_append(GTK_LIST_STORE(local_model),
+				      &iter);
+		gtk_list_store_set(GTK_LIST_STORE(local_model), &iter,
+				   COLUMN_TYPE, mms->type,
+				   COLUMN_CAPTION, mms->caption,
+				   COLUMN_SOURCE, mms->source,
+				   COLUMN_DIRECTORY, mms->directory,
+				   -1);
 		gnome_entry_append_history((GnomeEntry *) combo_entry1,
 					   TRUE, mms->directory);
 		g_free(mms);
 		tmp = g_list_next(tmp);
 	}
 	g_list_free(tmp);
-	
-	
+
+
 }
 
 /******************************************************************************
@@ -1441,7 +1500,7 @@ void on_radiobutton2_toggled(GtkToggleButton * togglebutton,
  */
 
 void save_sources(void)
-{	
+{
 	gchar *type = NULL;
 	gchar *caption = NULL;
 	gchar *source = NULL;
@@ -1452,53 +1511,43 @@ void save_sources(void)
 	    gtk_tree_view_get_model(GTK_TREE_VIEW(treeview_remote));
 	GtkTreeModel *local_model =
 	    gtk_tree_view_get_model(GTK_TREE_VIEW(treeview_local));
-	
+
 	mod_mgr_clear_config();
-		
-	valid = gtk_tree_model_get_iter_first (remote_model, &iter);
-	while (valid)
-	{					
-		gtk_tree_model_get (remote_model, &iter, 
-				  COLUMN_TYPE, &type,
-				  COLUMN_CAPTION, &caption,
-				  COLUMN_SOURCE, &source,
-				  COLUMN_DIRECTORY, &directory,
-				  -1);
-		
+
+	valid = gtk_tree_model_get_iter_first(remote_model, &iter);
+	while (valid) {
+		gtk_tree_model_get(remote_model, &iter,
+				   COLUMN_TYPE, &type,
+				   COLUMN_CAPTION, &caption,
+				   COLUMN_SOURCE, &source,
+				   COLUMN_DIRECTORY, &directory, -1);
+
 		mod_mgr_add_source("FTPSource",
-				   type, 
-				   caption,
-				   source, 
-				   directory);		
-		g_free (type);		
-		g_free (caption);		
-		g_free (source);		
-		g_free (directory);
-		valid = gtk_tree_model_iter_next (remote_model, &iter);
+				   type, caption, source, directory);
+		g_free(type);
+		g_free(caption);
+		g_free(source);
+		g_free(directory);
+		valid = gtk_tree_model_iter_next(remote_model, &iter);
 	}
-	
-	valid = gtk_tree_model_get_iter_first (local_model, &iter);
-	while (valid)
-	{					
-		gtk_tree_model_get (local_model, &iter, 
-				  COLUMN_TYPE, &type,
-				  COLUMN_CAPTION, &caption,
-				  COLUMN_SOURCE, &source,
-				  COLUMN_DIRECTORY, &directory,
-				  -1);
-		
+
+	valid = gtk_tree_model_get_iter_first(local_model, &iter);
+	while (valid) {
+		gtk_tree_model_get(local_model, &iter,
+				   COLUMN_TYPE, &type,
+				   COLUMN_CAPTION, &caption,
+				   COLUMN_SOURCE, &source,
+				   COLUMN_DIRECTORY, &directory, -1);
+
 		mod_mgr_add_source("DIRSource",
-				   type, 
-				   caption,
-				   source, 
-				   directory);		
-		g_free (type);		
-		g_free (caption);		
-		g_free (source);		
-		g_free (directory);
-		valid = gtk_tree_model_iter_next (local_model, &iter);
+				   type, caption, source, directory);
+		g_free(type);
+		g_free(caption);
+		g_free(source);
+		g_free(directory);
+		valid = gtk_tree_model_iter_next(local_model, &iter);
 	}
-	
+
 	load_source_treeviews();
 }
 
@@ -1520,33 +1569,34 @@ void save_sources(void)
  *   void
  */
 
-void on_fileselection_local_source_response (GtkDialog * dialog,
-                                gint response_id, GtkFileSelection * filesel)
+void on_fileselection_local_source_response(GtkDialog * dialog,
+					    gint response_id,
+					    GtkFileSelection * filesel)
 {
 	GtkTreeIter iter;
 	GtkTreeModel *model =
 	    gtk_tree_view_get_model(GTK_TREE_VIEW(treeview_local));
-	
-	switch(response_id) {
-		case GTK_RESPONSE_OK:
-			gtk_list_store_append(GTK_LIST_STORE(model), &iter);
-			gtk_list_store_set(GTK_LIST_STORE(model), &iter, 
-				COLUMN_TYPE, "DIR", 
-				COLUMN_CAPTION, 
-				gtk_file_selection_get_filename (filesel), 
-				COLUMN_SOURCE, "[local]", 
-				COLUMN_DIRECTORY, 
-				gtk_file_selection_get_filename (filesel), 
-				-1);
-			save_sources();
-			g_warning(gtk_file_selection_get_filename (filesel));
-			
+
+	switch (response_id) {
+	case GTK_RESPONSE_OK:
+		gtk_list_store_append(GTK_LIST_STORE(model), &iter);
+		gtk_list_store_set(GTK_LIST_STORE(model), &iter,
+				   COLUMN_TYPE, "DIR",
+				   COLUMN_CAPTION,
+				   gtk_file_selection_get_filename
+				   (filesel), COLUMN_SOURCE, "[local]",
+				   COLUMN_DIRECTORY,
+				   gtk_file_selection_get_filename
+				   (filesel), -1);
+		save_sources();
+		g_warning(gtk_file_selection_get_filename(filesel));
+
 		break;
-		case GTK_RESPONSE_CANCEL:
-			
-			
+	case GTK_RESPONSE_CANCEL:
+
+
 		break;
-		
+
 	}
 	gtk_widget_destroy(GTK_WIDGET(dialog));
 }
@@ -1568,33 +1618,45 @@ void on_fileselection_local_source_response (GtkDialog * dialog,
  *   GtkWidget*
  */
 
-GtkWidget* create_fileselection_local_source (void)
+GtkWidget *create_fileselection_local_source(void)
 {
-  GtkWidget *fileselection_local_source;
-  GtkWidget *ok_button1;
-  GtkWidget *cancel_button1;
+	GtkWidget *fileselection_local_source;
+	GtkWidget *ok_button1;
+	GtkWidget *cancel_button1;
 
-  fileselection_local_source = gtk_file_selection_new (_("Select Local Source"));
-  gtk_container_set_border_width (GTK_CONTAINER (fileselection_local_source), 10);
-  gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (fileselection_local_source));
-  
-  gtk_widget_set_sensitive(
-	GTK_FILE_SELECTION(fileselection_local_source)->file_list,FALSE);
-  gtk_widget_hide(GTK_FILE_SELECTION(fileselection_local_source)->selection_entry);
-	
-  ok_button1 = GTK_FILE_SELECTION (fileselection_local_source)->ok_button;	
-  gtk_widget_show (ok_button1);
-  GTK_WIDGET_SET_FLAGS (ok_button1, GTK_CAN_DEFAULT);
+	fileselection_local_source =
+	    gtk_file_selection_new(_("Select Local Source"));
+	gtk_container_set_border_width(GTK_CONTAINER
+				       (fileselection_local_source),
+				       10);
+	gtk_file_selection_hide_fileop_buttons(GTK_FILE_SELECTION
+					       (fileselection_local_source));
 
-  cancel_button1 = GTK_FILE_SELECTION (fileselection_local_source)->cancel_button;
-  gtk_widget_show (cancel_button1);
-  GTK_WIDGET_SET_FLAGS (cancel_button1, GTK_CAN_DEFAULT);
+	gtk_widget_set_sensitive(GTK_FILE_SELECTION
+				 (fileselection_local_source)->
+				 file_list, FALSE);
+	gtk_widget_hide(GTK_FILE_SELECTION(fileselection_local_source)->
+			selection_entry);
 
-  	g_signal_connect ((gpointer) fileselection_local_source, "response",
-                    G_CALLBACK (on_fileselection_local_source_response),
-                    (GtkFileSelection *)fileselection_local_source);
+	ok_button1 =
+	    GTK_FILE_SELECTION(fileselection_local_source)->ok_button;
+	gtk_widget_show(ok_button1);
+	GTK_WIDGET_SET_FLAGS(ok_button1, GTK_CAN_DEFAULT);
 
-  return fileselection_local_source;
+	cancel_button1 =
+	    GTK_FILE_SELECTION(fileselection_local_source)->
+	    cancel_button;
+	gtk_widget_show(cancel_button1);
+	GTK_WIDGET_SET_FLAGS(cancel_button1, GTK_CAN_DEFAULT);
+
+	g_signal_connect((gpointer) fileselection_local_source,
+			 "response",
+			 G_CALLBACK
+			 (on_fileselection_local_source_response),
+			 (GtkFileSelection *)
+			 fileselection_local_source);
+
+	return fileselection_local_source;
 }
 
 
@@ -1616,7 +1678,7 @@ GtkWidget* create_fileselection_local_source (void)
 
 void on_button_add_local_clicked(GtkButton * button, gpointer user_data)
 {
-	GtkWidget *dlg = create_fileselection_local_source ();
+	GtkWidget *dlg = create_fileselection_local_source();
 	gtk_widget_show(dlg);
 }
 
@@ -1637,12 +1699,13 @@ void on_button_add_local_clicked(GtkButton * button, gpointer user_data)
  *   void
  */
 
-static void on_button_remove_local_clicked(GtkButton * button, gpointer user_data)
+static void on_button_remove_local_clicked(GtkButton * button,
+					   gpointer user_data)
 {
 	gint test;
 	GS_DIALOG *yes_no_dialog;
 	gchar *name_string;
-	GtkTreeSelection* selection;
+	GtkTreeSelection *selection;
 	GtkTreeIter selected;
 	GtkTreeIter iter;
 	gchar *caption = NULL;
@@ -1651,28 +1714,26 @@ static void on_button_remove_local_clicked(GtkButton * button, gpointer user_dat
 	gchar *directory = NULL;
 	GString *str = g_string_new(NULL);
 	GtkTreeModel *model;
-	
-	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview_local));
-	if(!gtk_tree_selection_get_selected(selection, &model, &selected)) 
+
+	selection =
+	    gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview_local));
+	if (!gtk_tree_selection_get_selected
+	    (selection, &model, &selected))
 		return;
 	gtk_tree_model_get(GTK_TREE_MODEL(model), &selected,
-				   COLUMN_TYPE, &type, 
-				   COLUMN_CAPTION, &caption, 
-				   COLUMN_SOURCE, &source, 
-				   COLUMN_DIRECTORY , &directory, 
-				   -1);
+			   COLUMN_TYPE, &type,
+			   COLUMN_CAPTION, &caption,
+			   COLUMN_SOURCE, &source,
+			   COLUMN_DIRECTORY, &directory, -1);
 	name_string = caption;
 
 	yes_no_dialog = gui_new_dialog();
 	yes_no_dialog->stock_icon = GTK_STOCK_DIALOG_WARNING;
-	yes_no_dialog->title = N_("Bookmark");	
+	yes_no_dialog->title = N_("Bookmark");
 	g_string_printf(str,
 			"<span weight=\"bold\">%s</span>\n\n%s|%s|%s|%s",
 			_("Remove the selected source"),
-			caption,
-			type,
-			source,
-			directory);
+			caption, type, source, directory);
 	yes_no_dialog->label_top = str->str;
 	yes_no_dialog->yes = TRUE;
 	yes_no_dialog->no = TRUE;
@@ -1687,8 +1748,8 @@ static void on_button_remove_local_clicked(GtkButton * button, gpointer user_dat
 	g_free(caption);
 	g_free(source);
 	g_free(directory);
-	g_string_free(str,TRUE);
-	
+	g_string_free(str, TRUE);
+
 }
 
 
@@ -1708,13 +1769,14 @@ static void on_button_remove_local_clicked(GtkButton * button, gpointer user_dat
  *   void
  */
 
-void on_button_add_remote_clicked(GtkButton * button, gpointer user_data)
+void on_button_add_remote_clicked(GtkButton * button,
+				  gpointer user_data)
 {
 	gint test;
 	GS_DIALOG *dialog;
 	GtkTreeIter iter;
 	GString *str = g_string_new(NULL);
-	
+
 	GtkTreeModel *model =
 	    gtk_tree_view_get_model(GTK_TREE_VIEW(treeview_remote));
 	g_string_printf(str,
@@ -1723,19 +1785,19 @@ void on_button_add_remote_clicked(GtkButton * button, gpointer user_data)
 	dialog = gui_new_dialog();
 	dialog->stock_icon = GTK_STOCK_DIALOG_INFO;
 	dialog->label_top = str->str;
-	dialog->label1 = N_("Caption:");	
+	dialog->label1 = N_("Caption:");
 	dialog->label2 = N_("Type:");
 	dialog->label3 = N_("URL:");
 	dialog->label4 = N_("Directory:");
-	dialog->text1 = g_strdup("Crosswire");	
-	dialog->text2 = g_strdup("FTP");		
-	dialog->text3 = g_strdup("ftp.crosswire.org");		
-	dialog->text4 = g_strdup("/pub/sword/raw");	
+	dialog->text1 = g_strdup("Crosswire");
+	dialog->text2 = g_strdup("FTP");
+	dialog->text3 = g_strdup("ftp.crosswire.org");
+	dialog->text4 = g_strdup("/pub/sword/raw");
 	dialog->cancel = TRUE;
 	dialog->ok = TRUE;
-	
+
 	test = gui_gs_dialog(dialog);
-	if (test != GS_OK) {		
+	if (test != GS_OK) {
 		g_free(dialog->text1);
 		g_free(dialog->text2);
 		g_free(dialog->text3);
@@ -1745,12 +1807,11 @@ void on_button_add_remote_clicked(GtkButton * button, gpointer user_data)
 		return;
 	}
 	gtk_list_store_append(GTK_LIST_STORE(model), &iter);
-	gtk_list_store_set(GTK_LIST_STORE(model), &iter, 
-				COLUMN_TYPE, dialog->text2, 
-				COLUMN_CAPTION, dialog->text1, 
-				COLUMN_SOURCE, dialog->text3, 
-				COLUMN_DIRECTORY, dialog->text4, 
-				-1);
+	gtk_list_store_set(GTK_LIST_STORE(model), &iter,
+			   COLUMN_TYPE, dialog->text2,
+			   COLUMN_CAPTION, dialog->text1,
+			   COLUMN_SOURCE, dialog->text3,
+			   COLUMN_DIRECTORY, dialog->text4, -1);
 	g_free(dialog->text1);
 	g_free(dialog->text2);
 	g_free(dialog->text3);
@@ -1777,12 +1838,13 @@ void on_button_add_remote_clicked(GtkButton * button, gpointer user_data)
  *   void
  */
 
-void on_button_remove_remote_clicked(GtkButton * button, gpointer user_data)
+void on_button_remove_remote_clicked(GtkButton * button,
+				     gpointer user_data)
 {
 	gint test;
 	GS_DIALOG *yes_no_dialog;
 	gchar *name_string;
-	GtkTreeSelection* selection;
+	GtkTreeSelection *selection;
 	GtkTreeIter selected;
 	GtkTreeIter iter;
 	gchar *caption = NULL;
@@ -1791,28 +1853,26 @@ void on_button_remove_remote_clicked(GtkButton * button, gpointer user_data)
 	gchar *directory = NULL;
 	GString *str = g_string_new(NULL);
 	GtkTreeModel *model;
-	
-	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview_remote));
-	if(!gtk_tree_selection_get_selected(selection, &model, &selected)) 
+
+	selection =
+	    gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview_remote));
+	if (!gtk_tree_selection_get_selected
+	    (selection, &model, &selected))
 		return;
 	gtk_tree_model_get(model, &selected,
-				   COLUMN_TYPE, &type, 
-				   COLUMN_CAPTION, &caption, 
-				   COLUMN_SOURCE, &source, 
-				   COLUMN_DIRECTORY , &directory, 
-				   -1);
+			   COLUMN_TYPE, &type,
+			   COLUMN_CAPTION, &caption,
+			   COLUMN_SOURCE, &source,
+			   COLUMN_DIRECTORY, &directory, -1);
 	name_string = caption;
 
 	yes_no_dialog = gui_new_dialog();
 	yes_no_dialog->stock_icon = GTK_STOCK_DIALOG_WARNING;
-	yes_no_dialog->title = N_("Bookmark");	
+	yes_no_dialog->title = N_("Bookmark");
 	g_string_printf(str,
 			"<span weight=\"bold\">%s</span>\n\n%s|%s|%s|%s",
 			_("Remove the selected source"),
-			caption,
-			type,
-			source,
-			directory);
+			caption, type, source, directory);
 	yes_no_dialog->label_top = str->str;
 	yes_no_dialog->yes = TRUE;
 	yes_no_dialog->no = TRUE;
@@ -1827,11 +1887,25 @@ void on_button_remove_remote_clicked(GtkButton * button, gpointer user_data)
 	g_free(caption);
 	g_free(source);
 	g_free(directory);
-	g_string_free(str,TRUE);
-	
+	g_string_free(str, TRUE);
+
 }
 
 
+static gboolean on_destroy(GtkWidget * widget, GdkEvent * event, gpointer data)
+{
+	g_message("on_delete");
+	mod_mgr_shut_down();
+	while (gtk_events_pending()) {
+		gtk_main_iteration();
+	} 
+	if(have_changes) {
+		main_update_module_lists();
+		main_load_module_tree(sidebar.module_list);
+	}
+	return FALSE;
+}
+
 /******************************************************************************
  * Name
  *   create_dialog
@@ -1880,15 +1954,15 @@ GtkWidget *create_dialog(void)
 	GtkWidget *vbox7;
 	GtkWidget *label16;
 
-  GtkWidget *hbox12;
-  GtkWidget *vbox14;
-  GtkWidget *label26;
-  GtkWidget *scrolledwindow6;
-  GtkWidget *vbox15;
-  GtkWidget *label27;
-  GtkWidget *button_add_local;
-  GtkWidget *button_remove_local;
-  
+	GtkWidget *hbox12;
+	GtkWidget *vbox14;
+	GtkWidget *label26;
+	GtkWidget *scrolledwindow6;
+	GtkWidget *vbox15;
+	GtkWidget *label27;
+	GtkWidget *button_add_local;
+	GtkWidget *button_remove_local;
+
 	GtkWidget *hbox11;
 	GtkWidget *vbox9;
 	GtkWidget *label18;
@@ -1898,7 +1972,6 @@ GtkWidget *create_dialog(void)
 	GtkWidget *label15;
 
 	GtkWidget *dialog_action_area1;
-	GtkWidget *button4;
 	GtkWidget *alignment3;
 	GtkWidget *hbox8;
 	GtkWidget *image3;
@@ -1915,7 +1988,7 @@ GtkWidget *create_dialog(void)
 	GString *str = g_string_new(NULL);
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
-	
+
 	dialog = gtk_dialog_new();
 	gtk_container_set_border_width(GTK_CONTAINER(dialog), 6);
 	gtk_window_set_title(GTK_WINDOW(dialog), _("Module Manager"));
@@ -1940,6 +2013,9 @@ GtkWidget *create_dialog(void)
 				       (scrolledwindow2),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
+					    scrolledwindow2,
+					    settings.shadow_type);
 
 	model = create_model_to_first();
 	treeview1 = gtk_tree_view_new_with_model(model);
@@ -2047,8 +2123,9 @@ GtkWidget *create_dialog(void)
 	gtk_box_pack_start(GTK_BOX(vbox4), hbox2, FALSE, TRUE, 0);
 
 	radiobutton2 =
-	    gtk_radio_button_new_with_mnemonic_from_widget((GtkRadioButton *) 
-	    		radiobutton_source, _("Remote"));
+	    gtk_radio_button_new_with_mnemonic_from_widget((GtkRadioButton *)
+							   radiobutton_source,
+							   _("Remote"));
 	gtk_widget_show(radiobutton2);
 	gtk_box_pack_start(GTK_BOX(hbox2), radiobutton2, FALSE, FALSE,
 			   0);
@@ -2139,6 +2216,9 @@ GtkWidget *create_dialog(void)
 				       (scrolledwindow1),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
+					    scrolledwindow1,
+					    settings.shadow_type);
 
 	model = create_model();
 
@@ -2151,7 +2231,7 @@ GtkWidget *create_dialog(void)
 	/* add columns to the tree view */
 	add_columns(GTK_TREE_VIEW(treeview), FALSE);
 
-
+//dlg-un.png
 	progressbar = gtk_progress_bar_new();
 	gtk_widget_show(progressbar);
 	gtk_box_pack_start(GTK_BOX(vbox1), progressbar, FALSE, FALSE,
@@ -2178,6 +2258,9 @@ GtkWidget *create_dialog(void)
 				       (scrolledwindow3),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
+					    scrolledwindow3,
+					    settings.shadow_type);
 	model = create_model();
 
 	treeview2 = gtk_tree_view_new_with_model(model);
@@ -2213,49 +2296,61 @@ GtkWidget *create_dialog(void)
 	gtk_label_set_justify(GTK_LABEL(label16), GTK_JUSTIFY_LEFT);
 	gtk_misc_set_alignment(GTK_MISC(label16), 0, 0.5);
 
-  hbox12 = gtk_hbox_new (FALSE, 6);
-  gtk_widget_show (hbox12);
-  gtk_box_pack_start (GTK_BOX (vbox7), hbox12, TRUE, TRUE, 0);
-  gtk_container_set_border_width (GTK_CONTAINER (hbox12), 12);
+	hbox12 = gtk_hbox_new(FALSE, 6);
+	gtk_widget_show(hbox12);
+	gtk_box_pack_start(GTK_BOX(vbox7), hbox12, TRUE, TRUE, 0);
+	gtk_container_set_border_width(GTK_CONTAINER(hbox12), 12);
 
-  vbox14 = gtk_vbox_new (FALSE, 0);
-  gtk_widget_show (vbox14);
-  gtk_box_pack_start (GTK_BOX (hbox12), vbox14, TRUE, TRUE, 0);
+	vbox14 = gtk_vbox_new(FALSE, 0);
+	gtk_widget_show(vbox14);
+	gtk_box_pack_start(GTK_BOX(hbox12), vbox14, TRUE, TRUE, 0);
 
-  label26 = gtk_label_new (_("Current local sources"));
-  gtk_widget_show (label26);
-  gtk_box_pack_start (GTK_BOX (vbox14), label26, FALSE, FALSE, 0);
-  gtk_label_set_justify (GTK_LABEL (label26), GTK_JUSTIFY_LEFT);
-  gtk_misc_set_alignment (GTK_MISC (label26), 0, 0.5);
+	label26 = gtk_label_new(_("Current local sources"));
+	gtk_widget_show(label26);
+	gtk_box_pack_start(GTK_BOX(vbox14), label26, FALSE, FALSE, 0);
+	gtk_label_set_justify(GTK_LABEL(label26), GTK_JUSTIFY_LEFT);
+	gtk_misc_set_alignment(GTK_MISC(label26), 0, 0.5);
 
-  scrolledwindow6 = gtk_scrolled_window_new (NULL, NULL);
-  gtk_widget_show (scrolledwindow6);
-  gtk_box_pack_start (GTK_BOX (vbox14), scrolledwindow6, TRUE, TRUE, 0);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow6), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	scrolledwindow6 = gtk_scrolled_window_new(NULL, NULL);
+	gtk_widget_show(scrolledwindow6);
+	gtk_box_pack_start(GTK_BOX(vbox14), scrolledwindow6, TRUE, TRUE,
+			   0);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW
+				       (scrolledwindow6),
+				       GTK_POLICY_AUTOMATIC,
+				       GTK_POLICY_AUTOMATIC);
 
-  model = create_remote_source_treeview_model();
-  treeview_local = gtk_tree_view_new_with_model(model);
-  gtk_widget_show (treeview_local);
-  gtk_container_add (GTK_CONTAINER (scrolledwindow6), treeview_local);
-  gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview_local), FALSE);
-  add_columns_to_remote_treeview(GTK_TREE_VIEW(treeview_local));
-  
-  vbox15 = gtk_vbox_new (FALSE, 0);
-  gtk_widget_show (vbox15);
-  gtk_box_pack_start (GTK_BOX (hbox12), vbox15, TRUE, TRUE, 0);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
+					    scrolledwindow6,
+					    settings.shadow_type);
 
-  label27 = gtk_label_new ("");
-  gtk_widget_show (label27);
-  gtk_box_pack_start (GTK_BOX (vbox15), label27, FALSE, FALSE, 0);
-  gtk_label_set_justify (GTK_LABEL (label27), GTK_JUSTIFY_LEFT);
+	model = create_remote_source_treeview_model();
+	treeview_local = gtk_tree_view_new_with_model(model);
+	gtk_widget_show(treeview_local);
+	gtk_container_add(GTK_CONTAINER(scrolledwindow6),
+			  treeview_local);
+	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(treeview_local),
+					  FALSE);
+	add_columns_to_remote_treeview(GTK_TREE_VIEW(treeview_local));
 
-  button_add_local = gtk_button_new_from_stock ("gtk-add");
-  gtk_widget_show (button_add_local);
-  gtk_box_pack_start (GTK_BOX (vbox15), button_add_local, FALSE, FALSE, 0);
+	vbox15 = gtk_vbox_new(FALSE, 0);
+	gtk_widget_show(vbox15);
+	gtk_box_pack_start(GTK_BOX(hbox12), vbox15, TRUE, TRUE, 0);
 
-  button_remove_local = gtk_button_new_from_stock ("gtk-remove");
-  gtk_widget_show (button_remove_local);
-  gtk_box_pack_start (GTK_BOX (vbox15), button_remove_local, FALSE, FALSE, 0);
+	label27 = gtk_label_new("");
+	gtk_widget_show(label27);
+	gtk_box_pack_start(GTK_BOX(vbox15), label27, FALSE, FALSE, 0);
+	gtk_label_set_justify(GTK_LABEL(label27), GTK_JUSTIFY_LEFT);
+
+	button_add_local = gtk_button_new_from_stock("gtk-add");
+	gtk_widget_show(button_add_local);
+	gtk_box_pack_start(GTK_BOX(vbox15), button_add_local, FALSE,
+			   FALSE, 0);
+
+	button_remove_local = gtk_button_new_from_stock("gtk-remove");
+	gtk_widget_show(button_remove_local);
+	gtk_box_pack_start(GTK_BOX(vbox15), button_remove_local, FALSE,
+			   FALSE, 0);
 
 	hbox11 = gtk_hbox_new(FALSE, 6);
 	gtk_widget_show(hbox11);
@@ -2280,7 +2375,10 @@ GtkWidget *create_dialog(void)
 				       (scrolledwindow5),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
-				       
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
+					    scrolledwindow5,
+					    settings.shadow_type);
+
 	model = create_remote_source_treeview_model();
 	treeview_remote = gtk_tree_view_new_with_model(model);
 	gtk_widget_show(treeview_remote);
@@ -2322,11 +2420,19 @@ GtkWidget *create_dialog(void)
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area1),
 				  GTK_BUTTONBOX_END);
 
-	button4 = gtk_button_new_from_stock("gtk-close");
-	gtk_widget_show(button4);
-	gtk_dialog_add_action_widget(GTK_DIALOG(dialog), button4,
+	button_cancel = gtk_button_new_from_stock("gtk-cancel");
+//	gtk_widget_show(button_cancel);
+	gtk_dialog_add_action_widget(GTK_DIALOG(dialog), button_cancel,
+				     GTK_RESPONSE_CANCEL);
+	GTK_WIDGET_SET_FLAGS(button_cancel, GTK_CAN_DEFAULT);
+	gtk_tooltips_set_tip(tooltips, button_cancel,
+			     _("Cancel current operation"), NULL);
+	
+	button_close = gtk_button_new_from_stock("gtk-close");
+	gtk_widget_show(button_close);
+	gtk_dialog_add_action_widget(GTK_DIALOG(dialog), button_close,
 				     GTK_RESPONSE_CLOSE);
-	GTK_WIDGET_SET_FLAGS(button4, GTK_CAN_DEFAULT);
+	GTK_WIDGET_SET_FLAGS(button_close, GTK_CAN_DEFAULT);
 
 	button5 = gtk_button_new_from_stock("gtk-refresh");
 	//gtk_widget_show (button5);
@@ -2389,7 +2495,9 @@ GtkWidget *create_dialog(void)
 	gtk_box_pack_start(GTK_BOX(hbox7), label8, FALSE, FALSE, 0);
 	gtk_label_set_justify(GTK_LABEL(label8), GTK_JUSTIFY_LEFT);
 
-
+	//dialog
+	g_signal_connect((gpointer) dialog, "destroy",
+			 G_CALLBACK(on_destroy), NULL);
 	g_signal_connect((gpointer) dialog, "response",
 			 G_CALLBACK(on_dialog_response), NULL);
 	g_signal_connect(G_OBJECT(treeview1),
@@ -2399,14 +2507,13 @@ GtkWidget *create_dialog(void)
 			 G_CALLBACK(on_notebook1_switch_page), NULL);
 	g_signal_connect((gpointer) radiobutton2, "toggled",
 			 G_CALLBACK(on_radiobutton2_toggled), NULL);
-			 
-	
-  g_signal_connect ((gpointer) button_add_local, "clicked",
-                    G_CALLBACK (on_button_add_local_clicked),
-                    NULL);
-  g_signal_connect ((gpointer) button_remove_local, "clicked",
-                    G_CALLBACK (on_button_remove_local_clicked),
-                    NULL);
+
+
+	g_signal_connect((gpointer) button_add_local, "clicked",
+			 G_CALLBACK(on_button_add_local_clicked), NULL);
+	g_signal_connect((gpointer) button_remove_local, "clicked",
+			 G_CALLBACK(on_button_remove_local_clicked),
+			 NULL);
 	g_signal_connect((gpointer) button_add_remote, "clicked",
 			 G_CALLBACK(on_button_add_remote_clicked),
 			 NULL);
@@ -2451,14 +2558,13 @@ void gui_open_mod_mgr(void)
 	   if (g_thread_supported ())
 	   g_print("g_thread_supported\n");
 	 */
-	open_config_file(str->str);
 	mod_mgr_init(NULL);
 	dlg = create_dialog();
 
 	g_string_printf(str, "%s/%s", settings.homedir, ".sword");
 	gtk_label_set_text(GTK_LABEL(label_home), str->str);
 
-	path = get_path_to_mods();
+	path = main_get_path_to_mods();
 	gtk_label_set_text(GTK_LABEL(label_system), path);
 	if (access(path, W_OK) == -1) {
 		g_print("%s is write protected\n", path);
@@ -2471,7 +2577,6 @@ void gui_open_mod_mgr(void)
 
 	create_pixbufs();
 	load_source_treeviews();
-	close_config_file();
 	gtk_widget_show(dlg);
 	g_string_free(str, TRUE);
 }
@@ -2496,22 +2601,35 @@ void gui_open_mod_mgr(void)
 void gui_update_install_status(glong total, glong done,
 			       const gchar * message)
 {
-	GtkProgressBar *pbar;
+	gchar *buf;
+	GtkProgressBar *pbar = NULL;
+	
 	switch (current_page) {
 	case 1:
+		if(!progressbar_refresh) {
+			return;
+		}
 		pbar = GTK_PROGRESS_BAR(progressbar_refresh);
 		break;
 	case 2:
+		if(!progressbar) {
+			return;
+		}
 		pbar = GTK_PROGRESS_BAR(progressbar);
 		break;
 	case 3:
+		if(!progressbar1) {
+			return;
+		}
 		pbar = GTK_PROGRESS_BAR(progressbar1);
 		break;
 	}
-	gtk_progress_bar_set_text(pbar, message);
+	buf = g_strdup_printf("%s: %s",current_mod,message);
+	gtk_progress_bar_set_text(pbar, buf);
 	while (gtk_events_pending()) {
 		gtk_main_iteration();
 	}
+	g_free(buf);
 }
 
 
@@ -2536,12 +2654,18 @@ void gui_update_install_progressbar(gdouble fraction)
 	GtkProgressBar *pbar;
 	switch (current_page) {
 	case 1:
+		if(!progressbar_refresh)
+			return;
 		pbar = GTK_PROGRESS_BAR(progressbar_refresh);
 		break;
 	case 2:
+		if(!progressbar)
+			return;
 		pbar = GTK_PROGRESS_BAR(progressbar);
 		break;
 	case 3:
+		if(!progressbar1)
+			return;
 		pbar = GTK_PROGRESS_BAR(progressbar1);
 		break;
 	}
