@@ -25,32 +25,27 @@
 
 #include <gnome.h>
 #include <gtkhtml/gtkhtml.h>
-#include <gtkhtml/gtkhtmlfontstyle.h>
+/*#include <gtkhtml/gtkhtmlfontstyle.h>
 #include <gtkhtml/htmlform.h>
 #include <gtkhtml/htmlenums.h>
 #include <gtkhtml/htmlsettings.h>
 #include <gtkhtml/htmlcolor.h>
 #include <gtkhtml/htmlcolorset.h>
-#include <gtkhtml/htmllinktext.h>
 #include <gtkhtml/htmlengine-edit.h>
 #include <gtkhtml/htmlengine-edit-fontstyle.h>
 #include <gtkhtml/htmlengine-edit-cut-and-paste.h>
 #include <gtkhtml/htmlselection.h>
-#include <gtkhtml/htmlengine-search.h>
-#include <gal/widgets/e-unicode.h>
+#include <gtkhtml/htmlengine-search.h>*/
 #include <stdio.h>
 #include <sys/stat.h>
 #include <unistd.h>
 #include <sys/types.h>
 #include <fcntl.h>
 
-#include "gui/editor.h"
+#include "editor/editor-control.h"
+
+
 #include "gui/note_editor.h"
-#include "gui/note_toolbar_edit.h"
-#include "gui/note_toolbar_style.h"
-#include "gui/editor_replace.h"
-#include "gui/editor_spell.h"
-//#include "gui/percomm.h"
 #include "gui/fileselection.h"
 #include "gui/studypad.h"
 #include "gui/html.h"
@@ -60,7 +55,6 @@
 #include "gui/find_dialog.h"
 #include "gui/widgets.h"
 
-#include "main/percomm.h"
 #include "main/settings.h"
 #include "main/sword.h"
 #include "main/lists.h"
@@ -68,38 +62,12 @@
 #include "main/module_dialogs.h"
 
 
-static GtkWidget *create_menu(DIALOG_DATA * d);
 
 extern gboolean dialog_freed;
+extern gboolean do_display;
 
 static GtkWidget *sync_button;
-
-/******************************************************************************
- * Name
- *   on_dialog_motion_notify_event
- *
- * Synopsis
- *   #include "commentary_dialog.h"
- *
- *   gboolean on_dialog_motion_notify_event(GtkWidget *widget,
-                      GdkEventMotion  *event, DIALOG_DATA * vc)	
- *
- * Description
- *   
- *
- * Return value
- *   gboolean
- */
-
-static gboolean on_dialog_motion_notify_event(GtkWidget * widget,
-					      GdkEventMotion * event,
-					      DIALOG_DATA * d)
-{
-	//cur_vc = d;
-	return FALSE;
-}
-
-
+static GtkWidget *create_menu(DIALOG_DATA * d);
 
 
 
@@ -145,132 +113,6 @@ static gboolean html_key_press_event(GtkWidget * widget,
 }
 
 
-/******************************************************************************
- * Name
- *   book_changed
- *
- * Synopsis
- *   #include "bibletext_dialog.h"
- *
- *   void book_changed(GtkEditable * editable, gpointer user_data)	
- *
- * Description
- *   change book 
- *
- * Return value
- *   void
- */
-
-static void book_changed(GtkEditable * editable, DIALOG_DATA * c)
-{
-	gchar *url;
-	gchar *bookname = gtk_editable_get_chars(editable, 0, -1);
-	GSHTMLEditorControlData *ec = (GSHTMLEditorControlData*) c->editor;
-	
-	if (*bookname) {
-		url = g_strdup_printf("sword:///%s 1:1", bookname);
-		main_dialogs_url_handler(c, url, TRUE);
-		g_free(url);
-	}
-	if(!ec)
-		return;
-	if(ec->key)
-		g_free(ec->key);
-	ec->key = g_strdup_printf("%s 1:1", bookname);
-}
-
-
-/******************************************************************************
- * Name
- *   chapter_button_release_event
- *
- * Synopsis
- *   #include "bibletext_dialog.h"
- *
- *   gboolean chapter_button_release_event(GtkWidget * widget,
- *			GdkEventButton * event,   gpointer user_data)	
- *
- * Description
- *    change chapter 
- *
- * Return value
- *   gboolean
- */
-
-static gboolean chapter_button_release_event(GtkWidget * widget,
-					     GdkEventButton * event,
-					     DIALOG_DATA * c)
-{
-	G_CONST_RETURN gchar *bookname;
-	gchar *url;
-	gchar *val_key;
-	gint chapter;
-	GSHTMLEditorControlData *ec = (GSHTMLEditorControlData*) c->editor;
-
-	bookname = (gchar*)gtk_entry_get_text(GTK_ENTRY(c->cbe_book));
-	chapter =
-	    gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON
-					     (c->spb_chapter));
-	url = g_strdup_printf("sword:///%s %d:1", bookname, chapter);
-	main_dialogs_url_handler(c, url, TRUE);
-	g_free(url);	
-	
-	if(!ec)
-		return;
-	if(ec->key)
-		g_free(ec->key);
-	ec->key = g_strdup_printf("%s %d:1", bookname, chapter);
-	return FALSE;
-}
-
-
-/******************************************************************************
- * Name
- *   
- *
- * Synopsis
- *   #include "bibletext_dialog.h"
- *
- *   gboolean (GtkWidget * widget, 
- *			GdkEventButton * event,  gpointer user_data)	
- *
- * Description
- *    change verse
- *
- * Return value
- *   gboolean
- */
-
-static gboolean verse_button_release_event(GtkWidget * widget,
-					   GdkEventButton * event,
-					   DIALOG_DATA * c)
-{
-	G_CONST_RETURN gchar *bookname;
-	gchar *url;
-	gchar *val_key;
-	gint chapter, verse;
-	GSHTMLEditorControlData *ec = (GSHTMLEditorControlData*) c->editor;
-
-	bookname = (gchar*)gtk_entry_get_text(GTK_ENTRY(c->cbe_book));
-	chapter =
-	    gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON
-					     (c->spb_chapter));
-	verse =
-	    gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON
-					     (c->spb_verse));
-	url = g_strdup_printf("sword:///%s %d:%d", bookname, chapter, verse);
-	main_dialogs_url_handler(c, url, TRUE);
-	g_free(url);
-	
-	if(!ec)
-		return;
-	if(ec->key)
-		g_free(ec->key);
-	ec->key = g_strdup_printf("%s %d:%d", bookname, chapter, verse);
-	return FALSE;
-}
-
-
 /******************************************************************************
  * Name
  *   entry_key_press_event
@@ -352,18 +194,197 @@ static void sync_with_main(DIALOG_DATA * c)
  *   void
  */
 
-static void sync_toggled(GtkToggleButton * button, DIALOG_DATA * c)
+static void sync_toggled(GtkToggleButton * button, DIALOG_DATA * d)
 {
 	if(button->active) {
-		sync_with_main(c);
-		c->sync = TRUE;
+		sync_with_main(d);
+		d->sync = TRUE;
 	}
 	else		
-		c->sync = FALSE;
+		d->sync = FALSE;
 }
 
 
 
+static void on_comboboxentry4_changed(GtkComboBox * combobox, DIALOG_DATA * c)
+{
+	gchar *url = NULL;
+	gchar *book = NULL;
+	gchar *buf = NULL;
+	GtkTreeIter iter;
+	GSHTMLEditorControlData *ec
+	    = (GSHTMLEditorControlData *) c->editor;
+	GtkTreeModel *model = gtk_combo_box_get_model(combobox);
+
+	if (!do_display)
+		return;
+#ifdef DEBUG
+	g_message("on_comboboxentry4_changed");
+#endif
+	gtk_combo_box_get_active_iter(combobox, &iter);
+	gtk_tree_model_get(GTK_TREE_MODEL(model), &iter, 0, &book, -1);
+
+	url = g_strdup_printf("sword:///%s 1:1", book);
+	buf = g_strdup_printf("%s 1:1", book);
+
+	main_dialogs_url_handler(c, url, TRUE);
+	main_navbar_set(c->navbar, buf);
+	g_free(url);
+	g_free(book);
+	if (ec) {
+		if (ec->key)
+			g_free(ec->key);
+		ec->key = g_strdup_printf("%s", buf);
+	}
+	g_free(buf);
+}
+
+
+static void on_comboboxentry5_changed(GtkComboBox * combobox, DIALOG_DATA * c)
+{
+	gchar *url = NULL;
+	gchar *book = NULL;
+	gchar *chapter = NULL;
+	gchar *buf = NULL;
+	GtkTreeIter iter;
+
+	GSHTMLEditorControlData *ec
+	    = (GSHTMLEditorControlData *) c->editor;
+	GtkTreeModel *model = gtk_combo_box_get_model(combobox);
+	GtkTreeModel *book_model =
+	    gtk_combo_box_get_model(GTK_COMBO_BOX
+				    (c->navbar.comboboxentry_book));
+
+
+	if (!do_display)
+		return;
+#ifdef DEBUG
+	g_message("on_comboboxentry5_changed");
+#endif
+	gtk_combo_box_get_active_iter(GTK_COMBO_BOX
+				      (c->navbar.comboboxentry_book),
+				      &iter);
+	gtk_tree_model_get(GTK_TREE_MODEL(book_model), &iter, 0, &book,
+			   -1);
+
+	gtk_combo_box_get_active_iter(combobox, &iter);
+	gtk_tree_model_get(GTK_TREE_MODEL(model), &iter,
+			   0, &chapter, -1);
+
+	url = g_strdup_printf("sword:///%s %s:1",
+			      settings.MainWindowModule, book, chapter);
+	buf = g_strdup_printf("%s %s:1", book, chapter);
+	main_dialogs_url_handler(c, url, TRUE);
+	main_navbar_set(c->navbar, buf);
+
+	g_free(url);
+	g_free(book);
+	g_free(chapter);
+	if (ec) {
+		if (ec->key)
+			g_free(ec->key);
+		ec->key = g_strdup_printf("%s", buf);
+	}
+	g_free(buf);
+}
+
+
+static void on_comboboxentry6_changed(GtkComboBox * combobox, DIALOG_DATA * c)
+{
+	gchar *url = NULL;
+	gchar *book = NULL;
+	gchar *chapter = NULL;
+	gchar *verse = NULL;
+	gchar *buf = NULL;
+	GtkTreeIter iter;
+
+	GSHTMLEditorControlData *ec
+	    = (GSHTMLEditorControlData *) c->editor;
+	GtkTreeModel *model = gtk_combo_box_get_model(combobox);
+	GtkTreeModel *book_model =
+	    gtk_combo_box_get_model(GTK_COMBO_BOX
+				    (c->navbar.comboboxentry_book));
+	GtkTreeModel *chapter_model =
+	    gtk_combo_box_get_model(GTK_COMBO_BOX
+				    (c->navbar.comboboxentry_chapter));
+
+
+	if (!do_display)
+		return;
+#ifdef DEBUG
+	g_message("on_comboboxentry6_changed");
+#endif
+	gtk_combo_box_get_active_iter(GTK_COMBO_BOX
+				      (c->navbar.comboboxentry_book),
+				      &iter);
+	gtk_tree_model_get(GTK_TREE_MODEL(book_model), &iter, 0, &book,
+			   -1);
+
+	gtk_combo_box_get_active_iter(GTK_COMBO_BOX
+				      (c->navbar.comboboxentry_chapter),
+				      &iter);
+	gtk_tree_model_get(GTK_TREE_MODEL(chapter_model), &iter, 0,
+			   &chapter, -1);
+
+	gtk_combo_box_get_active_iter(combobox, &iter);
+	gtk_tree_model_get(GTK_TREE_MODEL(model), &iter, 0, &verse, -1);
+
+	url = g_strdup_printf("sword:///%s %s:%s",
+			      book, chapter, verse);
+	buf = g_strdup_printf("%s %s:%s", book, chapter, verse);
+	main_dialogs_url_handler(c, url, TRUE);
+	main_navbar_set(c->navbar, buf);
+
+	g_free(url);
+	g_free(book);
+	g_free(chapter);
+	g_free(verse);
+	if (ec) {
+		if (ec->key)
+			g_free(ec->key);
+		ec->key = g_strdup_printf("%s", buf);
+	}
+	g_free(buf);
+}
+
+
+/******************************************************************************
+ * Name
+ *   on_entry_activate
+ *
+ * Synopsis
+ *   #include "bibletext_dialog.h"
+ *
+ *   void on_entry_activate(GtkEntry * entry, DIALOG_DATA * c)	
+ *
+ * Description
+ *   go to verse in free form entry if user hit <enter>
+ *
+ * Return value
+ *   void
+ */
+
+static void on_entry_activate(GtkEntry * entry, DIALOG_DATA * c)
+{
+	GSHTMLEditorControlData *ec
+	    = (GSHTMLEditorControlData *) c->editor;
+	const gchar *buf = gtk_entry_get_text(entry);
+	if (c->navbar.key)
+		g_free(c->navbar.key);
+	c->navbar.key = g_strdup(buf);
+	gchar *url = g_strdup_printf("sword:///%s", buf);
+	main_dialogs_url_handler(c, url, TRUE);
+	g_free(url);
+	main_navbar_set(c->navbar, c->navbar.key);
+	
+	if (!ec)
+		return;
+	if (ec->key)
+		g_free(ec->key);
+	ec->key = g_strdup_printf("%s", buf);
+
+}
+
 
 
 /******************************************************************************
@@ -382,391 +403,173 @@ static void sync_toggled(GtkToggleButton * button, DIALOG_DATA * c)
  *   void
  */
 
-static GtkWidget *create_nav_toolbar(DIALOG_DATA * vc)
+static GtkWidget *create_nav_toolbar(DIALOG_DATA * c)
 {
-	GtkWidget *toolbar_nav;
-	GtkWidget *cbBook;
-	GtkObject *spbChapter_adj;
-	GtkObject *spbVerse_adj;
-	GtkWidget *tmp_toolbar_icon;
-	GtkWidget *vseparator;
-	GtkWidget *label;
+	GtkWidget *hbox3;
+	GtkWidget *image;
+	GtkWidget *separatortoolitem;
+	GtkListStore *store;
+	GtkCellRenderer *renderer;
 
-	toolbar_nav =
-	    gtk_toolbar_new();
-	gtk_toolbar_set_style (GTK_TOOLBAR (toolbar_nav), GTK_TOOLBAR_ICONS);
-	gtk_widget_show(toolbar_nav);
-	gtk_widget_set_size_request(toolbar_nav, -1, 34);
-	
-	tmp_toolbar_icon = gtk_image_new_from_stock (
-			GTK_STOCK_REFRESH, 
-			gtk_toolbar_get_icon_size (GTK_TOOLBAR (toolbar_nav)));
-	sync_button =
-		gtk_toolbar_append_element(GTK_TOOLBAR
-				       (toolbar_nav),
-				       GTK_TOOLBAR_CHILD_TOGGLEBUTTON,
-				       NULL, _("Sync"),
-				       _("Toggle sync with main window"), 
-				       NULL,
-				       tmp_toolbar_icon, NULL,
-				       NULL);
+	hbox3 = gtk_hbox_new(FALSE, 2);
+	gtk_widget_show(hbox3);
+	gtk_container_set_border_width(GTK_CONTAINER(hbox3), 3);
+
+	sync_button = gtk_toggle_button_new();
 	gtk_widget_show(sync_button);
+	gtk_box_pack_start(GTK_BOX(hbox3), sync_button, FALSE, FALSE,
+			   0);
+	gtk_button_set_relief(GTK_BUTTON(sync_button), GTK_RELIEF_NONE);
+
+	image =
+	    gtk_image_new_from_stock("gtk-refresh",
+				     GTK_ICON_SIZE_BUTTON);
+	gtk_widget_show(image);
+	gtk_container_add(GTK_CONTAINER(sync_button), image);
+
+	separatortoolitem = (GtkWidget *) gtk_separator_tool_item_new();
+	gtk_widget_show(separatortoolitem);
+	gtk_box_pack_start(GTK_BOX(hbox3), separatortoolitem, FALSE,
+			   TRUE, 0);
+	gtk_widget_set_size_request(separatortoolitem, 6, -1);
+
+	store = gtk_list_store_new(1, G_TYPE_STRING);
+	c->navbar.comboboxentry_book =
+	    gtk_combo_box_new_with_model(GTK_TREE_MODEL(store));
+	gtk_widget_show(c->navbar.comboboxentry_book);
+	gtk_box_pack_start(GTK_BOX(hbox3), c->navbar.comboboxentry_book,
+			   TRUE, TRUE, 0);
+	gtk_widget_set_size_request(c->navbar.comboboxentry_book, -1,
+				    6);
+
+	renderer = gtk_cell_renderer_text_new();
+	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT
+				   (c->navbar.comboboxentry_book),
+				   renderer, TRUE);
+	gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT
+				       (c->navbar.comboboxentry_book),
+				       renderer, "text", 0, NULL);
 
 
-	vseparator = gtk_vseparator_new();
-	gtk_widget_show(vseparator);
-	gtk_toolbar_append_widget(GTK_TOOLBAR(toolbar_nav),
-				  vseparator, NULL, NULL);
-	gtk_widget_set_size_request(vseparator, 6, 7);
-	
-	
-	cbBook = gtk_combo_new();
-	gtk_widget_show(cbBook);
-	gtk_toolbar_append_widget(GTK_TOOLBAR(toolbar_nav), cbBook,
-				  NULL, NULL);
+	separatortoolitem = (GtkWidget *) gtk_separator_tool_item_new();
+	gtk_widget_show(separatortoolitem);
+	gtk_box_pack_start(GTK_BOX(hbox3), separatortoolitem, FALSE,
+			   TRUE, 0);
+	gtk_widget_set_size_request(separatortoolitem, 6, -1);
+	gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM
+					 (separatortoolitem), FALSE);
 
-	/*
-	 * get and load books of the Bible 
-	 */
-	gtk_combo_set_popdown_strings(GTK_COMBO(cbBook),
-				      get_list(BOOKS_LIST));
+	store = gtk_list_store_new(1, G_TYPE_STRING);
 
-	vc->cbe_book = GTK_COMBO(cbBook)->entry;
-	gtk_widget_set_size_request(vc->cbe_book, 100, -1);
-	gtk_widget_show(vc->cbe_book);
+	c->navbar.comboboxentry_chapter = gtk_combo_box_new_with_model(GTK_TREE_MODEL(store));	//gtk_combo_box_entry_new();
+	gtk_widget_show(c->navbar.comboboxentry_chapter);
+	gtk_box_pack_start(GTK_BOX(hbox3),
+			   c->navbar.comboboxentry_chapter, FALSE, TRUE,
+			   0);
+	gtk_widget_set_size_request(c->navbar.comboboxentry_chapter, 61,
+				    -1);
 
-	label = gtk_label_new ("");
-	gtk_widget_show (label);
-	gtk_toolbar_append_widget (GTK_TOOLBAR (toolbar_nav), label, NULL, NULL);
-	gtk_widget_set_size_request (label, 6, -1);
-	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-	
-	spbChapter_adj = gtk_adjustment_new(8, -1, 151, 1, 10, 10);
-	vc->spb_chapter =
-	    gtk_spin_button_new(GTK_ADJUSTMENT(spbChapter_adj), 1, 0);
-	gtk_widget_show(vc->spb_chapter);
-	gtk_toolbar_append_widget(GTK_TOOLBAR(toolbar_nav),
-				  vc->spb_chapter, NULL, NULL);
-	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON
-				    (vc->spb_chapter), TRUE);
-				    
-	label = gtk_label_new ("");
-	gtk_widget_show (label);
-	gtk_toolbar_append_widget (GTK_TOOLBAR (toolbar_nav), label, NULL, NULL);
-	gtk_widget_set_size_request (label, 6, -1);
-	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-	
-	spbVerse_adj = gtk_adjustment_new(28, -1, 180, 1, 10, 10);
-	vc->spb_verse =
-	    gtk_spin_button_new(GTK_ADJUSTMENT(spbVerse_adj), 1, 0);
-	gtk_widget_show(vc->spb_verse);
-	gtk_toolbar_append_widget(GTK_TOOLBAR(toolbar_nav),
-				  vc->spb_verse, NULL, NULL);
-	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(vc->spb_verse),
-				    TRUE);
+	renderer = gtk_cell_renderer_text_new();
+	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT
+				   (c->navbar.comboboxentry_chapter),
+				   renderer, TRUE);
+	gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT
+				       (c->navbar.
+					comboboxentry_chapter),
+				       renderer, "text", 0, NULL);
 
-	label = gtk_label_new ("");
-	gtk_widget_show (label);
-	gtk_toolbar_append_widget (GTK_TOOLBAR (toolbar_nav), label, NULL, NULL);
-	gtk_widget_set_size_request (label, 6, -1);
-	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-	
-	vc->freeform_lookup = gtk_entry_new();
-	gtk_widget_show(vc->freeform_lookup);
-	gtk_toolbar_append_widget(GTK_TOOLBAR(toolbar_nav),
-				  vc->freeform_lookup, NULL, NULL);
-	gtk_entry_set_text(GTK_ENTRY(vc->freeform_lookup),
-			   _("Romans 8:28"));
+	separatortoolitem = (GtkWidget *) gtk_separator_tool_item_new();
+	gtk_widget_show(separatortoolitem);
+	gtk_box_pack_start(GTK_BOX(hbox3), separatortoolitem, FALSE,
+			   TRUE, 0);
+	gtk_widget_set_size_request(separatortoolitem, 6, -1);
+	gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM
+					 (separatortoolitem), FALSE);
 
-	g_signal_connect(GTK_OBJECT(vc->cbe_book),
-			   "changed",
-			   G_CALLBACK(book_changed), vc);
+	store = gtk_list_store_new(1, G_TYPE_STRING);
+	c->navbar.comboboxentry_verse = gtk_combo_box_new_with_model(GTK_TREE_MODEL(store));	//gtk_combo_box_entry_new();
+	gtk_widget_show(c->navbar.comboboxentry_verse);
+	gtk_box_pack_start(GTK_BOX(hbox3),
+			   c->navbar.comboboxentry_verse, FALSE, TRUE,
+			   0);
+	gtk_widget_set_size_request(c->navbar.comboboxentry_verse, 61,
+				    -1);
+
+
+	renderer = gtk_cell_renderer_text_new();
+	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT
+				   (c->navbar.comboboxentry_verse),
+				   renderer, TRUE);
+	gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT
+				       (c->navbar.comboboxentry_verse),
+				       renderer, "text", 0, NULL);
+
+
+	separatortoolitem = (GtkWidget *) gtk_separator_tool_item_new();
+	gtk_widget_show(separatortoolitem);
+	gtk_box_pack_start(GTK_BOX(hbox3), separatortoolitem, FALSE,
+			   TRUE, 0);
+
+	c->navbar.lookup_entry = gtk_entry_new();
+	gtk_widget_show(c->navbar.lookup_entry);
+	gtk_box_pack_start(GTK_BOX(hbox3), c->navbar.lookup_entry, TRUE,
+			   TRUE, 0);
 
 	g_signal_connect(GTK_OBJECT(sync_button),
-			   "toggled",
-			   G_CALLBACK(sync_toggled), vc);
-			   
-	g_signal_connect(GTK_OBJECT(vc->spb_chapter),
-			   "button_release_event",
-			   G_CALLBACK
-			   (chapter_button_release_event), vc);
-	g_signal_connect(GTK_OBJECT(vc->spb_verse),
-			   "button_release_event",
-			   G_CALLBACK
-			   (verse_button_release_event), vc);
-	g_signal_connect(GTK_OBJECT(vc->freeform_lookup),
-			   "key_press_event",
-			   G_CALLBACK(entry_key_press_event), vc);
-	return toolbar_nav;
+			 "toggled", G_CALLBACK(sync_toggled), c);
+	g_signal_connect((gpointer) c->navbar.comboboxentry_book,
+			 "changed",
+			 G_CALLBACK(on_comboboxentry4_changed), c);
+	g_signal_connect((gpointer) c->navbar.comboboxentry_chapter,
+			 "changed",
+			 G_CALLBACK(on_comboboxentry5_changed), c);
+	g_signal_connect((gpointer) c->navbar.comboboxentry_verse,
+			 "changed",
+			 G_CALLBACK(on_comboboxentry6_changed), c);
+	g_signal_connect((gpointer) c->navbar.lookup_entry, "activate",
+			 G_CALLBACK(on_entry_activate), c);
+	return hbox3;
 }
 
 
 
 void gui_create_note_editor(DIALOG_DATA * d)
 {
-	GtkWidget *vbox30;
+	GtkWidget *vbox;
 	GtkWidget *vbox_toolbars;
 	GtkWidget *toolbar_nav;
-	GtkWidget *frame19;
-	GtkWidget *scrolledwindow38;	
-	GSHTMLEditorControlData *ec = (GSHTMLEditorControlData*) d->editor;
-
+	
 	d->dialog = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-
 	gtk_object_set_data(GTK_OBJECT(d->dialog), "d->dialog",
 			    d->dialog);
 	gtk_window_set_title(GTK_WINDOW(d->dialog),
 			     main_get_module_description(d->mod_name));
-	gtk_window_set_policy(GTK_WINDOW(d->dialog), TRUE, TRUE,
-			      FALSE);
-	gtk_widget_set_size_request(d->dialog, 590, 380);
-
-	vbox30 = gtk_vbox_new(FALSE, 0);
-	gtk_widget_show(vbox30);
-
-	gtk_container_add(GTK_CONTAINER(d->dialog), vbox30);
-
+	gtk_window_set_resizable(GTK_WINDOW(d->dialog), TRUE);
+	gtk_widget_set_size_request(d->dialog, 600, 380);
+	
+	vbox = gtk_vbox_new(FALSE, 0);
+	gtk_widget_show(vbox);
+	gtk_container_add(GTK_CONTAINER(d->dialog), vbox);
+	
 	vbox_toolbars = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(vbox_toolbars);
-	gtk_box_pack_start(GTK_BOX(vbox30), vbox_toolbars, FALSE, FALSE,
+	gtk_box_pack_start(GTK_BOX(vbox), vbox_toolbars, FALSE, FALSE,
 			   0);
 
 	toolbar_nav = create_nav_toolbar(d);
 	gtk_widget_show(toolbar_nav);
 	gtk_box_pack_start(GTK_BOX(vbox_toolbars), toolbar_nav, FALSE,
 			   FALSE, 0);
-
-	frame19 = gtk_frame_new(NULL);
-	gtk_widget_show(frame19);
-	gtk_box_pack_start(GTK_BOX(vbox30), frame19, TRUE, TRUE, 0);
-	gtk_frame_set_shadow_type(GTK_FRAME(frame19), GTK_SHADOW_IN);
-
-	scrolledwindow38 = gtk_scrolled_window_new(NULL, NULL);
-	gtk_widget_show(scrolledwindow38);
-	gtk_container_add(GTK_CONTAINER(frame19), scrolledwindow38);
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW
-				       (scrolledwindow38),
-				       GTK_POLICY_NEVER,
-				       GTK_POLICY_AUTOMATIC);
-
-
 	
-	ec->htmlwidget = gtk_html_new();
-	ec->html = GTK_HTML(ec->htmlwidget);
-	gtk_widget_show(ec->htmlwidget);
-	gtk_container_add(GTK_CONTAINER(scrolledwindow38),
-			  ec->htmlwidget);
-
-	ec->vbox = vbox30;
-
-	ec->pm = create_menu(d);
-	gnome_popup_menu_attach(ec->pm, ec->htmlwidget,
-				NULL);
-
-	ec->statusbar = gtk_statusbar_new();
-	gtk_widget_show(ec->statusbar);
-	gtk_box_pack_start(GTK_BOX(vbox30), ec->statusbar,
-			   FALSE, TRUE, 0);
-	/*
-	   g_signal_connect(GTK_OBJECT(d->ec->html), "submit",
-	   G_CALLBACK(on_submit), d->ec);
-	   g_signal_connect(GTK_OBJECT
-	   (d->ec->htmlwidget),
-	   "load_done",
-	   G_CALLBACK(html_load_done), d->ec);
-	   g_signal_connect(GTK_OBJECT
-	   (d->ec->htmlwidget),
-	   "key_press_event",
-	   G_CALLBACK(html_key_pressed), d->ec);
-	   g_signal_connect(GTK_OBJECT
-	   (d->ec->htmlwidget),
-	   "button_press_event",
-	   G_CALLBACK(html_button_pressed), d->ec);
-	   g_signal_connect(GTK_OBJECT(d->ec->htmlwidget),
-	   "enter_notify_event",
-	   G_CALLBACK(on_html_enter_notify_event),
-	   d->ec);
-	g_signal_connect(G_OBJECT(d->ec->htmlwidget),
-			"cursor_move",
-			G_CALLBACK(html_cursor_move), d->ec);
-	 */
-	/* html.c */
-	g_signal_connect(G_OBJECT(ec->htmlwidget),
-			"key_press_event",
-			G_CALLBACK(html_key_press_event), d);
-	g_signal_connect(GTK_OBJECT(ec->htmlwidget),
-			   "link_clicked",
-			   G_CALLBACK(gui_link_clicked),
-			   NULL);
-	
-	g_signal_connect(GTK_OBJECT(ec->htmlwidget),
-			   "on_url", G_CALLBACK(gui_url),
-			   NULL);
-
-
-	gui_note_toolbar_style(d);	
-	gtk_box_pack_start(GTK_BOX(vbox_toolbars),
-			   ec->toolbar_style, FALSE, FALSE,
-			   0);			   
-	gtk_widget_show(ec->toolbar_style);
-
-
-	gui_note_toolbar_edit(d);
-	gtk_box_pack_start(GTK_BOX(vbox_toolbars),
-			   ec->toolbar_edit, FALSE, FALSE,
-			   0);
-	gtk_widget_show(ec->toolbar_edit);
-
+	d->editor = (GSHTMLEditorControlData *) 
+				editor_new(vbox,PERCOM,NULL);
 
 
 	g_signal_connect(GTK_OBJECT(d->dialog), "destroy",
 			   G_CALLBACK(on_dialog_destroy), d);
-	g_signal_connect(GTK_OBJECT(d->dialog),
-			   "motion_notify_event",
-			   G_CALLBACK
-			   (on_dialog_motion_notify_event), d);	
 }
 
 /***** menu stuff *****/
-/******************************************************************************
- * Name
- *  gui_new_activate
- *
- * Synopsis
- *   #include "editor_menu.h"
- *
- *   void gui_new_activate(GtkMenuItem * menuitem, 
- *					GSHTMLEditorControlData * ecd)	
- *
- * Description
- *    ask to save old file if needed then create new
- *
- * Return value
- *   void
- */
-
-static void gui_new_activate(GtkMenuItem * menuitem,
-		      DIALOG_DATA * d)
-{
-	gchar *filename = NULL;
-	gchar *buf = NULL;
-	gint test;
-	GS_DIALOG *info;
-	GString *str;
-	GSHTMLEditorControlData * ecd = (GSHTMLEditorControlData *) d->editor;
-	/* 
-	 * if study pad file has changed let's ask about saving it 
-	 */
-	if (ecd->changed) {
-		str = g_string_new("");
-		info = gui_new_dialog();
-		info->stock_icon = GTK_STOCK_DIALOG_WARNING;
-		if (settings.studypadfilename)
-			buf = settings.studypadfilename;
-		else
-			buf = N_("File");
-		g_string_printf(str,
-			"<span weight=\"bold\">%s</span>\n\n%s",
-			buf,
-			"has been modified. Do you wish to save it?");
-		info->label_top = str->str;
-		info->yes = TRUE;
-		info->no = TRUE;
-
-		test = gui_alert_dialog(info);
-		if (test == GS_YES) {
-			if (settings.studypadfilename) {
-				filename = g_strdup(settings.studypadfilename);
-				save_file(filename, ecd);
-			} else {
-				gui_fileselection_save(ecd,TRUE);
-			}
-		}
-		settings.modifiedSP = FALSE;
-		g_free(info);
-		g_string_free(str,TRUE);
-	}
-	
-	
-	settings.studypadfilename = NULL;
-	xml_set_value("GnomeSword", "studypad", "lastfile", 
-							NULL);
-	
-	sprintf(ecd->filename, "%s", "");
-	ecd->filename[0] = '\0';
-	gtk_html_select_all(ecd->html);
-	gtk_html_cut(ecd->html);
-	gtk_statusbar_push(GTK_STATUSBAR(ecd->statusbar), 1,
-			   _("-untitled-"));
-	ecd->changed = FALSE;
-}
-
-/******************************************************************************
- * Name
- *  on_open_activate
- *
- * Synopsis
- *   #include "editor_menu.h"
- *
- *   void on_open_activate(GtkMenuItem * menuitem,
-					GSHTMLEditorControlData * ecd)	
- *
- * Description
- *    open a file into notepad
- *
- * Return value
- *   void
- */
-
-static void on_open_activate(GtkMenuItem * menuitem,
-			     DIALOG_DATA * d)
-{
-	GtkWidget *openFile;
-	gchar buf[255];
-	gchar *tmp_buf = NULL;
-	GString *str;
-	gchar *filename = NULL;
-	GSHTMLEditorControlData * ecd = (GSHTMLEditorControlData *) d->editor;
-	/* 
-	 * if study pad file has changed let's ask about saving it 
-	 */
-	if (ecd->changed) {
-		GS_DIALOG *info;
-		gint test;
-
-		str = g_string_new("");
-		info = gui_new_dialog();
-		info->stock_icon = GTK_STOCK_DIALOG_WARNING;
-		if (settings.studypadfilename)
-			tmp_buf = settings.studypadfilename;
-		else
-			tmp_buf = N_("File");
-		g_string_printf(str,
-			"<span weight=\"bold\">%s</span>\n\n%s",
-			tmp_buf,
-			"has been modified. Do you wish to save it?");
-		info->label_top = str->str;
-		info->yes = TRUE;
-		info->no = TRUE;
-
-		test = gui_gs_dialog(info);
-		if (test == GS_YES) {
-			if (settings.studypadfilename) {
-				filename = g_strdup(settings.studypadfilename);
-				save_file(filename, ecd);
-			} else {
-				gui_fileselection_save(ecd,TRUE);
-			}
-		}
-		g_free(info);
-		g_string_free(str,TRUE);
-	}
-	sprintf(buf, "%s/*.pad", settings.studypaddir);
-	openFile = gui_fileselection_open(ecd);
-	gtk_file_selection_set_filename(GTK_FILE_SELECTION(openFile),
-					buf);
-	gtk_widget_show(openFile);
-}
 
 /******************************************************************************
  * Name
@@ -875,7 +678,7 @@ static void on_deletenote_activate(GtkMenuItem * menuitem,
 			url = g_strdup_printf(	"sword://%s/%s",
 						ecd->filename,
 						ecd->key);
-			main_dialog_goto_bookmark(url);
+			//main_dialog_goto_bookmark(url);
 			g_free(url);
 		}
 		settings.percomverse = ecd->key;
@@ -1186,7 +989,7 @@ static void set_link_to_module(gchar * linkref, gchar * linkmod,
 		url_copy =
 		    target ? g_strndup(url,
 				       target - url) : g_strdup(url);
-		new_link =
+/*		new_link =
 		    html_link_text_new(text,
 				       GTK_HTML_FONT_STYLE_DEFAULT,
 				       html_colorset_get_color(e->
@@ -1195,7 +998,7 @@ static void set_link_to_module(gchar * linkref, gchar * linkmod,
 							HTMLLinkColor),
 				       url_copy, target);
 		html_engine_paste_object(e, new_link,
-					 g_utf8_strlen(text, -1));
+					 g_utf8_strlen(text, -1));*/
 		g_free(url_copy);
 	}
 }
@@ -1220,7 +1023,7 @@ static void set_link_to_module(gchar * linkref, gchar * linkmod,
 static void on_link_activate(GtkMenuItem * menuitem,
 			     DIALOG_DATA * d)
 {
-	GSHTMLEditorControlData * ecd = (GSHTMLEditorControlData *) d->editor;
+/*	GSHTMLEditorControlData * ecd = (GSHTMLEditorControlData *) d->editor;
 	gint test;
 	GS_DIALOG *info;
 	GString *str;
@@ -1238,9 +1041,9 @@ static void on_link_activate(GtkMenuItem * menuitem,
 	info->label2 = N_("Module: ");
 	info->ok = TRUE;
 	info->cancel = TRUE;
-	/*
-	 * get selected text  
-	 */
+	
+	// * get selected text *
+	
 	if (html_engine_is_selection_active(ecd->html->engine)) {
 		gchar *buf;
 		buf =
@@ -1248,7 +1051,7 @@ static void on_link_activate(GtkMenuItem * menuitem,
 		info->text1 = g_strdup(buf);
 	}
 	info->text2 = g_strdup(xml_get_value("modules", "bible"));//settings.MainWindowModule);
-	/*** open dialog to get name for list ***/
+	// *** open dialog to get name for list ***
 	test = gui_gs_dialog(info);
 	if (test == GS_OK) {
 		if (strlen(info->text1) > 0) {
@@ -1262,6 +1065,7 @@ static void on_link_activate(GtkMenuItem * menuitem,
 	g_free(info->text2);
 	g_free(info);
 	g_string_free(str,TRUE);
+*/
 }
 
 /******************************************************************************
@@ -1467,8 +1271,8 @@ static GtkWidget *create_menu(DIALOG_DATA * d)
 			   G_CALLBACK(on_paste_activate), (DIALOG_DATA *) d);
 
 #ifdef USE_SPELL
-	g_signal_connect(GTK_OBJECT(spell), "activate",
-			   G_CALLBACK(spell_check_cb), (DIALOG_DATA *) d);
+/*	g_signal_connect(GTK_OBJECT(spell), "activate",
+			   G_CALLBACK(spell_check_cb), (DIALOG_DATA *) d);*/
 #endif	/* USE_SPELL */
 	g_signal_connect(GTK_OBJECT(undo), "activate",
 			   G_CALLBACK(on_undo_activate), (DIALOG_DATA *) d);
