@@ -60,7 +60,7 @@ typedef enum {
 	SHOW_SPLASH_SCREEN,
 	SHOW_BIBLE_PANE,
 	SHOW_COMMENTARY_PANE,
-	SHOW_LOWER_WORKBOOK,
+	SHOW_DICTIONARY_PANE,
 	SHOW_IN_VIEWER,
 	SHOW_IN_DICTIONARY,
 	SHOW_DEVOTION,
@@ -145,27 +145,11 @@ struct _preferences_check_buttons {
 
 	GtkWidget *show_bible_pane;
 	GtkWidget *show_commentary_pane;
-	GtkWidget *show_lower_workbook;
-
-	//GtkWidget *show_favorites;
-	//GtkWidget *show_text_group;
-	//GtkWidget *show_commentary_group;
-	//GtkWidget *show_dictionary_group;
-	//GtkWidget *show_book_group;
-	//GtkWidget *show_history_group;
-	//GtkWidget *dock_shortcut_bar;
+	GtkWidget *show_dictionary_pane;
 
 	GtkWidget *show_in_viewer;
 	GtkWidget *show_in_dictionary;
 	GtkWidget *show_devotion;
-	//GtkWidget *percomm_formatting;
-	//GtkWidget *use_studypad;
-	//GtkWidget *use_studypad_dialog;
-	//GtkWidget *use_percomm_dialog;
-
-	//GtkWidget *commentary_in_dialog;
-	//GtkWidget *dictionary_in_dialog;
-	//GtkWidget *book_in_dialog;
 };
 
 
@@ -563,66 +547,7 @@ static void on_button_toggled(GtkToggleButton * togglebutton,
 			      gpointer user_data)
 {
 	switch (GPOINTER_TO_INT(user_data)) {
-	case SHOW_BIBLE_TABS:
-		if (togglebutton->active)
-			xml_set_value("GnomeSword", "tabs", "bible",
-				      "1");
-		else
-			xml_set_value("GnomeSword", "tabs", "bible",
-				      "0");
-		settings.text_tabs =
-		    atoi(xml_get_value("tabs", "bible"));
-		gtk_notebook_set_show_tabs(GTK_NOTEBOOK
-					   (widgets.notebook_text),
-					   settings.text_tabs);
-/*		if (settings.havebible)
-			gui_set_text_frame_label(cur_t);*/
-		break;
-	case SHOW_COMMENTARY_TABS:
-		if (togglebutton->active)
-			xml_set_value("GnomeSword", "tabs", "comm",
-				      "1");
-		else
-			xml_set_value("GnomeSword", "tabs", "comm",
-				      "0");
-		settings.comm_tabs =
-		    atoi(xml_get_value("tabs", "comm"));
-		/*gtk_notebook_set_show_tabs(GTK_NOTEBOOK
-					   (widgets.notebook_comm),
-					   settings.comm_tabs);*/
-		/*if (settings.havecomm)
-			gui_set_comm_frame_label(settings.CommWindowModule);*/
-		break;
-	case SHOW_DICTIONARY_TABS:
-		if (togglebutton->active)
-			xml_set_value("GnomeSword", "tabs", "dict",
-				      "1");
-		else
-			xml_set_value("GnomeSword", "tabs", "dict",
-				      "0");
-		settings.dict_tabs =
-		    atoi(xml_get_value("tabs", "dict"));
-		gtk_notebook_set_show_tabs(GTK_NOTEBOOK
-					   (widgets.notebook_dict),
-					   settings.dict_tabs);
-//		if (settings.havedict)
-//			gui_set_dict_frame_label();
-		break;
-	case SHOW_BOOK_TABS:
-		if (togglebutton->active)
-			xml_set_value("GnomeSword", "tabs", "book",
-				      "1");
-		else
-			xml_set_value("GnomeSword", "tabs", "book",
-				      "0");
-		settings.book_tabs =
-		    atoi(xml_get_value("tabs", "book"));
-		gtk_notebook_set_show_tabs(GTK_NOTEBOOK
-					   (widgets.notebook_gbs),
-					   settings.book_tabs);
-//		if (settings.havebook)
-//			gui_set_gbs_frame_label();
-		break;
+	
 	case USE_DEFAULT_DICTIONARY:
 		if (togglebutton->active)
 			xml_set_value("GnomeSword", "lexicons",
@@ -682,7 +607,7 @@ static void on_button_toggled(GtkToggleButton * togglebutton,
 		    settings.showcomms;
 		gui_set_bible_comm_layout();
 		break;
-	case SHOW_LOWER_WORKBOOK:
+	case SHOW_DICTIONARY_PANE:
 		if (togglebutton->active)
 			xml_set_value("GnomeSword", "misc", "showdicts",
 				      "1");
@@ -695,28 +620,6 @@ static void on_button_toggled(GtkToggleButton * togglebutton,
 		    settings.showdicts;
 		gui_set_bible_comm_layout();
 		break;
-	case SHOW_IN_VIEWER:
-		if (GTK_TOGGLE_BUTTON(check_button.show_in_viewer)->
-		    active)
-			xml_set_value("GnomeSword", "lexicons",
-				      "inviewer", "1");
-		else
-			xml_set_value("GnomeSword", "lexicons",
-				      "inviewer", "0");
-		settings.inViewer =
-		    atoi(xml_get_value("lexicons", "inviewer"));
-		break;
-	case SHOW_IN_DICTIONARY:
-		if (GTK_TOGGLE_BUTTON(check_button.show_in_dictionary)->
-		    active)
-			xml_set_value("GnomeSword", "lexicons",
-				      "indictpane", "1");
-		else
-			xml_set_value("GnomeSword", "lexicons",
-				      "indictpane", "0");
-		settings.inDictpane =
-		    atoi(xml_get_value("lexicons", "indictpane"));
-		break;
 	case SHOW_DEVOTION:
 		if (GTK_TOGGLE_BUTTON(check_button.show_devotion)->
 		    active)
@@ -734,7 +637,8 @@ static void on_button_toggled(GtkToggleButton * togglebutton,
 			xml_set_value("GnomeSword", "tabs", "browsing",
 				      "1");
 			settings.browsing = TRUE;
-			gui_notebook_main_setup(NULL);
+			//gui_notebook_main_setup();
+			gui_open_tabs();
 			gtk_widget_show(widgets.hboxtb);
 		} else {
 			xml_set_value("GnomeSword", "tabs", "browsing",
@@ -746,42 +650,7 @@ static void on_button_toggled(GtkToggleButton * togglebutton,
 		settings.browsing =
 		    atoi(xml_get_value("tabs", "browsing"));
 		break;
-
-		/*
-		   case USE_STUDYPAD:   
-		   if (GTK_TOGGLE_BUTTON(check_button.use_studypad)->active)
-		   xml_set_value("GnomeSword", "editor", "UseStudyPad",
-		   "1");
-		   else
-		   xml_set_value("GnomeSword", "editor", "UseStudyPad",
-		   "0");
-		   settings.use_studypad =
-		   atoi(xml_get_value("editor", "UseStudyPad"));
-		   break;
-		   case USE_STUDYPAD_DIALOG:    
-		   if (GTK_TOGGLE_BUTTON(check_button.use_studypad_dialog)->active)
-		   xml_set_value("GnomeSword", "editor",
-		   "UseStudypadDialog", "1");
-		   else
-		   xml_set_value("GnomeSword", "editor",
-		   "UseStudypadDialog", "0");
-		   settings.use_studypad_dialog =
-		   atoi(xml_get_value("editor", "UseStudypadDialog"));
-		   break;
-		   case USE_PERCOMM_DIALOG:
-		   if (GTK_TOGGLE_BUTTON(check_button.use_percomm_dialog)->active)
-		   xml_set_value("GnomeSword", "editor",
-		   "UsePercommDialog", "1");
-		   else
-		   xml_set_value("GnomeSword", "editor",
-		   "UsePercommDialog", "0");
-		   settings.use_percomm_dialog =
-		   atoi(xml_get_value("editor", "UsePercommDialog"));
-		   break; */
 	}
-	xml_set_value("GnomeSword", "editor", "UseStudyPad", "1");
-	xml_set_value("GnomeSword", "editor", "UseStudypadDialog", "1");
-	xml_set_value("GnomeSword", "editor", "UsePercommDialog", "1");
 }
 
 
@@ -1178,8 +1047,7 @@ static GtkWidget *gui_create_preferences_dialog(GList * biblelist,
 	gtk_window_set_title(GTK_WINDOW(dialog_prefs),
 			     _("Preferences"));
 	gtk_window_set_default_size(GTK_WINDOW(dialog_prefs), 600, 345);
-	gtk_window_set_policy(GTK_WINDOW(dialog_prefs), TRUE, TRUE,
-			      FALSE);
+	gtk_window_set_resizable(GTK_WINDOW(dialog_prefs), TRUE);
 	gtk_dialog_set_has_separator(GTK_DIALOG(dialog_prefs), FALSE);
 	gtk_container_set_border_width(GTK_CONTAINER(dialog_prefs), 12);
 
@@ -1203,6 +1071,8 @@ static GtkWidget *gui_create_preferences_dialog(GList * biblelist,
 				       (scrolledwindow_treeview),
 				       GTK_POLICY_NEVER,
 				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow_treeview,
+                                             settings.shadow_type);
 
 	model = create_model();
 	treeview = gtk_tree_view_new_with_model(model);
@@ -1308,6 +1178,8 @@ static GtkWidget *gui_create_preferences_dialog(GList * biblelist,
 				       (scrolledwindow56),
 				       GTK_POLICY_NEVER,
 				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow56,
+                                             0);
 
 	viewport9 = gtk_viewport_new(NULL, NULL);
 	gtk_widget_show(viewport9);
@@ -1744,23 +1616,23 @@ static GtkWidget *gui_create_preferences_dialog(GList * biblelist,
 	gtk_tooltips_set_tip(tooltips,
 			     check_button.show_commentary_pane,
 			     _
-			     ("Commentaries, Personal Comments and StudyPad"),
+			     ("Display Commentary window"),
 			     NULL);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
 				     (check_button.
 				      show_commentary_pane), TRUE);
 
-	check_button.show_lower_workbook =
-	    gtk_check_button_new_with_label(_("Lower workbook"));
-	gtk_widget_show(check_button.show_lower_workbook);
+	check_button.show_dictionary_pane =
+	    gtk_check_button_new_with_label(_("Dictionary/Lexicon"));
+	gtk_widget_show(check_button.show_dictionary_pane);
 	gtk_box_pack_start(GTK_BOX(vbox86),
-			   check_button.show_lower_workbook, FALSE,
+			   check_button.show_dictionary_pane, FALSE,
 			   FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, check_button.show_lower_workbook,
-			     _("Dictionary/Lexicon and generic books"),
+	gtk_tooltips_set_tip(tooltips, check_button.show_dictionary_pane,
+			     _("Dictionary/Lexicon"),
 			     NULL);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
-				     (check_button.show_lower_workbook),
+				     (check_button.show_dictionary_pane),
 				     TRUE);
 
 /* end tabs and panes page */
@@ -1862,7 +1734,7 @@ static GtkWidget *gui_create_preferences_dialog(GList * biblelist,
 
 	gtk_frame_set_label_widget(GTK_FRAME(frame41), label805);
 
-	gtk_widget_show(frame41);
+//	gtk_widget_show(frame41);
 	gtk_box_pack_start(GTK_BOX(vbox28), frame41, TRUE, FALSE, 6);
 
 	vbox53 = gtk_vbox_new(FALSE, 0);
@@ -1874,7 +1746,7 @@ static GtkWidget *gui_create_preferences_dialog(GList * biblelist,
 
 	check_button.show_in_viewer =
 	    gtk_check_button_new_with_label(_("In Sidebar viewer"));
-	gtk_widget_show(check_button.show_in_viewer);
+//	gtk_widget_show(check_button.show_in_viewer);
 	gtk_box_pack_start(GTK_BOX(vbox53), check_button.show_in_viewer,
 			   FALSE, FALSE, 0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
@@ -1884,7 +1756,7 @@ static GtkWidget *gui_create_preferences_dialog(GList * biblelist,
 	check_button.show_in_dictionary =
 	    gtk_check_button_new_with_label(_
 					    ("In Dictionary/Lexicon window"));
-	gtk_widget_show(check_button.show_in_dictionary);
+//	gtk_widget_show(check_button.show_in_dictionary);
 	gtk_box_pack_start(GTK_BOX(vbox53),
 			   check_button.show_in_dictionary, FALSE,
 			   FALSE, 0);
@@ -2282,21 +2154,21 @@ static GtkWidget *gui_create_preferences_dialog(GList * biblelist,
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
 
 	label = gtk_label_new(_("Hebrew Lexicon Viewer"));
-	gtk_widget_show(label);
+//	gtk_widget_show(label);
 	gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
 	gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT);
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
 	gtk_misc_set_padding(GTK_MISC(label), 12, 0);
 
 	comboHebViewer = gtk_combo_new();
-	gtk_widget_show(comboHebViewer);
+//	gtk_widget_show(comboHebViewer);
 	gtk_box_pack_start(GTK_BOX(hbox), comboHebViewer, FALSE, TRUE,
 			   0);
 	gtk_widget_set_size_request(comboHebViewer, 209, -1);
 
 	entry.hebrew_lex_viewer_module =
 	    GTK_COMBO(comboHebViewer)->entry;
-	gtk_widget_show(entry.hebrew_lex_viewer_module);
+//	gtk_widget_show(entry.hebrew_lex_viewer_module);
 	gtk_tooltips_set_tip(tooltips, entry.hebrew_lex_viewer_module,
 			     _
 			     ("Which Hebrew Lexicon to display in viewer when a link or word is clicked"),
@@ -2330,21 +2202,21 @@ static GtkWidget *gui_create_preferences_dialog(GList * biblelist,
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
 
 	label = gtk_label_new(_("Greek Lexicon Viewer"));
-	gtk_widget_show(label);
+//	gtk_widget_show(label);
 	gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
 	gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT);
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
 	gtk_misc_set_padding(GTK_MISC(label), 12, 0);
 
 	comboGreekViewer = gtk_combo_new();
-	gtk_widget_show(comboGreekViewer);
+	//gtk_widget_show(comboGreekViewer);
 	gtk_box_pack_start(GTK_BOX(hbox), comboGreekViewer, FALSE, TRUE,
 			   0);
 	gtk_widget_set_size_request(comboGreekViewer, 209, -1);
 
 	entry.greek_lex_viewer_module =
 	    GTK_COMBO(comboGreekViewer)->entry;
-	gtk_widget_show(entry.greek_lex_viewer_module);
+	//gtk_widget_show(entry.greek_lex_viewer_module);
 	gtk_tooltips_set_tip(tooltips, entry.greek_lex_viewer_module,
 			     _
 			     ("Which Greek Lexicon to display in viewer when a link or word is clicked"),
@@ -2400,12 +2272,12 @@ static GtkWidget *gui_create_preferences_dialog(GList * biblelist,
 		gtk_combo_set_popdown_strings(GTK_COMBO
 					      (comboDefaultDict),
 					      dictlist);
-		gtk_combo_set_popdown_strings(GTK_COMBO
+		/*gtk_combo_set_popdown_strings(GTK_COMBO
 					      (comboGreekViewer),
 					      dictlist);
-		gtk_combo_set_popdown_strings(GTK_COMBO(combo26),
-					      dictlist);
 		gtk_combo_set_popdown_strings(GTK_COMBO(comboHebViewer),
+					      dictlist);*/
+		gtk_combo_set_popdown_strings(GTK_COMBO(combo26),
 					      dictlist);
 		gtk_combo_set_popdown_strings(GTK_COMBO(combo27),
 					      dictlist);
@@ -2428,7 +2300,7 @@ static GtkWidget *gui_create_preferences_dialog(GList * biblelist,
 	else
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
 					     (rbtnNoDefaults), TRUE);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
+/*	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
 				     (check_button.show_bible_tabs),
 				     settings.text_tabs);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
@@ -2441,7 +2313,7 @@ static GtkWidget *gui_create_preferences_dialog(GList * biblelist,
 				     settings.dict_tabs);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
 				     (check_button.show_book_tabs),
-				     settings.book_tabs);
+				     settings.book_tabs);*/
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
 				     (check_button.use_verse_style),
 				     settings.versestyle);
@@ -2456,7 +2328,7 @@ static GtkWidget *gui_create_preferences_dialog(GList * biblelist,
 				      show_commentary_pane),
 				     settings.showcomms);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
-				     (check_button.show_lower_workbook),
+				     (check_button.show_dictionary_pane),
 				     settings.showdicts);
 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
@@ -2473,13 +2345,13 @@ static GtkWidget *gui_create_preferences_dialog(GList * biblelist,
 	   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
 	   (check_button.use_percomm_dialog),
 	   settings.use_percomm_dialog);
-	 */
+	 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
 				     (check_button.show_in_viewer),
 				     settings.inViewer);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
 				     (check_button.show_in_dictionary),
-				     settings.inDictpane);
+				     settings.inDictpane);*/
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
 				     (check_button.
 				      use_default_dictionary),
@@ -2656,10 +2528,10 @@ static GtkWidget *gui_create_preferences_dialog(GList * biblelist,
 			 "toggled",
 			 G_CALLBACK(on_button_toggled),
 			 GINT_TO_POINTER(SHOW_COMMENTARY_PANE));
-	g_signal_connect(GTK_OBJECT(check_button.show_lower_workbook),
+	g_signal_connect(GTK_OBJECT(check_button.show_dictionary_pane),
 			 "toggled",
 			 G_CALLBACK(on_button_toggled),
-			 GINT_TO_POINTER(SHOW_LOWER_WORKBOOK));
+			 GINT_TO_POINTER(SHOW_DICTIONARY_PANE));
 /*
 	g_signal_connect(GTK_OBJECT(check_button.use_studypad),
 			   "toggled",
