@@ -25,7 +25,11 @@
 
 #include <gnome.h>
 #include <gtkhtml/gtkhtml.h>
+/*
+#ifdef USE_GTKHTML30
 #include <gal/widgets/e-unicode.h>
+#endif
+*/
 #include <regex.h>
 #include <string.h>
 #include <glib.h>
@@ -41,8 +45,6 @@
 #include "main/lists.h"
 #include "main/settings.h"
 #include "main/sword.h"
-#include "main/commentary.h"
-#include "main/bibletext.h"
 #include "main/xml.h"
 
 #define SEARCHING N_("Searching the ")
@@ -54,7 +56,7 @@
 
 
 
-SEARCH_DIALOG search;
+SEARCH_DIALOG1 search1;
 
 
 
@@ -79,30 +81,30 @@ static void button_clean(GtkButton * button, gpointer user_data)
 {
 	gboolean editable;
 
-	editable = gtk_html_get_editable(GTK_HTML(search.report_html));
+	editable = gtk_html_get_editable(GTK_HTML(search1.report_html));
 	if (!editable)
-		gtk_html_set_editable(GTK_HTML(search.report_html),
+		gtk_html_set_editable(GTK_HTML(search1.report_html),
 				      TRUE);
-	gtk_html_select_all(GTK_HTML(search.report_html));
-	gtk_html_cut(GTK_HTML(search.report_html));
-	gtk_html_set_editable(GTK_HTML(search.report_html), editable);
+	gtk_html_select_all(GTK_HTML(search1.report_html));
+	gtk_html_cut(GTK_HTML(search1.report_html));
+	gtk_html_set_editable(GTK_HTML(search1.report_html), editable);
 
 
-	editable = gtk_html_get_editable(GTK_HTML(search.results_html));
+	editable = gtk_html_get_editable(GTK_HTML(search1.results_html));
 	if (!editable)
-		gtk_html_set_editable(GTK_HTML(search.results_html),
+		gtk_html_set_editable(GTK_HTML(search1.results_html),
 				      TRUE);
-	gtk_html_select_all(GTK_HTML(search.results_html));
-	gtk_html_cut(GTK_HTML(search.results_html));
-	gtk_html_set_editable(GTK_HTML(search.results_html), editable);
+	gtk_html_select_all(GTK_HTML(search1.results_html));
+	gtk_html_cut(GTK_HTML(search1.results_html));
+	gtk_html_set_editable(GTK_HTML(search1.results_html), editable);
 
-	editable = gtk_html_get_editable(GTK_HTML(search.preview_html));
+	editable = gtk_html_get_editable(GTK_HTML(search1.preview_html));
 	if (!editable)
-		gtk_html_set_editable(GTK_HTML(search.preview_html),
+		gtk_html_set_editable(GTK_HTML(search1.preview_html),
 				      TRUE);
-	gtk_html_select_all(GTK_HTML(search.preview_html));
-	gtk_html_cut(GTK_HTML(search.preview_html));
-	gtk_html_set_editable(GTK_HTML(search.preview_html), editable);
+	gtk_html_select_all(GTK_HTML(search1.preview_html));
+	gtk_html_cut(GTK_HTML(search1.preview_html));
+	gtk_html_set_editable(GTK_HTML(search1.preview_html), editable);
 
 
 }
@@ -150,7 +152,7 @@ static void button_save(GtkButton * button, gpointer user_data)
 static void on_destroy(GtkWidget * dialog, gpointer user_data)
 {
 	main_close_search_dialog();
-	gtk_widget_destroy(search.dialog);
+	gtk_widget_destroy(search1.dialog);
 }
 
 
@@ -201,7 +203,7 @@ static void on_button_begin_search(GtkButton * button,
 static void on_togglebutton_show_main(GtkToggleButton * togglebutton,
 				      gpointer user_data)
 {
-	search.show_in_main = togglebutton->active;
+	search1.show_in_main = togglebutton->active;
 }
 
 
@@ -282,7 +284,7 @@ static void url(GtkHTML * html, const gchar * url, gpointer data)
 				str = g_strdup(" ");
 			
 			gnome_appbar_set_status(GNOME_APPBAR
-						(search.
+						(search1.
 						 progressbar),
 						str);
 			g_free(str);
@@ -361,19 +363,18 @@ static void link_clicked(GtkHTML * html, const gchar * url,
 		
 		switch(GPOINTER_TO_INT(data)) {
 		case 0:
-			if (GTK_TOGGLE_BUTTON(search.togglebutton_show_main)->
+			if (search1.show_in_main || GTK_TOGGLE_BUTTON(search1.togglebutton_show_main)->
 			    active) {
 				main_url_handler(url2,TRUE); //gui_change_module_and_key(modbuf, buf);
 	
-			}	
-			text = main_get_rendered_text(modbuf, buf);
+			}
+						
+			text = main_get_search_rendered_text(modbuf, buf);
 			if (text) {
-				main_entry_display(search.preview_html, modbuf,
+				main_entry_display(search1.preview_html, modbuf,
 				      text, buf, TRUE);
 				free(text);
 			}
-			if (search.show_in_main)
-				main_url_handler(url2,TRUE); //gui_change_module_and_key(modbuf, buf);
 			break;
 		case 1:
 				main_url_handler(url2,TRUE); //gui_change_module_and_key(modbuf, buf);
@@ -408,7 +409,7 @@ static void link_clicked(GtkHTML * html, const gchar * url,
 static void report_link_clicked(GtkHTML * html, const gchar * url,
 				gpointer data)
 {
-	gtk_html_jump_to_anchor(GTK_HTML(search.results_html), url);
+	gtk_html_jump_to_anchor(GTK_HTML(search1.results_html), url);
 }
 
 
@@ -440,10 +441,10 @@ static void list_name_changed(GtkEditable * editable,
 	GtkTreeIter selected;
 
 	model =
-	    gtk_tree_view_get_model(GTK_TREE_VIEW(search.module_lists));
+	    gtk_tree_view_get_model(GTK_TREE_VIEW(search1.module_lists));
 	list_store = GTK_LIST_STORE(model);
 	selection = gtk_tree_view_get_selection
-	    (GTK_TREE_VIEW(search.module_lists));
+	    (GTK_TREE_VIEW(search1.module_lists));
 
 	if (!gtk_tree_selection_get_selected
 	    (selection, NULL, &selected))
@@ -484,10 +485,10 @@ static void range_name_changed(GtkEditable * editable,
 
 	model =
 	    gtk_tree_view_get_model(GTK_TREE_VIEW
-				    (search.list_range_name));
+				    (search1.list_range_name));
 	list_store = GTK_LIST_STORE(model);
 	selection = gtk_tree_view_get_selection
-	    (GTK_TREE_VIEW(search.list_range_name));
+	    (GTK_TREE_VIEW(search1.list_range_name));
 
 	if (!gtk_tree_selection_get_selected
 	    (selection, NULL, &selected))
@@ -497,8 +498,8 @@ static void range_name_changed(GtkEditable * editable,
 	text = gtk_entry_get_text(GTK_ENTRY(editable));
 	gtk_list_store_set(list_store, &selected, 0, text, -1);
 /*
-	gtk_clist_set_text((GtkCList *) search.list_range_name,
-			   search.custom_range_row, 0, text);
+	gtk_clist_set_text((GtkCList *) search1.list_range_name,
+			   search1.custom_range_row, 0, text);
 	*/
 }
 
@@ -556,31 +557,31 @@ static void new_modlist(GtkButton * button, gpointer user_data)
 	GtkTreePath *path;
 
 	selection = gtk_tree_view_get_selection
-	    (GTK_TREE_VIEW(search.module_lists));
+	    (GTK_TREE_VIEW(search1.module_lists));
 
 
 	model =
 	    gtk_tree_view_get_model(GTK_TREE_VIEW
-				    (search.listview_modules));
+				    (search1.listview_modules));
 	list_store = GTK_LIST_STORE(model);
 
 	model2 =
-	    gtk_tree_view_get_model(GTK_TREE_VIEW(search.module_lists));
+	    gtk_tree_view_get_model(GTK_TREE_VIEW(search1.module_lists));
 	list_store2 = GTK_LIST_STORE(model2);
 
-	sprintf(buf, "New List%d", search.list_rows);
+	sprintf(buf, "New List%d", search1.list_rows);
 
-	search.module_count = 0;
+	search1.module_count = 0;
 	gtk_list_store_clear(list_store);
 
 	gtk_list_store_append(list_store2, &iter);
 	gtk_list_store_set(list_store2, &iter, 0, buf, -1);
 	path = gtk_tree_model_get_path(model2, &iter);
 	gtk_tree_selection_select_path(selection, path);
-	/*search.custom_list_row = gtk_clist_append((GtkCList *) search.
+	/*search1.custom_list_row = gtk_clist_append((GtkCList *) search1.
 	   module_lists, text); */
-	//search.list_rows = search.custom_list_row;
-	gtk_entry_set_text(GTK_ENTRY(search.entry_list_name), buf);
+	//search1.list_rows = search1.custom_list_row;
+	gtk_entry_set_text(GTK_ENTRY(search1.entry_list_name), buf);
 	gtk_tree_path_free(path);
 }
 
@@ -600,6 +601,7 @@ static void new_modlist(GtkButton * button, gpointer user_data)
  * Return value
  *   void
  */
+//gtk_widget_set_sensitive
 
 static void clear_modules(GtkButton * button, gpointer user_data)
 {
@@ -612,10 +614,10 @@ static void clear_modules(GtkButton * button, gpointer user_data)
 	GString *str;
 
 	selection = gtk_tree_view_get_selection
-	    (GTK_TREE_VIEW(search.module_lists));
+	    (GTK_TREE_VIEW(search1.module_lists));
 	model =
 	    gtk_tree_view_get_model(GTK_TREE_VIEW
-				    (search.listview_modules));
+				    (search1.listview_modules));
 	list_store = GTK_LIST_STORE(model);
 
 	str = g_string_new("");
@@ -639,7 +641,7 @@ static void clear_modules(GtkButton * button, gpointer user_data)
 	gtk_list_store_clear(list_store);
 
 	model =
-	    gtk_tree_view_get_model(GTK_TREE_VIEW(search.module_lists));
+	    gtk_tree_view_get_model(GTK_TREE_VIEW(search1.module_lists));
 	list_store = GTK_LIST_STORE(model);
 	if (gtk_tree_selection_get_selected(selection, NULL, &selected))
 		gtk_list_store_set(list_store, &selected, 1, "", -1);
@@ -666,7 +668,7 @@ static void clear_modules(GtkButton * button, gpointer user_data)
 
 static void delete_module(GtkButton * button, gpointer user_data)
 {
-	main_delete_module(GTK_TREE_VIEW(search.listview_modules));
+	main_delete_module(GTK_TREE_VIEW(search1.listview_modules));
 }
 
 
@@ -720,10 +722,10 @@ static void new_range(GtkButton * button, gpointer user_data)
 
 	model =
 	    gtk_tree_view_get_model(GTK_TREE_VIEW
-				    (search.list_range_name));
+				    (search1.list_range_name));
 	list_store = GTK_LIST_STORE(model);
 	selection = gtk_tree_view_get_selection
-	    (GTK_TREE_VIEW(search.list_range_name));
+	    (GTK_TREE_VIEW(search1.list_range_name));
 
 	if (!gtk_tree_selection_get_selected
 	    (selection, NULL, &selected))
@@ -740,8 +742,8 @@ static void new_range(GtkButton * button, gpointer user_data)
 	gtk_tree_selection_select_path(selection, path);
 	gtk_tree_path_free(path);
 
-	gtk_entry_set_text(GTK_ENTRY(search.entry_range_name), text[0]);
-	gtk_entry_set_text(GTK_ENTRY(search.entry_range_text), "");
+	gtk_entry_set_text(GTK_ENTRY(search1.entry_range_name), text[0]);
+	gtk_entry_set_text(GTK_ENTRY(search1.entry_range_text), "");
 }
 
 
@@ -818,10 +820,10 @@ static void delete_list(GtkButton * button, gpointer user_data)
 
 
 	model =
-	    gtk_tree_view_get_model(GTK_TREE_VIEW(search.module_lists));
+	    gtk_tree_view_get_model(GTK_TREE_VIEW(search1.module_lists));
 	list_store = GTK_LIST_STORE(model);
 	selection = gtk_tree_view_get_selection
-	    (GTK_TREE_VIEW(search.module_lists));
+	    (GTK_TREE_VIEW(search1.module_lists));
 
 	if (!gtk_tree_selection_get_selected
 	    (selection, NULL, &selected))
@@ -849,7 +851,7 @@ static void delete_list(GtkButton * button, gpointer user_data)
 
 	gtk_list_store_remove(list_store, &selected);
 	xml_remove_node("modlists", "modlist", name_string);
-	--search.list_rows;
+	--search1.list_rows;
 	save_modlist(NULL, NULL);
 
 	g_free(info);
@@ -879,7 +881,7 @@ static void delete_list(GtkButton * button, gpointer user_data)
 static void scope_toggled(GtkToggleButton * togglebutton,
 			  gpointer user_data)
 {
-	search.which_scope = togglebutton;
+	search1.which_scope = togglebutton;
 }
 
 
@@ -932,16 +934,59 @@ static void current_module_toggled(GtkToggleButton * togglebutton,
 				   gpointer user_data)
 {
 	if (togglebutton->active) {
-		main_change_mods_select_label(search.search_mod);
-		gtk_widget_set_sensitive(search.rb_last, TRUE);
+		main_change_mods_select_label(search1.search_mod);
+		gtk_widget_set_sensitive(search1.rb_last, TRUE);
 	}
 	else {
-		gtk_widget_set_sensitive(search.rb_last, FALSE);
-		gtk_toggle_button_set_active(search.which_scope, TRUE);
+		gtk_widget_set_sensitive(search1.rb_last, FALSE);
+		gtk_toggle_button_set_active(search1.which_scope, TRUE);
 	}
 }
 
 
+/******************************************************************************
+ * Name
+ *   indexed_word_toggled
+ *
+ * Synopsis
+ *   #include "gui/search_dialog.h"
+ *
+ *   void indexed_word_toggled(GtkToggleButton *togglebutton,
+						gpointer user_data)
+ *
+ * Description
+ *   
+ *
+ * Return value
+ *   void
+ */
+
+static void indexed_word_toggled(GtkToggleButton * togglebutton,
+				   gpointer user_data)
+{
+/*	if (togglebutton->active) {
+		//main_change_mods_select_label(search1.search_mod);
+		gtk_widget_set_sensitive(search1.rb_last, FALSE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(search1.rb_no_scope), TRUE);		
+		gtk_widget_set_sensitive(search1.rb_no_scope, FALSE);
+		gtk_widget_set_sensitive(search1.rb_custom_range, FALSE);
+		gtk_widget_set_sensitive(search1.cb_case_sensitive, FALSE);
+		gtk_widget_set_sensitive(search1.cb_include_strongs, FALSE);
+		gtk_widget_set_sensitive(search1.cb_include_morphs, FALSE);
+		gtk_widget_set_sensitive(search1.cb_include_footnotes, FALSE);
+	}
+	else {
+		gtk_widget_set_sensitive(search1.rb_last, TRUE);
+		gtk_widget_set_sensitive(search1.rb_no_scope, TRUE);
+		gtk_widget_set_sensitive(search1.rb_custom_range, TRUE);
+		gtk_widget_set_sensitive(search1.cb_case_sensitive, TRUE);
+		gtk_widget_set_sensitive(search1.cb_include_strongs, TRUE);
+		gtk_widget_set_sensitive(search1.cb_include_morphs, TRUE);
+		gtk_widget_set_sensitive(search1.cb_include_footnotes, TRUE);
+	}*/
+}
+
+
 /******************************************************************************
  * Name
  *   mod_selection_changed
@@ -1020,11 +1065,11 @@ static void selection_range_lists_changed(GtkTreeSelection * selection,
 
 	model =
 	    gtk_tree_view_get_model(GTK_TREE_VIEW
-				    (search.list_range_name));
+				    (search1.list_range_name));
 	gtk_tree_model_get(model, &selected, 0, &name, 1, &range, -1);
 
-	gtk_entry_set_text(GTK_ENTRY(search.entry_range_name), name);
-	gtk_entry_set_text(GTK_ENTRY(search.entry_range_text), range);
+	gtk_entry_set_text(GTK_ENTRY(search1.entry_range_name), name);
+	gtk_entry_set_text(GTK_ENTRY(search1.entry_range_text), range);
 	g_free(name);
 	g_free(range);
 }
@@ -1129,6 +1174,7 @@ GtkWidget *gui_create_search_dialog(void)
 	GtkWidget *rb_words;
 	GtkWidget *tb_regexp;
 	GtkWidget *rb_exact_phrase;
+	//GtkWidget *rb_indexed_word;
 	GtkWidget *frame57;
 	GtkWidget *vbox64;
 	GtkWidget *cb_case_sensitive;
@@ -1221,8 +1267,7 @@ GtkWidget *gui_create_search_dialog(void)
 			     _("Advanced Search"));
 	gtk_window_set_default_size(GTK_WINDOW(search_dialog), 598,
 				    400);
-	gtk_window_set_policy(GTK_WINDOW(search_dialog), TRUE, TRUE,
-			      FALSE);
+	gtk_window_set_resizable(GTK_WINDOW(search_dialog), TRUE);
 
 	hbox_search = gtk_hbox_new(FALSE, 0);
 	gtk_widget_show(hbox_search);
@@ -1479,20 +1524,26 @@ GtkWidget *gui_create_search_dialog(void)
 			   FALSE, 0);
 			   
 	
-	search.rb_attribute = gtk_radio_button_new_with_label_from_widget
+	search1.rb_attributes = gtk_radio_button_new_with_label_from_widget
                                             ((GtkRadioButton *)rb_words,
                                              _("Attributes"));
-	gtk_widget_show(search.rb_attribute);
+	gtk_widget_show(search1.rb_attributes);
 	header = g_strdup_printf("%s:\n%s\n%s",_("examples"),
 				"Word//Strongs/G1722",
 				"Footnote//body/love");
-	gtk_tooltips_set_tip(tooltips, search.rb_attribute,
+	gtk_tooltips_set_tip(tooltips, search1.rb_attributes,
 			     header, NULL);
-	gtk_box_pack_start(GTK_BOX(vbox63), search.rb_attribute, FALSE,
+	gtk_box_pack_start(GTK_BOX(vbox63), search1.rb_attributes, FALSE,
 			   FALSE, 0);	
 	g_free(header);			   
-			   
-
+/*		
+	rb_indexed_word = gtk_radio_button_new_with_label_from_widget
+                                            ((GtkRadioButton *)rb_words,
+                                             _("Indexed"));
+	gtk_widget_show(rb_indexed_word);
+	gtk_box_pack_start(GTK_BOX(vbox63), rb_indexed_word, FALSE,
+			   FALSE, 0);	   
+*/
 	frame57 = gtk_frame_new(NULL);
 	gtk_widget_show(frame57);
 	gtk_box_pack_start(GTK_BOX(hbox74), frame57, TRUE, TRUE, 0);
@@ -1519,31 +1570,31 @@ GtkWidget *gui_create_search_dialog(void)
 	gtk_box_pack_start(GTK_BOX(vbox64), cb_case_sensitive, FALSE,
 			   FALSE, 0);
 
-	search.cb_include_strongs =
+	search1.cb_include_strongs =
 	    gtk_check_button_new_with_label(_
 					    ("Include Strong's Numbers"));
-	gtk_widget_show(search.cb_include_strongs);
-	gtk_box_pack_start(GTK_BOX(vbox64), search.cb_include_strongs,
+	gtk_widget_show(search1.cb_include_strongs);
+	gtk_box_pack_start(GTK_BOX(vbox64), search1.cb_include_strongs,
 			   FALSE, FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, search.cb_include_strongs,
+	gtk_tooltips_set_tip(tooltips, search1.cb_include_strongs,
 			     _("In modules that have Strong's Numbers"),
 			     NULL);
 
-	search.cb_include_morphs =
+	search1.cb_include_morphs =
 	    gtk_check_button_new_with_label(_("Include Morphological Tags"));
-	gtk_widget_show(search.cb_include_morphs);
-	gtk_box_pack_start(GTK_BOX(vbox64), search.cb_include_morphs,
+	gtk_widget_show(search1.cb_include_morphs);
+	gtk_box_pack_start(GTK_BOX(vbox64), search1.cb_include_morphs,
 			   FALSE, FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, search.cb_include_morphs,
+	gtk_tooltips_set_tip(tooltips, search1.cb_include_morphs,
 			     _("In modules that have Morphological Tags"),
 			     NULL);
 
-	search.cb_include_footnotes =
+	search1.cb_include_footnotes =
 	    gtk_check_button_new_with_label(_("Include Footnotes"));
-	gtk_widget_show(search.cb_include_footnotes);
-	gtk_box_pack_start(GTK_BOX(vbox64), search.cb_include_footnotes,
+	gtk_widget_show(search1.cb_include_footnotes);
+	gtk_box_pack_start(GTK_BOX(vbox64), search1.cb_include_footnotes,
 			   FALSE, FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, search.cb_include_footnotes,
+	gtk_tooltips_set_tip(tooltips, search1.cb_include_footnotes,
 			     _("In modules that have Footnotes"), NULL);
 
 	label204 = gtk_label_new(_("Search Criteria"));
@@ -1663,6 +1714,8 @@ GtkWidget *gui_create_search_dialog(void)
 				       (scrolledwindow_report),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow_report,
+                                             settings.shadow_type);
 
 	vbox65 = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(vbox65);
@@ -1694,6 +1747,8 @@ GtkWidget *gui_create_search_dialog(void)
 				       (scrolledwindow_preview),
 				       GTK_POLICY_NEVER,
 				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow_preview,
+                                             settings.shadow_type);
 
 	vbox65 = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(vbox65);
@@ -1724,6 +1779,8 @@ GtkWidget *gui_create_search_dialog(void)
 				       (scrolledwindow_results),
 				       GTK_POLICY_NEVER,
 				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow_results,
+                                             settings.shadow_type);
 
 	appbar_search =
 	    gnome_appbar_new(TRUE, TRUE, GNOME_PREFERENCES_NEVER);
@@ -1808,26 +1865,28 @@ GtkWidget *gui_create_search_dialog(void)
 				       (scrolledwindow67),
 				       GTK_POLICY_NEVER,
 				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow67,
+                                             settings.shadow_type);
 				       
 	/* create tree model */
 	model = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
 
 	/* create tree view */
-	search.list_range_name =
+	search1.list_range_name =
 	    gtk_tree_view_new_with_model(GTK_TREE_MODEL(model));
-	gtk_widget_show(search.list_range_name);
+	gtk_widget_show(search1.list_range_name);
 	gtk_container_add(GTK_CONTAINER(scrolledwindow67),
-			  search.list_range_name);
+			  search1.list_range_name);
 	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW
-				     (search.list_range_name), TRUE);
+				     (search1.list_range_name), TRUE);
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW
-					  (search.list_range_name),
+					  (search1.list_range_name),
 					  FALSE);
-	add_two_text_columns(GTK_TREE_VIEW(search.list_range_name));
+	add_two_text_columns(GTK_TREE_VIEW(search1.list_range_name));
 
 	selection_range_name =
 	    G_OBJECT(gtk_tree_view_get_selection
-		     (GTK_TREE_VIEW(search.list_range_name)));
+		     (GTK_TREE_VIEW(search1.list_range_name)));
 		     
 	vbox76 = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(vbox76);
@@ -1878,12 +1937,14 @@ GtkWidget *gui_create_search_dialog(void)
 				       (scrolledwindow65),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow65,
+                                             settings.shadow_type);
 				       
 	/* create tree model */
 	model = gtk_list_store_new(1, G_TYPE_STRING);
 
 	/* create tree view */
-	search.list_ranges =
+	search1.list_ranges =
 	    gtk_tree_view_new_with_model(GTK_TREE_MODEL(model));
 	renderer = gtk_cell_renderer_text_new();
 	column = gtk_tree_view_column_new_with_attributes("Ranges",
@@ -1891,15 +1952,15 @@ GtkWidget *gui_create_search_dialog(void)
 							  "text", 0,
 							  NULL);
 	gtk_tree_view_column_set_sort_column_id(column, 0);
-	gtk_tree_view_append_column(GTK_TREE_VIEW(search.list_ranges),
+	gtk_tree_view_append_column(GTK_TREE_VIEW(search1.list_ranges),
 				    column);
-	gtk_widget_show(search.list_ranges);
+	gtk_widget_show(search1.list_ranges);
 	gtk_container_add(GTK_CONTAINER(scrolledwindow65),
-			  search.list_ranges);
-	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(search.list_ranges),
+			  search1.list_ranges);
+	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(search1.list_ranges),
 				     TRUE);
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW
-					  (search.list_ranges), FALSE);
+					  (search1.list_ranges), FALSE);
 
 	label206 = gtk_label_new(_("Custom Ranges"));
 	gtk_widget_show(label206);
@@ -1993,25 +2054,27 @@ GtkWidget *gui_create_search_dialog(void)
 				       (scrolledwindow68),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow68,
+                                             settings.shadow_type);
 				       
 	/* create tree model */
 	model = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
 
 	/* create tree view */
-	search.module_lists =
+	search1.module_lists =
 	    gtk_tree_view_new_with_model(GTK_TREE_MODEL(model));
-	gtk_widget_show(search.module_lists);
+	gtk_widget_show(search1.module_lists);
 	gtk_container_add(GTK_CONTAINER(scrolledwindow68),
-			  search.module_lists);
-	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(search.module_lists),
+			  search1.module_lists);
+	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(search1.module_lists),
 				     TRUE);
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW
-					  (search.module_lists), FALSE);
-	add_two_text_columns(GTK_TREE_VIEW(search.module_lists));
+					  (search1.module_lists), FALSE);
+	add_two_text_columns(GTK_TREE_VIEW(search1.module_lists));
 
 	selection_modules_lists =
 	    G_OBJECT(gtk_tree_view_get_selection
-		     (GTK_TREE_VIEW(search.module_lists)));
+		     (GTK_TREE_VIEW(search1.module_lists)));
 
 
 	vbox80 = gtk_vbox_new(FALSE, 4);
@@ -2097,6 +2160,8 @@ GtkWidget *gui_create_search_dialog(void)
 				       (scrolledwindow66),
 				       GTK_POLICY_NEVER,
 				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow66,
+                                             settings.shadow_type);
 	/* create tree model */
 	model = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
 
@@ -2121,34 +2186,35 @@ GtkWidget *gui_create_search_dialog(void)
 
 
 /*******   ******/
-	search.dialog = search_dialog;
+	search1.dialog = search_dialog;
 
-	search.label_search_module = label_search_module;
-	search.notebook = notebook8;
-	search.togglebutton_show_main = togglebutton_show_main;
-	search.rb_current_module = rb_one_mod;
-	search.rb_mod_list = rb_mod_list;
-	search.rb_custom_list = rb_custom_list;
-	search.listview_modules = listview_modules;
+	search1.label_search_module = label_search_module;
+	search1.notebook = notebook8;
+	search1.togglebutton_show_main = togglebutton_show_main;
+	search1.rb_current_module = rb_one_mod;
+	search1.rb_mod_list = rb_mod_list;
+	search1.rb_custom_list = rb_custom_list;
+	search1.listview_modules = listview_modules;
 
-	search.combo_list = combo31;
-	search.combo_entry_list = combo_entry20;
+	search1.combo_list = combo31;
+	search1.combo_entry_list = combo_entry20;
 
-	search.entry_list_name = entry_modlist_name;
-	search.rb_last = rb_last;
-	search.rb_no_scope = rb_no_scope;
-	search.rb_custom_range = rb_custom_range;
-	search.combo_range = combo_custom_range;
-	search.combo_entry_range = combo_entry_custom_range;
-	search.entry_range_name = entry_range_name;
-	search.entry_range_text = entry_range_text;
-	search.search_entry = entry17;
-	search.rb_words = rb_words;
-	search.rb_regexp = tb_regexp;
-	search.rb_exact_phrase = rb_exact_phrase;
-	search.cb_case_sensitive = cb_case_sensitive;
-	search.progressbar = appbar_search;
-	search.label_mod_select = label_search_module;
+	search1.entry_list_name = entry_modlist_name;
+	search1.rb_last = rb_last;
+	search1.rb_no_scope = rb_no_scope;
+	search1.rb_custom_range = rb_custom_range;
+	search1.combo_range = combo_custom_range;
+	search1.combo_entry_range = combo_entry_custom_range;
+	search1.entry_range_name = entry_range_name;
+	search1.entry_range_text = entry_range_text;
+	search1.search_entry = entry17;
+	search1.rb_words = rb_words;
+	search1.rb_regexp = tb_regexp;
+	search1.rb_exact_phrase = rb_exact_phrase;
+//	search1.rb_indexed_word = rb_indexed_word;
+	search1.cb_case_sensitive = cb_case_sensitive;
+	search1.progressbar = appbar_search;
+	search1.label_mod_select = label_search_module;
 
 	scrolledwindow_tree = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow_tree);
@@ -2156,16 +2222,18 @@ GtkWidget *gui_create_search_dialog(void)
 				       scrolledwindow_tree,
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow_tree,
+                                             settings.shadow_type);
 	gtk_paned_pack1(GTK_PANED(hpaned8), scrolledwindow_tree, TRUE,
 			TRUE);
 
 
-	search.treeview = gtk_tree_view_new();
-	gtk_widget_show(search.treeview);
+	search1.treeview = gtk_tree_view_new();
+	gtk_widget_show(search1.treeview);
 	gtk_container_add(GTK_CONTAINER(scrolledwindow_tree),
-			  search.treeview);
+			  search1.treeview);
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW
-					  (search.treeview), FALSE);
+					  (search1.treeview), FALSE);
 
 	renderer = gtk_cell_renderer_text_new();
 	column = gtk_tree_view_column_new_with_attributes("Found",
@@ -2173,36 +2241,36 @@ GtkWidget *gui_create_search_dialog(void)
 							     "text", 0,
 							     NULL);
 	gtk_tree_view_column_set_sort_column_id(column, 0);
-	gtk_tree_view_append_column(GTK_TREE_VIEW(search.treeview),
+	gtk_tree_view_append_column(GTK_TREE_VIEW(search1.treeview),
 					    column);
 	
 
-	search.which_scope = GTK_TOGGLE_BUTTON(search.rb_no_scope);
+	search1.which_scope = GTK_TOGGLE_BUTTON(search1.rb_no_scope);
 
 	/* add html widgets */
 
-	search.report_html = gtk_html_new();
-	gtk_widget_show(search.report_html);
-	gtk_html_load_empty(GTK_HTML(search.report_html));
+	search1.report_html = gtk_html_new();
+	gtk_widget_show(search1.report_html);
+	gtk_html_load_empty(GTK_HTML(search1.report_html));
 	gtk_container_add(GTK_CONTAINER(scrolledwindow_report),
-			  search.report_html);
+			  search1.report_html);
 
-	search.preview_html = gtk_html_new();
-	gtk_widget_show(search.preview_html);
-	gtk_html_load_empty(GTK_HTML(search.preview_html));
+	search1.preview_html = gtk_html_new();
+	gtk_widget_show(search1.preview_html);
+	gtk_html_load_empty(GTK_HTML(search1.preview_html));
 	gtk_container_add(GTK_CONTAINER(scrolledwindow_preview),
-			  search.preview_html);
+			  search1.preview_html);
 
-	search.results_html = gtk_html_new();
-	gtk_widget_show(search.results_html);
-	gtk_html_load_empty(GTK_HTML(search.results_html));
+	search1.results_html = gtk_html_new();
+	gtk_widget_show(search1.results_html);
+	gtk_html_load_empty(GTK_HTML(search1.results_html));
 	gtk_container_add(GTK_CONTAINER(scrolledwindow_results),
-			  search.results_html);
+			  search1.results_html);
 
-	gui_load_module_tree(search.treeview, FALSE);
+	gui_load_module_tree(search1.treeview, FALSE);
 	mod_selection =
 	    G_OBJECT(gtk_tree_view_get_selection
-		     (GTK_TREE_VIEW(search.treeview)));
+		     (GTK_TREE_VIEW(search1.treeview)));
 	/* connect signals */
 
 
@@ -2218,14 +2286,18 @@ GtkWidget *gui_create_search_dialog(void)
 			 G_CALLBACK(on_button_begin_search), NULL);
 	g_signal_connect(mod_selection, "changed",
 			 G_CALLBACK(mod_selection_changed),
-			 search.treeview);
-	g_signal_connect(G_OBJECT(search.rb_current_module), "toggled",
+			 search1.treeview);
+	g_signal_connect(G_OBJECT(search1.rb_current_module), "toggled",
 			 G_CALLBACK(current_module_toggled), NULL);
-	g_signal_connect(G_OBJECT(search.rb_no_scope), "toggled",
+/*			 
+	g_signal_connect(G_OBJECT(search1.rb_indexed_word), "toggled",
+			 G_CALLBACK(indexed_word_toggled), NULL);
+*/			 
+	g_signal_connect(G_OBJECT(search1.rb_no_scope), "toggled",
 			 G_CALLBACK(scope_toggled), NULL);
-	g_signal_connect(G_OBJECT(search.rb_mod_list), "toggled",
+	g_signal_connect(G_OBJECT(search1.rb_mod_list), "toggled",
 			 G_CALLBACK(mod_list_toggled), NULL);
-	g_signal_connect(G_OBJECT(search.rb_custom_range), "toggled",
+	g_signal_connect(G_OBJECT(search1.rb_custom_range), "toggled",
 			 G_CALLBACK(scope_toggled), NULL);
 	g_signal_connect(G_OBJECT(button_save_mods), "clicked",
 			 G_CALLBACK(save_modlist), NULL);
@@ -2253,23 +2325,23 @@ GtkWidget *gui_create_search_dialog(void)
 	g_signal_connect(G_OBJECT(entry_range_text), "changed",
 			 G_CALLBACK(range_text_changed), NULL);
 
-	g_signal_connect(G_OBJECT(search.entry_list_name),
+	g_signal_connect(G_OBJECT(search1.entry_list_name),
 			 "changed",
 			 G_CALLBACK(list_name_changed), NULL);
-	g_signal_connect(G_OBJECT(search.togglebutton_show_main),
+	g_signal_connect(G_OBJECT(search1.togglebutton_show_main),
 			 "toggled",
 			 G_CALLBACK(on_togglebutton_show_main), NULL);
 	g_signal_connect(G_OBJECT(button_begin_search), "clicked",
 			 G_CALLBACK(on_button_begin_search), NULL);
-	g_signal_connect(G_OBJECT(search.results_html),"link_clicked",
+	g_signal_connect(G_OBJECT(search1.results_html),"link_clicked",
 			 G_CALLBACK(link_clicked), 
 			 GINT_TO_POINTER(0));
-	g_signal_connect(G_OBJECT(search.preview_html),"link_clicked",
+	g_signal_connect(G_OBJECT(search1.preview_html),"link_clicked",
 			 G_CALLBACK(link_clicked), 
 			 GINT_TO_POINTER(1));
-	g_signal_connect(G_OBJECT(search.results_html), "on_url",
+	g_signal_connect(G_OBJECT(search1.results_html), "on_url",
 			 G_CALLBACK(url), NULL);
-	g_signal_connect(G_OBJECT(search.report_html),
+	g_signal_connect(G_OBJECT(search1.report_html),
 			 "link_clicked",
 			 G_CALLBACK(report_link_clicked), NULL);
 
@@ -2280,8 +2352,8 @@ GtkWidget *gui_create_search_dialog(void)
 	g_signal_connect(G_OBJECT(button_save_results), "clicked",
 			 G_CALLBACK(button_save), NULL);
 
-	gtk_object_set_data(GTK_OBJECT(search.dialog), "tooltips",
+	gtk_object_set_data(GTK_OBJECT(search1.dialog), "tooltips",
 			    tooltips);
 
-	return search.dialog;
+	return search1.dialog;
 }
