@@ -22,8 +22,11 @@
 #ifndef __STUDYPAD_H_
 #define __STUDYPAD_H_
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 #include <gnome.h>
-#include "gui/editor.h"
+#include "editor/editor.h"
 
 extern GSHTMLEditorControlData *editor_cd;
 
@@ -32,7 +35,8 @@ gint save_file_program_end(GtkWidget *htmlwidget, gchar *filename);
 gint save_file(gchar *filename, GSHTMLEditorControlData *ecd);
 gint load_file(gchar *filename, GSHTMLEditorControlData *ecd);
 gint gui_open_studypad(gchar * file_name);
-GtkWidget *gui_create_studypad_control(GtkWidget * container,
-				gchar * filename);
 
+#ifdef __cplusplus
+}
+#endif	
 #endif
