@@ -25,7 +25,8 @@
 
 #include <gnome.h>
 #include <swmgr.h>
-#include <swmodule.h>
+#include <swmodule.h>	
+#include <url.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -37,23 +38,25 @@ extern "C" {
 
 #include <string.h>
 
+#include "editor/editor.h"
+#include "editor/editor-control.h"
+//#include "editor/note_editor.h"
+
 #include "gui/bibletext_dialog.h"
 #include "gui/commentary_dialog.h"
 #include "gui/dictlex_dialog.h"
 #include "gui/gbs_dialog.h"
 #include "gui/display_info.h"
-#include "gui/editor.h"
-#include "gui/note_editor.h"
 #include "gui/font_dialog.h"
 #include "gui/sidebar.h"
 #include "gui/hints.h"
 #include "gui/html.h"
 #include "gui/main_window.h"
+#include "gui/note_editor.h"
 #include "gui/gnomesword.h"
 #include "gui/utilities.h"
 #include "gui/widgets.h"
 
-#include "main/bibletext.h"
 #include "main/module_dialogs.h"
 #include "main/sword.h"
 #include "main/sidebar.h"
@@ -112,8 +115,111 @@ static gboolean bible_in_url;
  * externs
  */
 extern gboolean gsI_isrunning;	/* information dialog */
+extern gboolean do_display;
 
 
+/******************************************************************************
+ * Name
+ *   main_dialog_information_viewer
+ *
+ * Synopsis
+ *   #include "main/sword.h.h"
+ *
+ *   void main_dialog_information_viewer(GtkWidget * html_widget, gchar * mod_name, 
+ *		    gchar * text, gchar *key, gchar * type, gboolean show_key)
+ *
+ * Description
+ *   display information in the information viewer
+ *
+ * Return value
+ *   void
+ */
+
+void main_dialog_information_viewer(gchar * mod_name, gchar * text, gchar * key,
+		             gchar * action ,gchar * type ,gchar * morph_text,
+			     gchar * morph, DIALOG_DATA * d)
+{
+	GString *tmp_str = g_string_new(NULL);
+	GString *str;
+	GString *search_str;
+	MOD_FONT *mf = get_font(mod_name);
+	GtkHTML *html;
+	
+	if(!d->previewer)
+		return;
+	
+	html = GTK_HTML(d->previewer);
+	
+	g_string_printf(tmp_str,
+		//HTML_START
+		"<body bgcolor=\"%s\" text=\"%s\" link=\"%s\">",
+		settings.bible_bg_color, settings.bible_text_color,
+		settings.link_color);
+
+	str = g_string_new(tmp_str->str);
+	if(type) {
+		if(!strcmp(type,"n")) {
+			g_string_printf(tmp_str,"<font color=\"grey\">%s<HR></font><br>",
+					_("Footnote"));
+			str = g_string_append(str, tmp_str->str);
+		}
+		if(!strcmp(type,"x")) {
+			g_string_printf(tmp_str,"<font color=\"grey\">%s<HR></font><br>",
+					_("Cross Reference"));
+			str = g_string_append(str, tmp_str->str);
+		}
+		if(!strcmp(action ,"showStrongs")) {  //&& !strcmp(type,"Greek")
+			g_string_printf(tmp_str,"<font color=\"grey\">%s: %s<HR></font><br>",
+					_("Strongs"),key);
+			str = g_string_append(str, tmp_str->str);
+		}
+		if(!strcmp(action ,"showMorph")) {  //&& !strcmp(type,"Greek")
+			g_string_printf(tmp_str,"<font color=\"grey\">%s: %s<HR></font><br>",
+					_("Morphology"),key);
+			str = g_string_append(str, tmp_str->str);
+		}
+	}
+	
+	if(!strcmp(action ,"showStrongsMorph")) {  //&& !strcmp(type,"Greek")
+		g_string_printf(tmp_str,"<font color=\"grey\">%s: %s<HR></font><br>",
+				_("Strongs"),key);
+		str = g_string_append(str, tmp_str->str);
+		g_string_printf(tmp_str, 
+				"<font face=\"%s\" size=\"%s\">",
+				(mf->old_font)?mf->old_font:"none", 
+				(mf->old_font_size)?mf->old_font_size:"+0");
+		str = g_string_append(str, tmp_str->str);
+		str = g_string_append(str, text);
+		
+		g_string_printf(tmp_str,"<font color=\"grey\"><br><br>%s: %s<HR></font><br>",
+					_("Morphology"),morph);
+		str = g_string_append(str, tmp_str->str);
+		str = g_string_append(str, morph_text);
+		g_string_printf(tmp_str, " %s<br>", "</font></body></html>");
+		str = g_string_append(str, tmp_str->str);
+		
+		
+	} else {
+		g_string_printf(tmp_str, 
+				"<font face=\"%s\" size=\"%s\">",
+				(mf->old_font)?mf->old_font:"none", 
+				(mf->old_font_size)?mf->old_font_size:"+0");
+		str = g_string_append(str, tmp_str->str);
+		str = g_string_append(str, text);
+	
+		g_string_printf(tmp_str, " %s", "</font></body></html>");
+		str = g_string_append(str, tmp_str->str);
+	
+	}
+	
+	if (str->len) {
+		gtk_html_load_from_string(html,str->str,str->len);
+	}
+	
+	free_font(mf);
+	g_string_free(str, TRUE);
+	g_string_free(tmp_str, TRUE);
+}
 
 /******************************************************************************
  * Name
@@ -344,7 +450,7 @@ void main_dialogs_tree_selection_changed(GtkTreeModel * model,
 
 void main_dialogs_dictionary_entery_changed(DIALOG_DATA * d)
 {
-	gint count = 7, i;
+	gint count = 10, i;
 	gchar *new_key, *text = NULL;
 	gchar *key = NULL;
 	static gboolean firsttime = TRUE;
@@ -455,10 +561,15 @@ static gboolean save_note_receiver(const HTMLEngine * engine,
  *   void
  */
 
-void main_dialog_save_note(DIALOG_DATA * d)
+void main_dialog_save_note(gpointer data)
 {
-	BackEnd *be = (BackEnd*)d->backend;
-	GSHTMLEditorControlData *e = (GSHTMLEditorControlData*)d->editor;
+	//gchar *buf = NULL;                                       
+//	gsize bytes_read;
+//	gsize bytes_written;
+//	GError **error = NULL;
+	GSHTMLEditorControlData *e = (GSHTMLEditorControlData*) data;
+	BackEnd *be = (BackEnd*)e->be;
+	
 	
 	if(!be)
 		return;	
@@ -471,8 +582,17 @@ void main_dialog_save_note(DIALOG_DATA * d)
 		 GINT_TO_POINTER(0)) ){
 		g_warning("file not writen");
 	} else {
+		/*buf = g_convert(note_str->str,
+                             -1,
+                             OLD_CODESET,
+                             UTF_8,
+                             &bytes_read,
+                             &bytes_written,
+                             error);*/
+		//g_message(note_str->str);
 		be->save_entry(note_str->str);	
 		g_print("\nnote saved\n");
+		//g_free(buf);
 	}
 	g_string_free(note_str, 0);
 	gtk_html_set_editable(e->html, TRUE);
@@ -494,9 +614,10 @@ void main_dialog_save_note(DIALOG_DATA * d)
  *   void
  */
 
-void main_dialog_delete_note(DIALOG_DATA * d)
+void main_dialog_delete_note(gpointer data)
 {
-	BackEnd *be = (BackEnd*)d->backend;
+	GSHTMLEditorControlData *e = (GSHTMLEditorControlData*) data;
+	BackEnd *be = (BackEnd*)e->be;
 	
 	if(!be)
 		return;	
@@ -506,119 +627,12 @@ void main_dialog_delete_note(DIALOG_DATA * d)
 
 /******************************************************************************
  * Name
- *   update_controls
+ *   main_free_on_destroy
  *
  * Synopsis
- *   #include "bibletext_dialog.h"
+ *   #include ".h"
  *
- *   void update_controls(DIALOG_DATA * vt)	
- *
- * Description
- *   update the book, chapter and verse contorls
- *
- * Return value
- *   void
- */
-
-void main_dialog_update_controls(DIALOG_DATA * t)
-{
-	gchar *val_key;
-	gint cur_chapter, cur_verse;
-	BackEnd *be = (BackEnd*)t->backend;
-
-	dlg_bible = t;
-	bible_apply_change = FALSE;
-	val_key = be->get_valid_key(t->key);
-	cur_chapter = be->key_get_chapter(val_key);
-	cur_verse = be->key_get_verse(val_key);
-	/* 
-	 *  set book, chapter,verse and freeform lookup entries
-	 *  to new verse - settings.bible_apply_change is set to false so we don't
-	 *  start a loop
-	 */
-	gtk_entry_set_text(GTK_ENTRY(t->cbe_book),
-			   be->key_get_book(val_key));
-	gtk_spin_button_set_value(GTK_SPIN_BUTTON
-				  (t->spb_chapter), cur_chapter);
-	gtk_spin_button_set_value(GTK_SPIN_BUTTON
-				  (t->spb_verse), cur_verse);
-	gtk_entry_set_text(GTK_ENTRY(t->freeform_lookup), val_key);
-	if(t->key)
-		g_free(t->key);
-	t->key = g_strdup(val_key);
-	g_free(val_key);
-
-	bible_apply_change = TRUE;
-}
-
-/******************************************************************************
- * Name
- *   
- *
- * Synopsis
- *   #include "bibletext_dialog.h"
- *
- *   void (DIALOG_DATA * vt)
- *
- * Description
- *   
- *
- * Return value
- *   void
- */
-
-void main_bible_dialog_passage_changed(DIALOG_DATA * t, gchar * passage)
-{	
-	BackEnd *be = (BackEnd*)t->backend;
-	gchar buf[256];
-	gchar *val_key = NULL;
-	if (bible_apply_change) {
-		if (*passage) {
-			val_key = be->get_valid_key(passage);
-			if(t->key)
-				g_free(t->key);
-			t->key = g_strdup(val_key );
-			main_dialog_update_controls(t);	
-			be->set_key(t->key);
-			be->display_mod->Display();
-			g_free(val_key);
-		}
-	}
-}
-
-
-
-/******************************************************************************
- * Name
- *   
- *
- * Synopsis
- *   #include "bibletext_dialog.h"
- *
- *   void (DIALOG_DATA * vt)
- *
- * Description
- *   
- *
- * Return value
- *   void
- */
-
-void main_bible_dialog_display(DIALOG_DATA * t)
-{	
-	BackEnd *be = (BackEnd*)t->backend;
-	be->set_module_key(t->mod_name,t->key);
-	be->display_mod->Display();	
-}
-
-/******************************************************************************
- * Name
- *   free_on_destroy
- *
- * Synopsis
- *   #include "bibletext_dialog.h"
- *
- *   void free_on_destroy(DIALOG_DATA * vt)
+ *   void main_free_on_destroy(DIALOG_DATA * vt)
  *
  * Description
  *   removes dialog from dialog_list when dialog is destroyed other than
@@ -636,7 +650,7 @@ void main_free_on_destroy(DIALOG_DATA * t)
 	g_free(t->key);
 	g_free(t->mod_name); 
 	if((GSHTMLEditorControlData*)t->editor) {
-		gui_html_editor_control_data_destroy(NULL, 
+		editor_control_data_destroy(NULL, 
 				(GSHTMLEditorControlData*)t->editor);		
 		dlg_percom = NULL;
 	}
@@ -664,45 +678,47 @@ void main_free_on_destroy(DIALOG_DATA * t)
  *   void
  */
 
-void main_dialog_goto_bookmark(gchar * url)
+void main_dialog_goto_bookmark(const gchar * module, const gchar * key)
 {
+	DIALOG_DATA *t = NULL;
 	GList *tmp = NULL;
-	gchar **work_buf = NULL;
-	
-	work_buf = g_strsplit (url,"/",4);
-	
-	if(!work_buf[MODULE] && !work_buf[KEY]) {
-		g_strfreev(work_buf);
-		return;
-	}
 	
 	tmp = g_list_first(list_dialogs);
 	while (tmp != NULL) {
-		DIALOG_DATA *t = (DIALOG_DATA *) tmp->data;
-		if(!strcmp(t->mod_name, work_buf[MODULE])) {
-			BackEnd* be = (BackEnd*)t->backend;
-			if(t->key)
-				g_free(t->key);
-			t->key = g_strdup(work_buf[KEY]);
-			main_dialog_update_controls(t);
-			be->set_key(t->key);
+		t = (DIALOG_DATA *) tmp->data;
+		if(!strcmp(t->mod_name, module)) {
+			BackEnd* be = (BackEnd*)t->backend;			
+			if(t->mod_type == BOOK_TYPE) {
+				t->offset = atoi(key);			
+				be->set_treekey(t->offset);
+			} else {
+				if(t->key)
+					g_free(t->key);
+				t->key = g_strdup(key);
+				be->set_key(t->key);
+			}
+			if(t->mod_type == TEXT_TYPE || 
+					t->mod_type == COMMENTARY_TYPE)
+				main_navbar_set(t->navbar, key);
 			be->display_mod->Display();
-			gdk_window_raise(t->dialog->window);	
-			g_strfreev(work_buf);
+			gdk_window_raise(t->dialog->window);
 			return;
 		}		
 		tmp = g_list_next(tmp);
 	}
 	
-	main_dialogs_open(work_buf[2]);
-	BackEnd* be = (BackEnd*)dlg_bible->backend;
-	if(dlg_bible->key)
-		g_free(dlg_bible->key);
-	dlg_bible->key = g_strdup(work_buf[3]);
-	main_dialog_update_controls(dlg_bible);
-	be->set_key(dlg_bible->key);
-	be->display_mod->Display();	
-	g_strfreev(work_buf);
+	t = main_dialogs_open((gchar*)module,key);
+	BackEnd* be = (BackEnd*)t->backend;	
+	if(t->mod_type == BOOK_TYPE) {	
+		t->offset = atoi(key);		
+		be->set_treekey(t->offset);
+	} else {
+		if(t->key)
+			g_free(t->key);
+		t->key = g_strdup(key);
+		be->set_key(t->key);
+	}
+	be->display_mod->Display();
 }
 
 
@@ -734,12 +750,12 @@ void main_dialogs_setup(void)
 
 /******************************************************************************
  * Name
- *   
+ *   main_keep_bibletext_dialog_in_sync
  *
  * Synopsis
  *   #include ".h"
  *
- *   	
+ *   void main_keep_bibletext_dialog_in_sync(gchar * key)	
  *
  * Description
  *   
@@ -767,15 +783,15 @@ void main_keep_bibletext_dialog_in_sync(gchar * key)
 
 /******************************************************************************
  * Name
- *  gui_shutdown_bibletext_dialog
+ *  main_dialogs_shutdown
  *
  * Synopsis
- *   #include "bibletext_dialog.h"
+ *   #include ".h"
  *
- *  void gui_shutdown_bibletext_dialog(void)	
+ *  void main_dialogs_shutdown(void)	
  *
  * Description
- *   shut down bibletext dialog support clean mem
+ *   shut down dialog support clean mem
  *
  * Return value
  *   void
@@ -798,13 +814,17 @@ void main_dialogs_shutdown(void)
 		 * free each DIALOG_DATA item created 
 		 */
 		if((GSHTMLEditorControlData*)t->editor) 
-			gui_html_editor_control_data_destroy(NULL, 
+			editor_control_data_destroy(NULL, 
 					(GSHTMLEditorControlData*)t->editor);
 		
 		if((BackEnd*)t->backend) {
 			BackEnd* be = (BackEnd*)t->backend;
 			delete be;
 		}
+		if(t->navbar.key)
+			g_free(t->navbar.key);
+		if(t->navbar.module_name)
+			g_free(t->navbar.module_name);
 		g_free(t->mod_name);
 		g_free(t->ops);
 		g_free(t->key);
@@ -814,14 +834,15 @@ void main_dialogs_shutdown(void)
 	g_list_free(list_dialogs);
 }
 
+
 /******************************************************************************
  * Name
- *   
+ *   main_dialog_set_global_opt
  *
  * Synopsis
  *   #include ".h"
  *
- *   	
+ *   main_dialog_set_global_opt(gboolean choice)	
  *
  * Description
  *   
@@ -845,12 +866,13 @@ void main_dialog_set_global_opt(gboolean choice)
  
 /******************************************************************************
  * Name
- *   note_uri
+ *   show_note
  *
  * Synopsis
- *   #include "gui/utilities.h"
+ *   #include ".h"
  *
- *   gint note_uri(const gchar * url)
+ *   gint show_note(DIALOG_DATA * d,const gchar * module, const gchar * passage, 
+		const gchar * type, const gchar * value, gboolean clicked)
  *
  * Description
  *  
@@ -859,174 +881,246 @@ void main_dialog_set_global_opt(gboolean choice)
  *   gint
  */
  
-static gint note_uri(DIALOG_DATA * t, const gchar * url, gboolean clicked)
+static gint show_note(DIALOG_DATA * d,const gchar * module, const gchar * passage, 
+		const gchar * type, const gchar * value, gboolean clicked)
 {	
-	gchar **work_buf = NULL;
-	gchar *module = NULL;
 	gchar *tmpbuf = NULL;
+	gchar *buf = NULL;
+	GString *str = g_string_new(NULL);
+	GList *tmp = NULL;
+	gint i = 0;	
+	BackEnd* be = (BackEnd*)d->backend;
 	
-	BackEnd* be = (BackEnd*)t->backend;
 	
-	work_buf = g_strsplit (url,"/",6);
+	if(!be->is_module((gchar*)module)) 
+		module = settings.MainWindowModule;
 	
-	if (hint.in_popup) {
-		gtk_widget_destroy(hint.hint_window);
-		hint.in_popup = FALSE;
-	}
+	if(passage && (strlen(passage) < 5))
+		passage = settings.currentverse;
 	
-	if(be->is_module(work_buf[2])) 
-		module = work_buf[2];
-	else
-		module = t->mod_name;
-	
-	//if(strstr(work_buf[4],"x") && clicked) {
-	be->set_module_key(module, work_buf[3]);
+	if(strstr(type,"x") && clicked) {
+		be->set_module_key((gchar*)module, (gchar*)passage);
 		tmpbuf = be->get_entry_attribute("Footnote",
-							work_buf[5],
-							"body");
-		//tmpbuf = get_crossref(module,work_buf[3],work_buf[5]);
+							 (gchar*)value,
+							"refList");
 		if (tmpbuf) {
-			if (!gsI_isrunning) {
-				gui_create_display_informtion_dialog();
-			}
-			
-			gui_display_text_information(tmpbuf);
-			gtk_window_set_title(GTK_WINDOW(dialog_display_info),
-			     _("Note"));
+			main_display_verse_list_in_sidebar(settings.
+					  currentverse,
+					  (gchar*)module,
+					  tmpbuf);
 			g_free(tmpbuf);
 		}
-		/*
-	} else if(!clicked) {
+	} else if(strstr(type,"n") && !clicked) {
+		be->set_module_key((gchar*)module, (gchar*)passage);		
+		tmpbuf = be->get_entry_attribute("Footnote",
+						(gchar*)value,
+						"body");		
+		buf = be->render_this_text((gchar*)module,(gchar*)tmpbuf);
+		if(tmpbuf) g_free(tmpbuf);	
+		if (buf) {
+			main_dialog_information_viewer((gchar*)module, 
+					buf, 
+					(gchar*)value,
+					"showNote",			
+					(gchar*)type,
+					NULL,
+					NULL,
+					d);
+			if(buf) g_free(buf);	
+		}			
+	} else if(strstr(type,"x") && !clicked) {
+		be->set_module_key((gchar*)module, (gchar*)passage);		
+		tmpbuf = be->get_entry_attribute("Footnote",
+						(gchar*)value,
+						"refList");
 		
-		tmpbuf = get_footnote_body(module,work_buf[3],work_buf[5]);
-		if (tmpbuf) {
-			void gui_display_text_information(gchar * information)
-			gui_display_in_hint_window(tmpbuf);
-			g_free(tmpbuf);	
+		
+		list_of_verses = g_list_first(list_of_verses);
+		if(list_of_verses) {
+			while(list_of_verses) {
+				g_free(list_of_verses->data);
+				list_of_verses = g_list_next(list_of_verses);
+			}
+			g_list_free(list_of_verses);
+		}
+		list_of_verses = NULL;
+		
+		tmp = be->parse_verse_list(tmpbuf, settings.currentverse);  
+		while (tmp != NULL) {
+			buf = g_strdup_printf(
+				"<a href=\"sword://%s/%s\">"
+				"<font color=\"%s\">%s,</font></a><br>",
+				(gchar*)module,
+				(const char *) tmp->data,
+				settings.bible_text_color,
+				(const char *) tmp->data);
+			str = g_string_append(str,buf);
+			if(buf) g_free(buf);
+			buf = NULL;
+			++i;
+			g_free((char *) tmp->data);
+			tmp = g_list_next(tmp);
+		}
+		g_list_free(tmp);
+		
+		buf = g_strdup_printf(
+				"<a href=\"sword://%s/%s\">"
+				"<font color=\"%s\">%s%s</font></a><br>",
+				(gchar*)module,
+				settings.currentverse,
+				settings.bible_text_color,
+				_("Back to "),
+				settings.currentverse);
+		str = g_string_append(str,buf);
+		if(buf) g_free(buf);		
+		
+		if(tmpbuf) g_free(tmpbuf);	
+		if (str) {
+			main_dialog_information_viewer((gchar*)module, 
+					str->str, 
+					(gchar*)value,
+					"showNote",			
+					(gchar*)type,
+					NULL,
+					NULL,
+					d);
 		}			
 	}
-	*/
-	g_strfreev(work_buf);
+	g_string_free(str, 1);
 	return 1;
-	
 }
- 
+
 
 /******************************************************************************
  * Name
- *   morph_uri
+ *   show_morph
  *
  * Synopsis
- *   #include "gui/utilities.h"
+ *   #include ".hh"
  *
- *   gint morph_uri(const gchar * url)
+ *   gint show_morph(DIALOG_DATA * d, const gchar * type, 
+			const gchar * value, gboolean clicked)
  *
  * Description
- *   handle a sword uri in the form 'sword://KJV/1John5:8'
- *                                   'sword://MHC/Genesis1:1'
- *                                   'sword:///Romans8:28'
- *   and display in the appropriate pane
+ *  
  *
  * Return value
  *   gint
  */
-
-static gint morph_uri(DIALOG_DATA * t, const gchar * url, gboolean clicked)
-{
-	gchar *module = NULL;
-	gchar *key = NULL;
+ 
+ static gint show_morph(DIALOG_DATA * d, const gchar * type, 
+			const gchar * value, gboolean clicked)
+{	
 	gchar *modbuf = NULL;
-	gchar **work_buf = NULL;
-	static GtkWidget *dlg;
+	gchar *mybuf = NULL;
+	static GtkWidget *dlg;	
+		
 	
-	BackEnd* be = (BackEnd*)t->backend;
+	BackEnd* be = (BackEnd*)d->backend;
 	
-	work_buf = g_strsplit (url,"/",4);
-	if(!work_buf[MODULE] && !work_buf[KEY]) {
-		g_strfreev(work_buf);
-		return 0;
-	}
-	if(!strcmp(work_buf[2],"Greek") || strstr(work_buf[2],"x-Robinson")) {
+	if(!strcmp(type,"Greek") || strstr(type,"x-Robinson")) {
 		if(be->is_module("Robinson")) 
 			modbuf = "Robinson";
-	} else
-		return 0;
-	
-	if (!gsI_isrunning) {
-		dlg =
-		    gui_create_display_informtion_dialog();
+	} 		
+	if (clicked) {
+		if (!gsI_isrunning) 
+			dlg = gui_create_display_informtion_dialog();
+		else
+			gtk_widget_show(dlg);
+		
+		gui_display_mod_and_key(modbuf, (gchar*)value);
+		gtk_window_set_title(GTK_WINDOW(dialog_display_info),
+		     modbuf);			
+	} else {
+		mybuf = main_get_rendered_text(modbuf, (gchar*)value);
+		if (mybuf) {
+			main_dialog_information_viewer(modbuf, 
+					mybuf, 
+					(gchar*)value, 
+					"showMorph",
+					(gchar*)type,
+					NULL,
+					NULL,
+					d);
+			g_free(mybuf);
+		}
 	}
-	
-	gui_display_mod_and_key(modbuf, work_buf[KEY]);
-	gtk_window_set_title(GTK_WINDOW(dialog_display_info),
-	     modbuf);
-	g_strfreev(work_buf);	
 	return 1;
+	
 }
 
 
-
-/******************************************************************************
+ /******************************************************************************
  * Name
- *   strongs_uri
+ *   show_strongs
  *
  * Synopsis
- *   #include "gui/utilities.h"
+ *   #include "main/url.hh"
  *
- *   gint sword_uri(const gchar * url)
+ *   gint show_strongs(DIALOG_DATA * t, const gchar * type, 
+			const gchar * value, gboolean clicked)
  *
  * Description
- *   handle a sword uri in the form 'sword://KJV/1John5:8'
- *                                   'sword://MHC/Genesis1:1'
- *                                   'sword:///Romans8:28'
- *   and display in the appropriate pane
+ *  
  *
  * Return value
  *   gint
- */
-
-static gint strongs_uri(DIALOG_DATA * t, const gchar * url, gboolean clicked)
-{
-	gchar *module = NULL;
-	gchar *key = NULL;
+ */ 
+ 
+static gint show_strongs(DIALOG_DATA * t, const gchar * type, 
+			const gchar * value, gboolean clicked)
+{	
+	gchar *modbuf_viewer = NULL;
 	gchar *modbuf = NULL;
-	gchar **work_buf = NULL;
-	static GtkWidget *dlg;
+	gchar *mybuf = NULL;
+	guint delay;	
+	guint i;
+	static GtkWidget *dlg;	
 	
 	BackEnd* be = (BackEnd*)t->backend;
 	
-	work_buf = g_strsplit (url,"/",4);
-	if(!work_buf[MODULE] && !work_buf[KEY]) {
-		g_strfreev(work_buf);
-		return 0;
-	}
-	
-	if(!strcmp(work_buf[2],"Greek")) {
-		if(be->is_module(settings.lex_greek)) 
+	if(!strcmp(t->mod_name,"NASB")) {
+		if(!strcmp(type,"Greek")) 
+			modbuf = "NasbGreek";
+		else 
+			modbuf = "NasbHebrew";
+			
+	} else {
+		if(!strcmp(type,"Greek")) 
 			modbuf = settings.lex_greek;
-		else
-			return 0;
-	} else if(!strcmp(work_buf[2],"Hebrew")) {
-		if(be->is_module(settings.lex_hebrew)) 
+		else if(!strcmp(type,"Hebrew")) 
 			modbuf = settings.lex_hebrew;
+	}
+	
+	if (clicked) {
+		if (!gsI_isrunning) 
+			dlg = gui_create_display_informtion_dialog();
 		else
-			return 0;
+			gtk_widget_show(dlg);
+		
+		gui_display_mod_and_key(modbuf, (gchar*)value);
+		gtk_window_set_title(GTK_WINDOW(dialog_display_info),
+		     modbuf);		
+	} else {
+		mybuf =
+		    main_get_rendered_text(modbuf, (gchar*)value);
+		if (mybuf) {
+			main_dialog_information_viewer(  
+					modbuf, 
+					mybuf, 
+					(gchar*)value, 
+					"showStrongs",
+					(gchar*)type,
+					NULL,
+					NULL,
+					t);
+			g_free(mybuf);
+		}
 	}
-	
-	if (!gsI_isrunning) {
-		dlg =
-		    gui_create_display_informtion_dialog();
-	}
-	
-	gui_display_mod_and_key(modbuf, work_buf[KEY]);
-	gtk_window_set_title(GTK_WINDOW(dialog_display_info),
-	     modbuf);
-	g_strfreev(work_buf);	
 	return 1;
 }
 
 
-
 /******************************************************************************
  * Name
  *   sword_uri
@@ -1085,8 +1179,8 @@ static gint sword_uri(DIALOG_DATA * t, const gchar * url, gboolean clicked)
 	be->set_module_key(t->mod_name, t->key);
 	main_dialog_set_global_options(t);
 	be->display_mod->Display();
-		
-	//main_dialog_update_controls(t);
+	if(t->navbar.module_name)
+		main_navbar_set(t->navbar, t->key);
 	
 	g_free(module);
 	g_free(key);
@@ -1095,14 +1189,70 @@ static gint sword_uri(DIALOG_DATA * t, const gchar * url, gboolean clicked)
 	
 }
 
+
+static gint new_url_handler(DIALOG_DATA * t, const gchar * url, gboolean clicked)
+{
+
+	gchar* action = NULL;
+	gchar* type = NULL;
+	gchar* value = NULL;
+	gchar* module = NULL;
+	gchar* passage = NULL;
+	gchar *buf = NULL;
+	URL* m_url;
+	
+#ifdef DEBUG	
+	//g_warning("url = %s",url);
+#endif
+	m_url = new URL((const char*)url);	
+	action = g_strdup(m_url->getParameterValue("action"));
+	type = g_strdup((gchar*)m_url->getParameterValue("type"));
+	value = g_strdup((gchar*)m_url->getParameterValue("value"));
+	
+#ifdef DEBUG
+	g_warning("action = %s",action);
+	g_warning("type = %s",type);  
+	g_warning("value = %s",value);
+#endif	
+
+ 
+	if(!strcmp(action,"showStrongs")) {
+		show_strongs(t, type, value, clicked);
+	}
+	
+	
+	if(!strcmp(action,"showMorph")) {
+		show_morph(t, type, value, clicked);
+	}
+	
+	if(!strcmp(action,"showNote")) {	
+		module = g_strdup(m_url->getParameterValue("module"));
+		passage = g_strdup((gchar*)m_url->getParameterValue("passage"));
+		show_note(t, module, passage, type, value, clicked);
+		if(module) g_free(module);
+		if(passage) g_free(passage);
+	}
+	
+	if(!strcmp(action,"showRef")) {	
+		module = g_strdup(m_url->getParameterValue("module"));
+		//new_reference_uri(module,value,clicked);
+		if(module) g_free(module);
+	}
+	
+	if(action) g_free(action);
+	if(type) g_free(type);
+	if(value) g_free(value);
+	return 1;
+}
+
 /******************************************************************************
  * Name
- *   gui_url_handler
+ *   main_dialogs_url_handler
  *
  * Synopsis
- *   #include "gui/utilities.h"
+ *   #include "main/module_dialogs.h"
  *
- *   gint gui_url_handler(const gchar * url)
+ *   gint main_dialogs_url_handler(DIALOG_DATA * t, const gchar * url, gboolean clicked)
  *
  * Description
  *   
@@ -1112,23 +1262,12 @@ static gint sword_uri(DIALOG_DATA * t, const gchar * url, gboolean clicked)
  */
 
 gint main_dialogs_url_handler(DIALOG_DATA * t, const gchar * url, gboolean clicked)
-{		
-	//g_warning(url);
+{	
+	g_message(url);
+	if(strstr(url,"passagestudy.jsp") || strstr(url,"gnomesword.url"))
+		return new_url_handler(t,url,clicked);
 	if(strstr(url,"sword://"))
 		return sword_uri(t, url, clicked);
-	if(strstr(url,"strongs://"))
-		return strongs_uri(t, url, clicked);
-	if(strstr(url,"morph://"))
-		return morph_uri(t, url, clicked);
-	if(strstr(url,"noteID://"))
-		return note_uri(t, url, clicked);
-/*	if(strstr(url,"bookmark://"))
-		return bookmark_uri(url,clicked);
-	if(strstr(url,"reference://"))
-		return reference_uri(url,clicked);
-	if(strstr(url,"about://"))
-		return about_uri(url,clicked);
-*/
 	return 0;
 }
 
@@ -1149,7 +1288,7 @@ gint main_dialogs_url_handler(DIALOG_DATA * t, const gchar * url, gboolean click
  *   void
  */
 
-void main_dialogs_open(gchar * mod_name)
+DIALOG_DATA *main_dialogs_open(const gchar * mod_name ,  const gchar * key)
 {	
 	GtkWidget *popupmenu;
 	BackEnd *be;
@@ -1158,16 +1297,16 @@ void main_dialogs_open(gchar * mod_name)
 	gchar *direction = NULL;
 	gchar *url;
 	GSHTMLEditorControlData *ec;
-	
+	do_display = TRUE;
 	if(!backend->is_module(mod_name))
-		return;
+		return NULL;
 	type = backend->module_type(mod_name);
 	
 	t = g_new0(DIALOG_DATA, 1);
 	t->backend = (BackEnd*) new BackEnd();
 	be = (BackEnd*)t->backend;
 	
-	t->ops = main_new_globals(mod_name);
+	t->ops = main_new_globals((gchar*)mod_name);
 	t->ops->words_in_red = FALSE;
 	t->ops->strongs = FALSE;
 	t->ops->morphs = FALSE;
@@ -1181,7 +1320,7 @@ void main_dialogs_open(gchar * mod_name)
 	t->ops->variants_all = FALSE;
 	t->ops->variants_primary = FALSE;
 	t->ops->variants_secondary = FALSE;
-	
+	t->navbar.module_name = NULL;
 	t->editor = NULL;
 	t->search_string = NULL;
 	t->dialog = NULL;
@@ -1198,6 +1337,7 @@ void main_dialogs_open(gchar * mod_name)
 	
 	switch(type) {
 		case TEXT_TYPE:
+			t->mod_type = TEXT_TYPE;
 			gui_create_bibletext_dialog(t);
 			if(t->is_rtol)
 				be->dialogRTOLDisplay 
@@ -1205,59 +1345,87 @@ void main_dialogs_open(gchar * mod_name)
 			else	
 				be->chapDisplay 
 				      = new DialogChapDisp(t->html, be); 
-			be->init_SWORD(1);			
-			t->key = g_strdup(settings.currentverse);
-			main_dialog_update_controls(t);
+			be->init_SWORD(1);
+			if(key)
+				t->key = g_strdup(key);
+			else			
+				t->key = g_strdup(settings.currentverse);
 			dlg_bible = t;
+			t->navbar.is_dialog = TRUE;
+			t->navbar.key = g_strdup(settings.currentverse);
+			t->navbar.module_name = g_strdup(mod_name);
+			main_navbar_fill_book_combo(t->navbar);
 		break;
 		case COMMENTARY_TYPE:
+			t->mod_type = COMMENTARY_TYPE;
 			gui_create_commentary_dialog(t, FALSE);
 			be->entryDisplay = new DialogEntryDisp(t->html, be); 
 			be->init_SWORD(1);
-			t->key = g_strdup(settings.currentverse);
-			main_dialog_update_controls(t);
+			if(key)
+				t->key = g_strdup(key);
+			else			
+				t->key = g_strdup(settings.currentverse);
+			t->navbar.is_dialog = TRUE;
+			t->navbar.key = g_strdup(settings.currentverse);
+			t->navbar.module_name = g_strdup(mod_name);
+			main_navbar_fill_book_combo(t->navbar);
 		break;
 		case PERCOM_TYPE:
-			t->editor = (GSHTMLEditorControlData *) 
-					gs_html_editor_control_data_new();
+			t->mod_type = PERCOM_TYPE;
+			gui_create_note_editor(t);
 			ec = (GSHTMLEditorControlData *) t->editor;
-			ec->stylebar = TRUE;
-			ec->editbar = TRUE;
-			ec->personal_comments = TRUE;
 			ec->key = g_strdup(settings.currentverse);
 			strcpy(ec->filename, t->mod_name);
 			t->is_percomm = TRUE;
-			gui_create_note_editor(t);
 			be->entryDisplay 
 				    = new DialogEntryDisp(ec->htmlwidget, be); 
 			be->init_SWORD(1);
-			t->key = g_strdup(settings.currentverse);
-			main_dialog_update_controls(t);
+			ec->be = (BackEnd*)be;
+			if(key)
+				t->key = g_strdup(key);
+			else			
+				t->key = g_strdup(settings.currentverse);
 			settings.percomm_dialog_exist = TRUE;
 			dlg_percom = t;
+			t->navbar.is_dialog = TRUE;
+			t->navbar.key = g_strdup(t->key);
+			t->navbar.module_name = g_strdup(mod_name);
+			main_navbar_fill_book_combo(t->navbar);
 		break;
 		case DICTIONARY_TYPE:
+			t->mod_type = DICTIONARY_TYPE;
 			gui_create_dictlex_dialog(t);
 			be->entryDisplay = new DialogEntryDisp(t->html, be); 
 			be->init_SWORD(1);
-			t->key = g_strdup(settings.dictkey);
+			if(key)
+				t->key = g_strdup(key);
+			else			
+				t->key = g_strdup(settings.dictkey);
 		break;
 		case BOOK_TYPE:
+			t->mod_type = BOOK_TYPE;
 			gui_create_gbs_dialog(t);
 			be->entryDisplay = new DialogEntryDisp(t->html, be); 
 			be->init_SWORD(1);
-			t->key = g_strdup(settings.book_key);
-			if(settings.book_offset)
-				t->offset = settings.book_offset;
+			t->key = NULL; 
+			if(key)
+				t->offset = atoi(key);
 			else
-				t->offset = 0;
+				t->offset = 4;
 		break;
 	}
 		
 	gtk_widget_show(t->dialog);
 	list_dialogs = g_list_append(list_dialogs, (DIALOG_DATA *) t);
 	be->set_module(t->mod_name);
-	be->set_key(t->key);
+	
+	if(type == BOOK_TYPE) {
+		main_dialogs_add_book_to_tree(t->tree, t->mod_name, 
+			     TRUE, t);
+		be->set_treekey(t->offset);
+		g_message("offset = %d",t->offset);
+	} else
+		be->set_key(t->key);
 	
 	if (be->get_config_entry(t->mod_name, "CipherKey")) {
 		t->cipher_old = be->get_config_entry(t->mod_name, "CipherKey");
@@ -1265,10 +1433,7 @@ void main_dialogs_open(gchar * mod_name)
 	} else {
 		t->is_locked = 0;
 		t->cipher_old = NULL;
-	}
-	
-	if(type == BOOK_TYPE)
-		be->set_treekey(t->offset);
+	}	
 	
 	be->display_mod->Display();
 	bible_apply_change = TRUE;
@@ -1278,10 +1443,7 @@ void main_dialogs_open(gchar * mod_name)
 	}
 	if(type == DICTIONARY_TYPE)
 		gtk_entry_set_text(GTK_ENTRY(t->entry),t->key);	
-	if(type == BOOK_TYPE)
-		main_dialogs_add_book_to_tree(t->tree, t->mod_name, 
-			     TRUE, t);
+	return t;
 }
 
-
 /******   end of file   ******/
