@@ -1,6 +1,6 @@
 /*
  * GnomeSword Bible Study Tool
- * sword.c - glue 
+ * sword.cc - glue 
  *
  * Copyright (C) 2000,2001,2002 GnomeSword Developer Team
  *
@@ -27,15 +27,21 @@
 #include <gnome.h>
 #include <swmgr.h>
 #include <swmodule.h>
-
-#ifdef USE_SWORD_CVS
 #include <stringmgr.h>
+#include <localemgr.h>
+
+#ifdef USE_GTKMOZEMBED
+#include <gtkmozembed.h>
+#include <gtkmozembed_internal.h>
+#include <nsIDOMMouseEvent.h>
+#include <dom/nsIDOMKeyEvent.h>
 #endif
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 #include <gtkhtml/gtkhtml.h>
+#include "gui/bibletext.h"
 #ifdef __cplusplus
 }
 #endif
@@ -47,21 +53,27 @@ extern "C" {
 #include "gui/font_dialog.h"
 #include "gui/widgets.h"
 #include "gui/commentary.h"
+#include "gui/parallel_dialog.h"
 #include "gui/parallel_view.h"
 #include "gui/tabbed_browser.h"
 #include "gui/gnomesword.h"
+#include "gui/sidebar.h"
 #include "gui/utilities.h"
+#include "gui/html.h"
 
 #include "main/display.hh"
-#include "main/sword.h"
-#include "main/settings.h"
 #include "main/lists.h"
+#include "main/navbar.h"
+#include "main/previewer.h"
+#include "main/settings.h"
+#include "main/sword.h"
 #include "main/xml.h"
  
 #include "main/parallel_view.h"
-#include "backend/sword.h"
 #include "backend/sword_main.hh"
 
+extern char *OLD_CODESET;
+using namespace sword; 
 	
 #define HTML_START "<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"></head>"
 
@@ -69,11 +81,11 @@ extern GtkWidget *cbe_book;
 extern GtkWidget *spb_chapter;
 extern GtkWidget *spb_verse;
 extern GtkWidget *cbe_freeform_lookup;
+extern gboolean shift_key_presed;
 
 gboolean style_display = TRUE;
 
-
-
+	
 /******************************************************************************
  * Name
  *  set_module_unlocked
@@ -96,6 +108,31 @@ void main_set_module_unlocked(char * mod_name, char * key)
 	mgr->setCipherKey(mod_name, key);	
 }
 
+
+/******************************************************************************
+ * Name
+ *  main_save_module_key
+ *
+ * Synopsis
+ *   #include "main/configs.h"
+ *
+ *   void main_save_module_key(gchar * mod_name, gchar * key)	
+ *
+ * Description
+ *    to unlock locked modules
+ *
+ * Return value
+ *   void
+ */ 
+
+void main_save_module_key(char * mod_name, char * key)
+{
+	backend->save_module_key(mod_name, key);
+
+	/* FIXME: we need to display change */
+}
+
+
 /******************************************************************************
  * Name
  *   main_update_nav_controls
@@ -114,34 +151,16 @@ void main_set_module_unlocked(char * mod_name, char * key)
 
 gchar *main_update_nav_controls(const gchar * key)
 {
-	char *val_key;
-	gint cur_chapter = 8, cur_verse = 28;
-
-	settings.apply_change = FALSE;
-	val_key = backend->get_valid_key(key);
-	//g_warning(key);
-	//g_warning("key = %s val_key = %s",key,val_key);
-	cur_chapter = backend->key_get_chapter(val_key);
-	cur_verse = backend->key_get_verse(val_key);
+	char *val_key = backend->get_valid_key(key);
+	
 	/* 
-	 *  remember last verse 
+	 *  remember verse 
 	 */
 	xml_set_value("GnomeSword", "keys", "verse", val_key);
 	settings.currentverse = xml_get_value("keys", "verse");
-	/* 
-	 *  set book, chapter,verse and freeform lookup entries
-	 *  to new verse - settings.apply_change is set to false so we don't
-	 *  start a loop
-	 */
-	gtk_entry_set_text(GTK_ENTRY(cbe_book),
-			   backend->key_get_book(val_key));
-	gtk_spin_button_set_value(GTK_SPIN_BUTTON
-				  (spb_chapter), cur_chapter);
-	gtk_spin_button_set_value(GTK_SPIN_BUTTON
-				  (spb_verse), cur_verse);
-	gtk_entry_set_text(GTK_ENTRY(cbe_freeform_lookup), val_key);
-	if(settings.browsing)
-		gui_set_tab_label(val_key);
+	
+	settings.apply_change = FALSE;
+	main_navbar_set(navbar_main, val_key);
 	settings.apply_change = TRUE;
 	return val_key;
 }
@@ -223,6 +242,7 @@ char *main_get_active_pane_module(void)
 	}
 	return NULL;
 }
+
 /******************************************************************************
  * Name
  *  module_name_from_description
@@ -246,12 +266,12 @@ char *main_module_name_from_description(char *description)
 
 /******************************************************************************
  * Name
- *  get_sword_version
+ *  main_get_sword_version
  *
  * Synopsis
  *   #include "sword.h"
  *
- *   const char *get_sword_version(void)	
+ *   const char *main_get_sword_version(void)	
  *
  * Description
  *    
@@ -260,12 +280,13 @@ char *main_module_name_from_description(char *description)
  *   const char *
  */ 
 
-const char *get_sword_version(void)
+const char *main_get_sword_version(void)
 {
-	return backend_get_sword_version();
+	return backend->get_sword_version();
 }
 
 
+
 /******************************************************************************
  * Name
  *   
@@ -282,39 +303,9 @@ const char *get_sword_version(void)
  *   char*
  */
 
-char *main_get_crossref(char * mod_name, char * key, char * note_number)
+char *main_get_treekey_local_name(unsigned long offset)
 {
-	
-		backend->set_module_key(mod_name, key);
-		return g_strdup(backend->get_entry_attribute("Footnote",
-							note_number,
-							"refList"));
-}
-
-
-/******************************************************************************
- * Name
- *   
- *
- * Synopsis
- *   #include "main/module.h"
- *
- *   
- *
- * Description
- *   
- *
- * Return value
- *   char*
- */
-
-char *main_get_footnote_body(char * mod_name, char * key, char * note_number)
-{
-	
-	backend->set_module_key(mod_name, key);
-	return g_strdup(backend->get_entry_attribute("Footnote",
-							note_number,
-							"body"));
+	return backend->treekey_get_local_name(offset);
 }
 
 
@@ -343,12 +334,12 @@ char *main_get_search_results_text(char * mod_name, char * key)
 
 /******************************************************************************
  * Name
- *  get_path_to_mods
+ *  main_get_path_to_mods
  *
  * Synopsis
  *   #include "sword.h"
  *
- *   	gchar *get_path_to_mods(void)
+ *   	gchar *main_get_path_to_mods(void)
  *
  * Description
  *    returns the path to the sword modules
@@ -357,7 +348,7 @@ char *main_get_search_results_text(char * mod_name, char * key)
  *   gchar *
  */ 
 
-char *get_path_to_mods(void)
+char *main_get_path_to_mods(void)
 {
 	SWMgr *mgr = backend->get_main_mgr();
 	char *path = mgr->prefixPath;
@@ -367,10 +358,50 @@ char *get_path_to_mods(void)
 }
 
 
-void init_sword(void)
-{
-	backend_init();
+/******************************************************************************
+ * Name
+ *   backend_init
+ *
+ * Synopsis
+ *   #include "main/sword.h"
+ *
+ *   void main_init_backend(void)	
+ *
+ * Description
+ *   start sword 
+ *
+ * Return value
+ *   void
+ */
+
+void main_init_backend(void)
+{	
+	char *sword_locale = NULL;
+	char *sys_locale = NULL;
+	const char *lang = getenv("LANG");
+	SWMgr mgr;
+	
+	backend = new BackEnd();
+	backend->init_SWORD(0);
+	sword_locale = backend->set_sword_locale(lang);
+#ifdef DEBUG	
+	//g_print("date: %s\n", getenv("DATE"));
+	g_print("%s sword-%s\n", _("Starting"), backend->get_sword_version());
+	g_print("%s\n", _("Initiating SWORD"));
+	g_print("%s: %s\n",_("path to sword"),mgr.prefixPath);
+	g_print("%s %s\n", _("System locale is"),lang);	
+	g_print("%s %s\n", _("SWORD locale is"), sword_locale);	
+	g_print("OLD_CODESET = %s\n\n", OLD_CODESET);
+	g_print("%s\n", _("Checking for SWORD Modules"));
+#endif
+	sys_locale = strdup(lang);
+	settings.spell_language = strdup(sys_locale);	
+	main_init_lists();
+	free((char*)sword_locale);
+	free(sys_locale);	
 }
+
+
 /******************************************************************************
  * Name
  *   shutdown_sword
@@ -381,15 +412,18 @@ void init_sword(void)
  *   void shutdown_sword(void)	
  *
  * Description
- *   close down sword by calling backend_shutdown();
+ *   close down sword by deleting backend;
  *
  * Return value
  *   void
  */
 
-void shutdown_backend(void)
+void main_shutdown_backend(void)
 {
-	backend_shutdown(TRUE);
+	delete backend; 
+#ifdef DEBUG	
+	g_print("%s\n", _("SWORD is shutdown"));
+#endif
 }
 
 /******************************************************************************
@@ -409,9 +443,10 @@ void shutdown_backend(void)
  *   void
  */
 
-void main_locked_module_display(GtkWidget * html_widget,
-				  gchar * mod_name, gchar * cipher_key)
+void main_locked_module_display(gpointer data,
+				  char * mod_name, char * cipher_key)
 {
+	GtkWidget *html_widget = (GtkWidget *) data;
 	GtkHTML *html = GTK_HTML(html_widget);
 	GtkHTMLStreamStatus status1;
 	GtkHTMLStream *htmlstream;
@@ -496,273 +531,191 @@ void main_locked_module_display(GtkWidget * html_widget,
 
 }
 
-
 /******************************************************************************
  * Name
- *   mark_search_words
+ *   main_dictionary_entry_changed
  *
  * Synopsis
- *   #include ".h"
+ *   #include "main/sword.h"
  *
- *   void mark_search_words( GString *str )	
+ *   void main_dictionary_entry_changed(char * mod_name)
  *
  * Description
- *    
+ *   text in the dictionary entry has changed and the entry activated
  *
  * Return value
  *   void
  */
 
-static void mark_search_words(GString * str)
-{
-	gchar *tmpbuf, *buf, *searchbuf;
-	gint len1, len2, len3, len4;
-	gchar closestr[40], openstr[40];
-
-	/* regular expression search results         **fixme** */
-	if (settings.searchType == 0) {
-		return;
-	}
-	/* close tags */
-	sprintf(closestr, "</b></font>");
-	/* open tags */
-	sprintf(openstr, "<font color=\"%s\"><b>",
-		settings.found_color);
-	/* point buf to found verse */
-	buf = str->str;
-	searchbuf = g_strdup(settings.searchText);
-
-	/* if we have a muti word search go here */
-	if (settings.searchType == -2) {
-		char *token;
-		GList *list;
-		gint count = 0, i = 0;
-
-		list = NULL;
-		/* seperate the search words and add them to a glist */
-		if ((token = strtok(searchbuf, " ")) != NULL) {
-			list = g_list_append(list, token);
-			++count;
-			while ((token = strtok(NULL, " ")) != NULL) {
-				list = g_list_append(list, token);
-				++count;
-			}
-			/* if we have only one word */
-		} else {
-			list = g_list_append(list, searchbuf);
-			count = 1;
-		}
-		list = g_list_first(list);
-		/* find each word in the list and mark it */
-		for (i = 0; i < count; i++) {
-			/* set len1 to length of verse */
-			len1 = strlen(buf);
-			/* set len2 to length of search word */
-			len2 = strlen((gchar *) list->data);
-			/* find search word in verse */
-			if ((tmpbuf =
-			     strstr(buf,
-				    (gchar *) list->data)) != NULL) {
-				/* set len3 to length of tmpbuf 
-				   (tmpbuf points to first occurance of 
-				   search word in verse) */
-				len3 = strlen(tmpbuf);
-				//-- set len4 to diff between len1 and len3
-				len4 = len1 - len3;
-				/* add end tags first 
-				   (position to add tag to is len4 + len2) */
-				str =
-				    g_string_insert(str, (len4 + len2),
-						    closestr);
-				/* then add start tags 
-				   (position to add tag to is len4) */
-				str =
-				    g_string_insert(str, len4, openstr);
-			}
-			/* point buf to changed str */
-			buf = str->str;
-			list = g_list_next(list);
-		}
-		g_list_free(list);
-
-		/* else we have a phrase and only need to mark it */
-	} else {
-		len1 = strlen(buf);
-		len2 = strlen(searchbuf);
-		tmpbuf = strstr(buf, searchbuf);
-		if (tmpbuf) {
-			len3 = strlen(tmpbuf);
-			len4 = len1 - len3;
-			/* place end tag first */
-			str =
-			    g_string_insert(str, (len4 + len2),
-					    closestr);
-			/* then place start tag */
-			str = g_string_insert(str, len4, openstr);
-		}
-	}
-	/* free searchbuf */
-	g_free(searchbuf);
-}
-
-
-/******************************************************************************
- * Name
- *   main_entry_display
- *
- * Synopsis
- *   #include ".h"
- *
- *   void main_entry_display(GtkWidget * html_widget, gchar * mod_name, 
- *					      gchar * text, gchar *key)
- *
- * Description
- *   display Sword modules one verse (entry) at a time
- *
- * Return value
- *   void
- */
-
-void main_entry_display(GtkWidget * html_widget, gchar * mod_name,
-		   gchar * text, gchar * key, gboolean show_key)
-{
-	GString *tmp_str = g_string_new(NULL);
-	GString *str;
-	GString *search_str;
-	gboolean was_editable = FALSE;
-	MOD_FONT *mf = get_font(mod_name);
-	GtkHTML *html = GTK_HTML(html_widget);
-
-	/* setup gtkhtml widget */
-	was_editable = gtk_html_get_editable(html);
-	if (was_editable)
-		gtk_html_set_editable(html, FALSE);
-
-	g_string_printf(tmp_str,
-		HTML_START
-		"<body bgcolor=\"%s\" text=\"%s\" link=\"%s\">",
-		settings.bible_bg_color, settings.bible_text_color,
-		settings.link_color);
-
-	str = g_string_new(tmp_str->str);
-	/* show key in html widget  */
-	if (show_key) {
-		if ((settings.displaySearchResults)) {
-			g_string_printf(tmp_str,
-				"<a href=\"sword://%s/%s\">"
-				"<font color=\"%s\">[%s] %s </font></A>",
-				mod_name,
-				key,
-				settings.bible_verse_num_color,
-				mod_name, key);
-		} else {
-			g_string_printf(tmp_str,
-				"<a href=\"about://%s/%s\">"
-				"<font color=\"%s\">[%s]</a></font>[%s] ",
-				mod_name,
-				backend->module_description(mod_name),
-				settings.bible_verse_num_color,
-				mod_name, 
-				key);
-		}
-		str = g_string_append(str, tmp_str->str);
-	}
-	
-	g_string_printf(tmp_str, 
-			"<font face=\"%s\" size=\"%s\">",
-			(mf->old_font)?mf->old_font:"none", 
-			(mf->old_font_size)?mf->old_font_size:"+0");
-	str = g_string_append(str, tmp_str->str);
-	
-	if (settings.displaySearchResults) {
-		search_str = g_string_new(text);
-		mark_search_words(search_str);
-		str = g_string_append(str, search_str->str);
-	} else {
-		str = g_string_append(str, text);
-	}
-
-	g_string_printf(tmp_str, " %s", "</font></body></html>");
-	str = g_string_append(str, tmp_str->str);
-
-	if (str->len) {
-		gtk_html_load_from_string(html,str->str,str->len);
-	}
-	gtk_html_set_editable(html, was_editable);
-
-	/* andyp - inserted for debugging, remove */
-	//g_print(str->str); 
-	
-	free_font(mf);
-	g_string_free(str, TRUE);
-	g_string_free(tmp_str, TRUE);
-}
-
-void main_dictionary_entery_changed(char * mod_name)
-{
-	gint count = 7, i;
-	gchar *new_key, *text = NULL;
+void main_dictionary_entry_changed(char * mod_name)
+{	
 	gchar *key = NULL;
 	gchar *key2 = NULL;
-	static gboolean firsttime = TRUE;
-	GtkTreeModel *model;
-	GtkListStore *list_store;
-	GtkTreeIter iter;
-	gint height;
-	//StringMgr *strmgr;
 	
-	//strmgr = new StringMgr();
-	key = (gchar*)gtk_entry_get_text(GTK_ENTRY(widgets.entry_dict));
-	//g_warning(key);
+	
+	if(strcmp(settings.DictWindowModule,mod_name)) {
+		xml_set_value("GnomeSword", "modules", "dict",
+					mod_name);
+		settings.DictWindowModule = xml_get_value(
+					"modules", "dict");
+	}	
+	
+	key = g_strdup((gchar*)gtk_entry_get_text(GTK_ENTRY(widgets.entry_dict)));
+	
 	key2 = g_utf8_strup(key,strlen(key));
-	//key2 = toupperstr(key);
-//	g_warning(key2);
 	
-	//key = g_ascii_strup(key,strlen(key));
-	//g_warning(key);
 	backend->set_module_key(mod_name, key2);
 	g_free(key2);
-	//g_warning("mod = %s key = %s",mod_name, key);
+	g_free(key);
 	key = backend->get_module_key();
-	//g_warning(key);
+	
 	xml_set_value("GnomeSword", "keys", "dictionary", key);
 	settings.dictkey = xml_get_value("keys", "dictionary");
 	
 	backend->set_module_key(mod_name, key);
 	backend->display_mod->Display();
-	g_free(key);
-	model = gtk_tree_view_get_model(GTK_TREE_VIEW(widgets.listview_dict));
-	list_store = GTK_LIST_STORE(model);
 	
-	if (!firsttime) {
-		gdk_drawable_get_size ((GdkDrawable *)widgets.listview_dict->window,
-                                             NULL,
-                                             &height);
-		count = height / settings.cell_height;
-	}	 
-
-	if (count) {
-		gtk_list_store_clear(list_store);
-		new_key = backend->navigate_module(-1);
-
-		for (i = 0; i < (count / 2); i++) {
-			free(new_key);
-			new_key = backend->navigate_module(0);
-		}
-
-		for (i = 0; i < count; i++) {
-			free(new_key);
-			new_key = backend->navigate_module(1);
-			gtk_list_store_append(list_store, &iter);
-			gtk_list_store_set(list_store, &iter, 0,
-					   new_key, -1);
-		}
-		free(new_key);
-	}
-	firsttime = FALSE;
+	gtk_entry_set_text(GTK_ENTRY(widgets.entry_dict), key);
+	g_free(key);
 } 
 
 
+
+static void dict_key_list_select(GtkMenuItem * menuitem, gpointer user_data)
+{
+	gtk_entry_set_text(GTK_ENTRY(widgets.entry_dict), (gchar*) user_data);
+	gtk_widget_activate(widgets.entry_dict);
+}
+
+/******************************************************************************
+ * Name
+ *   
+ *
+ * Synopsis
+ *   #include "main/sword.h"
+ *
+ *   
+ *
+ * Description
+ *   text in the dictionary entry has changed and the entry activated
+ *
+ * Return value
+ *   void
+ */
+
+GtkWidget *main_dictionary_drop_down_new(char * mod_name, char * old_key)
+{	
+	gint count = 9, i;
+	gchar *new_key, *text = NULL;
+	gchar *key = NULL;
+	gchar *key2 = NULL;
+	gint height;
+        gsize bytes_written;
+	GtkWidget *menu;
+	GtkWidget * item;
+	
+	menu = gtk_menu_new();
+	
+	if(strcmp(settings.DictWindowModule,mod_name)) {
+		xml_set_value("GnomeSword", "modules", "dict",
+					mod_name);
+		settings.DictWindowModule = xml_get_value(
+					"modules", "dict");
+	}	
+	
+	key = g_strdup((gchar*)gtk_entry_get_text(GTK_ENTRY(widgets.entry_dict)));
+	
+	key2 = g_utf8_strup(key,strlen(key));
+	
+	backend->set_module_key(mod_name, key2);
+	g_free(key2);
+	g_free(key);
+	key = backend->get_module_key();
+	
+	xml_set_value("GnomeSword", "keys", "dictionary", key);
+	settings.dictkey = xml_get_value("keys", "dictionary");
+	
+	backend->set_module_key(mod_name, key);
+	backend->display_mod->Display();
+	/*new_key = g_locale_to_utf8((char*)backend->display_mod->KeyText(),
+                                             -1,
+                                             NULL,
+                                             &bytes_written,
+                                             NULL);*/
+	
+	new_key = g_strdup((char*)backend->display_mod->KeyText());
+	
+	for (i = 0; i < (count / 2)+1; i++) {
+		free(new_key);
+		(*backend->display_mod)--;
+		/*new_key = g_locale_to_utf8((char*)backend->display_mod->KeyText(),
+                                             -1,
+                                             NULL,
+                                             &bytes_written,
+                                             NULL);*/
+		new_key = g_strdup((char*)backend->display_mod->KeyText());
+	}
+
+	for (i = 0; i < count; i++) {
+		free(new_key);			
+		(*backend->display_mod)++;
+		/*new_key = g_locale_to_utf8((char*)backend->display_mod->KeyText(),
+                                             -1,
+                                             NULL,
+                                             &bytes_written,
+                                             NULL);*/
+		new_key = g_strdup((char*)backend->display_mod->KeyText());
+		/* add menu item */
+		item =
+		    gtk_menu_item_new_with_label((gchar *) new_key);
+		gtk_widget_show(item);
+		g_signal_connect(GTK_OBJECT(item), "activate",
+				   G_CALLBACK(dict_key_list_select),
+				   g_strdup(new_key));		
+		gtk_container_add(GTK_CONTAINER(menu), item); 
+	}
+	
+	free(new_key);
+	g_free(key);
+	return menu;
+} 
+
+/******************************************************************************
+ * Name
+ *   main_dictionary_button_clicked
+ *
+ * Synopsis
+ *   #include "main/sword.h"
+ *
+ *   void main_dictionary_button_clicked(gint direction)
+ *
+ * Description
+ *   The back or foward dictinary key button was clicked.
+ *   the module key is set to the current dictkey.
+ *   then the module is incremented or decremented.
+ *   the new key is returned from the module and the dictionary entry is set
+ *   to the new key. The entry is then activated.
+ *
+ * Return value
+ *   void
+ */
+
+
+void main_dictionary_button_clicked(gint direction)
+{	
+	gchar *key = NULL;
+	backend->set_module_key(settings.DictWindowModule, 
+				settings.dictkey);
+	if(direction == 0)
+		(*backend->display_mod)--;
+	else
+		(*backend->display_mod)++;
+	key = g_strdup((char*)backend->display_mod->KeyText());	
+	gtk_entry_set_text(GTK_ENTRY(widgets.entry_dict), key);
+	gtk_widget_activate(widgets.entry_dict);
+	g_free(key);
+}
+
 void main_display_book(const char * mod_name, char * key)
 {
 	if(!settings.havebook || !mod_name)
@@ -772,10 +725,7 @@ void main_display_book(const char * mod_name, char * key)
 	if(!settings.book_mod)
 		settings.book_mod = (char*)mod_name;
 	
-	//settings.comm_showing = FALSE;
 	settings.whichwindow = BOOK_WINDOW;
-	gtk_label_set_text (GTK_LABEL(widgets.label_comm),mod_name);
-	gui_change_window_title(settings.book_mod);
 	
 	xml_set_value("GnomeSword", "keys", "offset", key);
 	settings.book_offset = atol(xml_get_value( "keys", "offset"));
@@ -800,18 +750,20 @@ void main_display_book(const char * mod_name, char * key)
 }
 
 void main_display_commentary(const char * mod_name, const char * key)
-{
-	if(!settings.havecomm || !mod_name || !settings.comm_showing)
+{	
+	if(!settings.havecomm || !settings.comm_showing)
 		return;
-	if(!backend->is_module(mod_name))
+	
+	if(!mod_name)
+		mod_name = xml_get_value("modules", "comm");
+	
+	if(!mod_name || !backend->is_module(mod_name))
 		return;
 	if(!settings.CommWindowModule)
 		settings.CommWindowModule = (char*)mod_name;
 	
-	//settings.comm_showing = TRUE;
+	settings.comm_showing = TRUE;
 	settings.whichwindow = COMMENTARY_WINDOW;
-	gtk_label_set_text (GTK_LABEL(widgets.label_comm),mod_name);
-	gui_change_window_title(settings.CommWindowModule);
 	
 	if(strcmp(settings.CommWindowModule,mod_name)) {
 		xml_set_value("GnomeSword", "modules", "comm", mod_name);
@@ -847,16 +799,18 @@ void main_display_dictionary(char * mod_name, char * key)
 		settings.DictWindowModule = xml_get_value(
 					"modules", "dict");
 	}
-	gtk_label_set_text (GTK_LABEL(widgets.label_dict),mod_name);
+	//gtk_label_set_text (GTK_LABEL(widgets.label_dict),mod_name);
 	
 	if(key == NULL)
 		key = "Grace";
 	
 	old_key = gtk_entry_get_text(GTK_ENTRY(widgets.entry_dict));
 	if(!strcmp(old_key, key))
-		main_dictionary_entery_changed(settings.DictWindowModule);
-	else
+		main_dictionary_entry_changed(settings.DictWindowModule);
+	else {
 		gtk_entry_set_text(GTK_ENTRY(widgets.entry_dict), key);
+		gtk_widget_activate(widgets.entry_dict);
+	}
 	
 	if(settings.browsing)
 		gui_update_tab_struct(NULL,
@@ -873,21 +827,21 @@ void main_display_bible(const char * mod_name, const char * key)
 {
 	gchar *file = NULL;
 	gchar *style = NULL;
+	gchar *val_key = NULL;
+	
+	
+	if(!mod_name)
+		mod_name = xml_get_value("modules", "bible");	
+	
 	
 	if(!settings.havebible || !mod_name)
 		return;
 	if(!backend->is_module(mod_name))
 		return;
-
+	
 	file = g_strdup_printf("%s/modops.conf", settings.gSwordDir);
 	if(!settings.MainWindowModule)
 		settings.MainWindowModule = (char*)mod_name;
-	if(strcmp(settings.MainWindowModule, mod_name)) {
-		xml_set_value("GnomeSword", "modules", "bible",
-					mod_name);
-		settings.MainWindowModule = xml_get_value(
-					"modules", "bible");
-	}
 	
 	if(strcmp(settings.currentverse, key)) {
 		xml_set_value("GnomeSword", "keys", "verse",
@@ -896,6 +850,20 @@ void main_display_bible(const char * mod_name, const char * key)
 					"keys", "verse");
 	}
 	
+	if(strcmp(settings.MainWindowModule, mod_name)) {
+		xml_set_value("GnomeSword", "modules", "bible",
+					mod_name);
+		settings.MainWindowModule = xml_get_value(
+					"modules", "bible");
+		if(navbar_main.module_name) 
+			g_free(navbar_main.module_name);
+		navbar_main.module_name = g_strdup(settings.MainWindowModule);
+		if(navbar_main.key) 
+			g_free(navbar_main.key);
+		navbar_main.key = g_strdup(settings.currentverse);
+		main_navbar_fill_book_combo(navbar_main);
+	}
+	
 	settings.whichwindow = MAIN_TEXT_WINDOW;
 	gui_change_window_title(settings.MainWindowModule);
 	
@@ -911,9 +879,24 @@ void main_display_bible(const char * mod_name, const char * key)
 				       settings.versestyle);
 	style_display = TRUE;
 	
-	backend->set_module_key(mod_name, key);
-	backend->display_mod->Display();
+	if(backend->module_has_testament(mod_name,
+				backend->get_key_testament(key))) {
+			backend->set_module_key(mod_name, key);
+			backend->display_mod->Display();
+	} else {
+		if(backend->get_key_testament(key) == 1)
+			val_key = main_update_nav_controls("Matthew 1:1");
+		else
+			val_key = main_update_nav_controls("Genesis 1:1");
+		
+		backend->set_module_key(mod_name, val_key);
+		backend->display_mod->Display();
+		g_free(val_key);			
+	}
 	
+#ifdef DEBUG 
+	g_print("mod_name = %s\n",mod_name);	
+#endif
 	if(settings.browsing) {
 		gui_update_tab_struct(mod_name,
 				      NULL,
@@ -928,32 +911,78 @@ void main_display_bible(const char * mod_name, const char * key)
 	/*
 	 * change parallel verses
 	 */
-	if (settings.dockedInt) {
+	if (settings.dockedInt) 
 		main_update_parallel_page();
-	}
-
+	else
+		gui_keep_parallel_dialog_in_sync();
 }
 
 
-void main_change_verse(const char * bible, const char * commentary, 
-						const char * key)
+
+
+/******************************************************************************
+ * Name
+ *   main_display_devotional
+ *
+ * Synopsis
+ *   #include "main/sword.h"
+ *
+ *   void main_display_devotional(void)
+ *
+ * Description
+ *
+ *
+ * Return value
+ *   void
+ */
+
+void main_display_devotional(void)
 {
+	gchar buf[80];
+	time_t curtime;
+	struct tm *loctime;
+	gchar *text;
+
+	/*
+	 * Get the current time.
+	 */
+	curtime = time(NULL);
+
+	/*
+	 * Convert it to local time representation.
+	 */
+	loctime = localtime(&curtime);
+
+	/*
+	 * Print it out in a nice format.
+	 */
+	strftime(buf, 80, "%m.%d", loctime);
 	
+	text = backend->get_render_text(settings.devotionalmod, buf);
+	if (text) {
+		main_entry_display(sidebar.html_viewer_widget,
+			      settings.devotionalmod, text, buf, TRUE);
+		free(text);
+	}
 }
 
 
 void main_setup_displays(void)
-{
-//	sw.entryDisplay = new GTKEntryDisp(widgets.html_comm,backend);
-//	sw.dictDisplay = new GTKEntryDisp(widgets.html_dict,backend);
-}
+{ 
 
-void main_setup_new_displays(void)
-{
-	backend->commDisplay = new GTKEntryDisp(widgets.html_comm,backend);
-	backend->dictDisplay = new GTKEntryDisp(widgets.html_dict,backend);
-	backend->textDisplay = new GTKChapDisp(widgets.html_text,backend);
+#ifdef USE_GTKMOZEMBED
+	backend->textDisplay = new GtkMozChapDisp(widgets.html_text,backend);
+	backend->RTOLDisplay = new GtkMozChapDisp(widgets.html_text,backend);
+	backend->commDisplay = new GTKMozEntryDisp(widgets.html_comm,backend);
+	backend->bookDisplay = new GTKMozEntryDisp(widgets.html_book,backend);
+	backend->dictDisplay = new GTKMozEntryDisp(widgets.html_dict,backend);
+#else
 	backend->RTOLDisplay = new GTKTextviewChapDisp(widgets.textview,backend);
+	backend->textDisplay = new GTKChapDisp(widgets.html_text,backend);
+	backend->commDisplay = new GTKEntryDisp(widgets.html_comm,backend);
+	backend->bookDisplay = new GTKEntryDisp(widgets.html_book,backend);
+	backend->dictDisplay = new GTKEntryDisp(widgets.html_dict,backend);
+#endif
 }
 
 const char *main_get_module_language(const char *module_name)
